@@ -17,17 +17,17 @@ if [ "$QUBES" = "true" ]; then
 fi
 
 meson .. \
-    -Ddocs=none \
+    -Ddocs=disabled \
     -Dman=true \
     -Dtests=true \
+    -Db_sanitize=address,undefined \
     -Dgusb:tests=false \
     -Dplugin_dummy=true \
-    -Dplugin_flashrom=true \
-    -Dplugin_modem_manager=false \
-    -Dplugin_thunderbolt=true \
-    -Dplugin_uefi_capsule=true \
-    -Dplugin_dell=true \
-    -Dplugin_synaptics_mst=true $@
+    -Dplugin_flashrom=enabled \
+    -Dplugin_modem_manager=disabled \
+    -Dplugin_uefi_capsule=enabled \
+    -Dplugin_dell=enabled \
+    -Dplugin_synaptics_mst=enabled $@
 ninja-build dist
 popd
 VERSION=`meson introspect build --projectinfo | jq -r .version`
