@@ -2,12 +2,21 @@
 set -e
 set -x
 
-#clone test firmware if necessary
-. ./contrib/ci/get_test_firmware.sh
-
 #check for and install missing dependencies
 ./contrib/ci/fwupd_setup_helpers.py install-dependencies --yes -o ubuntu
 
+#check we have pip
+./contrib/ci/fwupd_setup_helpers.py install-pip --yes -o ubuntu
+
+#check meson is new enough
+./contrib/ci/fwupd_setup_helpers.py test-meson
+
+#check markdown is new enough
+./contrib/ci/fwupd_setup_helpers.py test-markdown
+
+#clone test firmware if necessary
+. ./contrib/ci/get_test_firmware.sh
+
 #evaluate using Ubuntu's buildflags
 #evaluate using Debian/Ubuntu's buildflags
 #disable link time optimization, Ubuntu currently only sets it for GCC
@@ -20,7 +29,7 @@ export LDFLAGS
 root=$(pwd)
 rm -rf ${root}/build
 chown -R nobody ${root}
-sudo -u nobody meson ${root}/build -Dman=false -Ddocs=docgen -Dgusb:tests=false -Dplugin_platform_integrity=true --prefix=${root}/dist
+sudo -u nobody meson ${root}/build -Dman=false -Ddocs=enabled -Dgusb:tests=false -Dplugin_platform_integrity=true --prefix=${root}/dist
 #build with clang
 sudo -u nobody ninja -C ${root}/build test -v
 
