@@ -15,7 +15,7 @@ import sys
 import imp
 import io
 import platform
-from distutils.version import LooseVersion as l_ver
+from packaging.version import Version
 from pathlib import Path
 from test.fwupd_logs import UPDATE_INFO, GET_DEVICES, DMI_DECODE
 from test.fwupd_logs import GET_DEVICES_NO_UPDATES, GET_DEVICES_NO_VERSION
@@ -218,34 +218,29 @@ class TestQubesFwupdmgr(unittest.TestCase):
     @unittest.skipUnless("qubes" in platform.release(), "Requires Qubes OS")
     def test_download_firmware_updates(self):
         self.q._download_firmware_updates(
-            "https://fwupd.org/downloads/0a29848de74d26348bc5a6e24fc9f03778eddf0e-hughski-colorhug2-2.0.7.cab",
-            "32c4a2c9be787cdf1d757c489d6455bd7bb14053425180b6d331c37e1ccc1cda",
+            "https://fwupd.org/downloads/e5ad222bdbd3d3d48d8613e67c7e0a0e194f"
+            "8cd828e33c554d9f05d933e482c7-hughski-colorhug2-2.0.7.cab",
+            "e5ad222bdbd3d3d48d8613e67c7e0a0e194f8cd828e33c554d9f05d933e482c7",
         )
         update_path = os.path.join(
             FWUPD_DOM0_UPDATES_DIR,
-            "0a29848de74d26348bc5a6e24fc9f03778eddf0e-hughski-colorhug2-2.0.7",
+            "e5ad222bdbd3d3d48d8613e67c7e0a0e194f8cd828e33c554d9f05d933e482c7"
+            "-hughski-colorhug2-2.0.7.cab",
         )
         self.assertTrue(os.path.exists(update_path))
 
-    @unittest.skipUnless("qubes" in platform.release(), "Requires Qubes OS")
-    def test_download_firmware_special_char(self):
-        self.q._download_firmware_updates(
-            "https://fwupd.org/downloads/bc334d8b098f2e91603c5f7dfdc837fb01797bbe-Dell%20XPS%2015%209560&Precision%205520%20System%20BIOS_Ver.1.18.0.cab",
-            "86d9e5e35b0b264be1bb1e49ec16ccd1330390423bfe962267a58c27be7712b8",
-        )
-        update_path = os.path.join(FWUPD_DOM0_UPDATES_DIR, "trusted")
-        self.assertTrue(os.path.exists(update_path))
-
     @unittest.skipUnless(check_whonix_updatevm(), "Requires sys-whonix")
     def test_download_firmware_updates_whonix(self):
         self.q._download_firmware_updates(
-            "https://fwupd.org/downloads/0a29848de74d26348bc5a6e24fc9f03778eddf0e-hughski-colorhug2-2.0.7.cab",
-            "32c4a2c9be787cdf1d757c489d6455bd7bb14053425180b6d331c37e1ccc1cda",
+            "https://fwupd.org/downloads/e5ad222bdbd3d3d48d8613e67c7e0a0e194f"
+            "8cd828e33c554d9f05d933e482c7-hughski-colorhug2-2.0.7.cab",
+            "e5ad222bdbd3d3d48d8613e67c7e0a0e194f8cd828e33c554d9f05d933e482c7",
             whonix=True,
         )
         update_path = os.path.join(
             FWUPD_DOM0_UPDATES_DIR,
-            "0a29848de74d26348bc5a6e24fc9f03778eddf0e-hughski-colorhug2-2.0.7",
+            "e5ad222bdbd3d3d48d8613e67c7e0a0e194f8cd828e33c554d9f05d933e482c7"
+            "-hughski-colorhug2-2.0.7.cab",
         )
         self.assertTrue(os.path.exists(update_path))
 
@@ -444,7 +439,7 @@ class TestQubesFwupdmgr(unittest.TestCase):
         self.q._get_dom0_devices()
         downgrades = self.q._parse_downgrades(self.q.dom0_devices_info)
         new_version = downgrades[number]["Version"]
-        self.assertGreater(l_ver(old_version), l_ver(new_version))
+        self.assertGreater(Version(old_version), Version(new_version))
 
     @unittest.skipUnless(
         check_whonix_updatevm() and device_connected_usbvm(), REQUIRED_DEV
@@ -474,7 +469,7 @@ class TestQubesFwupdmgr(unittest.TestCase):
             raw = usbvm_device_info.read()
             downgrades = self.q._parse_downgrades(raw)
         new_version = downgrades[number]["Version"]
-        self.assertGreater(l_ver(old_version), l_ver(new_version))
+        self.assertGreater(Version(old_version), Version(new_version))
         old_version = None
         new_version = None
         self.q._get_dom0_updates()
@@ -506,7 +501,7 @@ class TestQubesFwupdmgr(unittest.TestCase):
                 break
         if new_version is None:
             self.fail("Test device not found")
-        self.assertLess(l_ver(old_version), l_ver(new_version))
+        self.assertLess(Version(old_version), Version(new_version))
 
     @unittest.skipUnless(device_connected_usbvm(), REQUIRED_DEV)
     def test_downgrade_firmware_usbvm(self):
@@ -533,7 +528,7 @@ class TestQubesFwupdmgr(unittest.TestCase):
             raw = usbvm_device_info.read()
             downgrades = self.q._parse_downgrades(raw)
         new_version = downgrades[number]["Version"]
-        self.assertGreater(l_ver(old_version), l_ver(new_version))
+        self.assertGreater(Version(old_version), Version(new_version))
 
     def test_parse_downgrades(self):
         downgrades = self.q._parse_downgrades(GET_DEVICES)
@@ -622,7 +617,7 @@ class TestQubesFwupdmgr(unittest.TestCase):
                 break
         if new_version is None:
             self.fail("Test device not found")
-        self.assertLess(l_ver(old_version), l_ver(new_version))
+        self.assertLess(Version(old_version), Version(new_version))
 
     @unittest.skipUnless(device_connected_usbvm(), REQUIRED_DEV)
     def test_update_firmware_usbvm(self):
@@ -657,7 +652,7 @@ class TestQubesFwupdmgr(unittest.TestCase):
                 break
         if new_version is None:
             self.fail("Test device not found")
-        self.assertLess(l_ver(old_version), l_ver(new_version))
+        self.assertLess(Version(old_version), Version(new_version))
 
     @unittest.skipUnless(check_usbvm(), REQUIRED_USBVM)
     def test_get_usbvm_devices(self):
@@ -825,8 +820,11 @@ class TestQubesFwupdmgr(unittest.TestCase):
 
     @unittest.skipUnless(check_usbvm(), REQUIRED_USBVM)
     def test_validate_usbvm_archive(self):
-        url = "https://fwupd.org/downloads/0a29848de74d26348bc5a6e24fc9f03778eddf0e-hughski-colorhug2-2.0.7.cab"
-        sha = "32c4a2c9be787cdf1d757c489d6455bd7bb14053425180b6d331c37e1ccc1cda"
+        url = (
+            "https://fwupd.org/downloads/e5ad222bdbd3d3d48d8613e67c7e0a0e1"
+            "94f8cd828e33c554d9f05d933e482c7-hughski-colorhug2-2.0.7.cab"
+        )
+        sha = "e5ad222bdbd3d3d48d8613e67c7e0a0e194f8cd828e33c554d9f05d933e482c7"
         name = url.replace("https://fwupd.org/downloads/", "")
         self.q._clean_usbvm()
         self.q._validate_usbvm_dirs()
