@@ -362,6 +362,14 @@ G_BEGIN_DECLS
  * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
  **/
 #define FWUPD_RESULT_KEY_TRUST_FLAGS "TrustFlags"
+/**
+ * FWUPD_RESULT_KEY_PROBLEMS:
+ *
+ * Result key to represent problems
+ *
+ * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_PROBLEMS "Problems"
 /**
  * FWUPD_RESULT_KEY_UPDATE_MESSAGE:
  *
@@ -482,5 +490,97 @@ G_BEGIN_DECLS
  * The D-Bus type signature string is 's' i.e. a string.
  **/
 #define FWUPD_RESULT_KEY_VERSION "Version"
+/**
+ * FWUPD_RESULT_KEY_BATTERY_LEVEL:
+ *
+ * Result key to represent the current battery level in percent.
+ * Expressed from 0-100%, or 101 for invalid or unset.
+ *
+ * The D-Bus type signature string is 'u' i.e. a unsigned 32 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_BATTERY_LEVEL "BatteryLevel"
+/**
+ * FWUPD_RESULT_KEY_BATTERY_THRESHOLD:
+ *
+ * Result key to represent the minimum battery level required to perform an update.
+ * Expressed from 0-100%, or 101 for invalid or unset.
+ *
+ * The D-Bus type signature string is 'u' i.e. a unsigned 32 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_BATTERY_THRESHOLD "BatteryThreshold"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_ID:
+ *
+ * Result key to represent the unique identifier of the BIOS setting.
+ *
+ * The D-Bus type signature string is 's' i.e. a string.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_ID "BiosSettingId"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE:
+ *
+ * Result key to represent the value that would enable this attribute.
+ *
+ * The D-Bus type signature string is 's' i.e. a string.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE "BiosSettingTargetValue"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE:
+ *
+ * Result key to represent the current value of BIOS setting.
+ *
+ * The D-Bus type signature string is 's' i.e. a string.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE "BiosSettingCurrentValue"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_TYPE:
+ *
+ * Result key to represent the type of BIOS setting.
+ * 0 is invalid, 1+ represent an attribute type
+ *
+ * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_TYPE "BiosSettingType"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_POSSIBLE_VALUES:
+ *
+ * Result key to represent possible values
+ *
+ * The D-Bus type signature string is 'as' i.e. an array of strings.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_POSSIBLE_VALUES "BiosSettingPossibleValues"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_LOWER_BOUND:
+ *
+ * Result key to represent the upper bound for an integer BIOS setting.
+ * or minimum length for string BIOS setting.
+ * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_LOWER_BOUND "BiosSettingLowerBound"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_UPPER_BOUND:
+ *
+ * Result key to represent the lower bound for an integer BIOS setting
+ * or maximum length for string BIOS setting.
+ *
+ * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_UPPER_BOUND "BiosSettingUpperBound"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_SCALAR_INCREMENT:
+ *
+ * Result key to represent the scalar increment for an integer BIOS setting.
+ *
+ * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_SCALAR_INCREMENT "BiosSettingScalarIncrement"
+/**
+ * FWUPD_RESULT_KEY_BIOS_SETTING_READ_ONLY:
+ *
+ * Result key to represent whether BIOS setting is read only
+ *
+ * The D-Bus type signature string is 'b' i.e. a boolean.
+ **/
+#define FWUPD_RESULT_KEY_BIOS_SETTING_READ_ONLY "BiosSettingReadOnly"
 
 G_END_DECLS
