@@ -7,7 +7,6 @@
 #include "config.h"
 
 #include <gio/gio.h>
-#include <glib-object.h>
 #include <string.h>
 
 #include "fwupd-common-private.h"
@@ -63,6 +62,8 @@ typedef struct {
 	gchar *update_image;
 } FwupdReleasePrivate;
 
+enum { PROP_0, PROP_REMOTE_ID, PROP_LAST };
+
 G_DEFINE_TYPE_WITH_PRIVATE(FwupdRelease, fwupd_release, G_TYPE_OBJECT)
 #define GET_PRIVATE(o) (fwupd_release_get_instance_private(o))
 
@@ -109,6 +110,7 @@ fwupd_release_set_remote_id(FwupdRelease *self, const gchar *remote_id)
 
 	g_free(priv->remote_id);
 	priv->remote_id = g_strdup(remote_id);
+	g_object_notify(G_OBJECT(self), "remote-id");
 }
 
 /**
@@ -427,7 +429,7 @@ fwupd_release_has_category(FwupdRelease *self, const gchar *category)
  * fwupd_release_get_checksums:
  * @self: a #FwupdRelease
  *
- * Gets the release checksums.
+ * Gets the release container checksums.
  *
  * Returns: (element-type utf8) (transfer none): the checksums, which may be empty
  *
@@ -444,7 +446,7 @@ fwupd_release_get_checksums(FwupdRelease *self)
 /**
  * fwupd_release_add_checksum:
  * @self: a #FwupdRelease
- * @checksum: (not nullable): the update checksum
+ * @checksum: (not nullable): the update container checksum
  *
  * Sets the update checksum.
  *
@@ -469,7 +471,7 @@ fwupd_release_add_checksum(FwupdRelease *self, const gchar *checksum)
  * @self: a #FwupdRelease
  * @checksum: (not nullable): the update checksum
  *
- * Finds out if the release has the update checksum.
+ * Finds out if the release has the update container checksum.
  *
  * Returns: %TRUE if the release matches
  *
@@ -1940,33 +1942,6 @@ fwupd_release_from_key_value(FwupdRelease *self, const gchar *key, GVariant *val
 	}
 }
 
-static void
-fwupd_pad_kv_str(GString *str, const gchar *key, const gchar *value)
-{
-	/* ignore */
-	if (key == NULL || value == NULL)
-		return;
-	g_string_append_printf(str, "  %s: ", key);
-	for (gsize i = strlen(key); i < 20; i++)
-		g_string_append(str, " ");
-	g_string_append_printf(str, "%s\n", value);
-}
-
-static void
-fwupd_pad_kv_unx(GString *str, const gchar *key, guint64 value)
-{
-	g_autoptr(GDateTime) date = NULL;
-	g_autofree gchar *tmp = NULL;
-
-	/* ignore */
-	if (value == 0)
-		return;
-
-	date = g_date_time_new_from_unix_utc((gint64)value);
-	tmp = g_date_time_format(date, "%F");
-	fwupd_pad_kv_str(str, key, tmp);
-}
-
 static void
 fwupd_pad_kv_siz(GString *str, const gchar *key, guint64 value)
 {
@@ -1996,18 +1971,6 @@ fwupd_pad_kv_tfl(GString *str, const gchar *key, FwupdReleaseFlags release_flags
 	fwupd_pad_kv_str(str, key, tmp->str);
 }
 
-static void
-fwupd_pad_kv_int(GString *str, const gchar *key, guint32 value)
-{
-	g_autofree gchar *tmp = NULL;
-
-	/* ignore */
-	if (value == 0)
-		return;
-	tmp = g_strdup_printf("%" G_GUINT32_FORMAT, value);
-	fwupd_pad_kv_str(str, key, tmp);
-}
-
 /**
  * fwupd_release_to_json:
  * @self: a #FwupdRelease
@@ -2213,11 +2176,59 @@ fwupd_release_to_string(FwupdRelease *self)
 	return g_string_free(str, FALSE);
 }
 
+static void
+fwupd_release_get_property(GObject *obj, guint prop_id, GValue *value, GParamSpec *pspec)
+{
+	FwupdRelease *self = FWUPD_RELEASE(obj);
+	FwupdReleasePrivate *priv = GET_PRIVATE(self);
+
+	switch (prop_id) {
+	case PROP_REMOTE_ID:
+		g_value_set_string(value, priv->remote_id);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+fwupd_release_set_property(GObject *obj, guint prop_id, const GValue *value, GParamSpec *pspec)
+{
+	FwupdRelease *self = FWUPD_RELEASE(obj);
+
+	switch (prop_id) {
+	case PROP_REMOTE_ID:
+		fwupd_release_set_remote_id(self, g_value_get_string(value));
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, prop_id, pspec);
+		break;
+	}
+}
+
 static void
 fwupd_release_class_init(FwupdReleaseClass *klass)
 {
+	GParamSpec *pspec;
 	GObjectClass *object_class = G_OBJECT_CLASS(klass);
 	object_class->finalize = fwupd_release_finalize;
+	object_class->get_property = fwupd_release_get_property;
+	object_class->set_property = fwupd_release_set_property;
+
+	/**
+	 * FwupdRelease:remote-id:
+	 *
+	 * The remote ID.
+	 *
+	 * Since: 1.8.0
+	 */
+	pspec = g_param_spec_string("remote-id",
+				    NULL,
+				    NULL,
+				    NULL,
+				    G_PARAM_READWRITE | G_PARAM_STATIC_NAME);
+	g_object_class_install_property(object_class, PROP_REMOTE_ID, pspec);
 }
 
 static void
