@@ -29,6 +29,8 @@ typedef struct {
 	GPtrArray *guids;
 	GHashTable *metadata; /* (nullable) */
 	gchar *name;
+	gchar *title;
+	gchar *description;
 	gchar *plugin;
 	gchar *url;
 	guint64 created;
@@ -36,6 +38,9 @@ typedef struct {
 	FwupdSecurityAttrResult result;
 	FwupdSecurityAttrResult result_fallback;
 	FwupdSecurityAttrFlags flags;
+	gchar *bios_setting_id;
+	gchar *bios_setting_target_value;
+	gchar *bios_setting_current_value;
 } FwupdSecurityAttrPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE(FwupdSecurityAttr, fwupd_security_attr, G_TYPE_OBJECT)
@@ -60,12 +65,20 @@ fwupd_security_attr_flag_to_string(FwupdSecurityAttrFlags flag)
 		return "success";
 	if (flag == FWUPD_SECURITY_ATTR_FLAG_OBSOLETED)
 		return "obsoleted";
+	if (flag == FWUPD_SECURITY_ATTR_FLAG_MISSING_DATA)
+		return "missing-data";
 	if (flag == FWUPD_SECURITY_ATTR_FLAG_RUNTIME_UPDATES)
 		return "runtime-updates";
 	if (flag == FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ATTESTATION)
 		return "runtime-attestation";
 	if (flag == FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ISSUE)
 		return "runtime-issue";
+	if (flag == FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM)
+		return "action-contact-oem";
+	if (flag == FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW)
+		return "action-config-fw";
+	if (flag == FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS)
+		return "action-config-os";
 	return NULL;
 }
 
@@ -86,12 +99,20 @@ fwupd_security_attr_flag_from_string(const gchar *flag)
 		return FWUPD_SECURITY_ATTR_FLAG_SUCCESS;
 	if (g_strcmp0(flag, "obsoleted") == 0)
 		return FWUPD_SECURITY_ATTR_FLAG_OBSOLETED;
+	if (g_strcmp0(flag, "missing-data") == 0)
+		return FWUPD_SECURITY_ATTR_FLAG_MISSING_DATA;
 	if (g_strcmp0(flag, "runtime-updates") == 0)
 		return FWUPD_SECURITY_ATTR_FLAG_RUNTIME_UPDATES;
 	if (g_strcmp0(flag, "runtime-attestation") == 0)
 		return FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ATTESTATION;
 	if (g_strcmp0(flag, "runtime-issue") == 0)
 		return FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ISSUE;
+	if (g_strcmp0(flag, "action-contact-oem") == 0)
+		return FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM;
+	if (g_strcmp0(flag, "action-config-fw") == 0)
+		return FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW;
+	if (g_strcmp0(flag, "action-config-os") == 0)
+		return FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS;
 	return FWUPD_SECURITY_ATTR_FLAG_NONE;
 }
 
@@ -205,6 +226,46 @@ fwupd_security_attr_flag_to_suffix(FwupdSecurityAttrFlags flag)
 	return NULL;
 }
 
+/**
+ * fwupd_security_attr_get_bios_setting_id:
+ * @self: a #FwupdSecurityAttr
+ *
+ * Gets the #FwupdBiosSetting that can be used to improve this
+ * #FwupdSecurityAttr.
+ *
+ * Returns: The unique ID used for #FwupdBiosSetting or NULL
+ *
+ * Since: 1.8.4
+ **/
+const gchar *
+fwupd_security_attr_get_bios_setting_id(FwupdSecurityAttr *self)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FWUPD_IS_SECURITY_ATTR(self), NULL);
+	return priv->bios_setting_id;
+}
+
+/**
+ * fwupd_security_attr_set_bios_setting_id:
+ * @self: a #FwupdSecurityAttr
+ * @id: Unique identifier used for #FwupdBiosSetting
+ *
+ * Sets the #FwupdBiosSetting that can be used to improve this
+ * #FwupdSecurityAttr.
+ *
+ * Since: 1.8.4
+ **/
+void
+fwupd_security_attr_set_bios_setting_id(FwupdSecurityAttr *self, const gchar *id)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FWUPD_IS_SECURITY_ATTR(self));
+	if (priv->bios_setting_id == id)
+		return;
+	g_free(priv->bios_setting_id);
+	priv->bios_setting_id = g_strdup(id);
+}
+
 /**
  * fwupd_security_attr_get_obsoletes:
  * @self: a #FwupdSecurityAttr
@@ -441,6 +502,133 @@ fwupd_security_attr_set_name(FwupdSecurityAttr *self, const gchar *name)
 	priv->name = g_strdup(name);
 }
 
+/**
+ * fwupd_security_attr_get_bios_setting_target_value:
+ * @self: a #FwupdSecurityAttr
+ *
+ * Gets the value that when written to an attribute would activate it or satisfy
+ * a security requirement.
+ *
+ * Returns: the target value of the attribute.
+ *
+ * Since: 1.8.4
+ **/
+const gchar *
+fwupd_security_attr_get_bios_setting_target_value(FwupdSecurityAttr *self)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FWUPD_IS_SECURITY_ATTR(self), NULL);
+	return priv->bios_setting_target_value;
+}
+
+/**
+ * fwupd_security_attr_set_bios_setting_target_value:
+ * @self: a #FwupdSecurityAttr
+ * @value: The string to set target value to
+ *
+ * Sets the string used for the target value of an attribute.
+ *
+ * Since: 1.8.4
+ **/
+void
+fwupd_security_attr_set_bios_setting_target_value(FwupdSecurityAttr *self, const gchar *value)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+
+	/* not changed */
+	if (g_strcmp0(priv->bios_setting_target_value, value) == 0)
+		return;
+
+	g_free(priv->bios_setting_target_value);
+	priv->bios_setting_target_value = g_strdup(value);
+}
+
+/**
+ * fwupd_security_attr_get_bios_setting_current_value:
+ * @self: a #FwupdSecurityAttr
+ *
+ * Gets the current value of the BIOS setting that can be changed.
+ *
+ * Returns: the current value of the attribute.
+ *
+ * Since: 1.8.4
+ **/
+const gchar *
+fwupd_security_attr_get_bios_setting_current_value(FwupdSecurityAttr *self)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FWUPD_IS_SECURITY_ATTR(self), NULL);
+	return priv->bios_setting_current_value;
+}
+
+/**
+ * fwupd_security_attr_set_bios_setting_current_value:
+ * @self: a #FwupdSecurityAttr
+ * @value: The string to set current value to
+ *
+ * Sets the current value of the BIOS setting that can be changed.
+ *
+ * Since: 1.8.4
+ **/
+void
+fwupd_security_attr_set_bios_setting_current_value(FwupdSecurityAttr *self, const gchar *value)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+
+	/* not changed */
+	if (g_strcmp0(priv->bios_setting_current_value, value) == 0)
+		return;
+
+	g_free(priv->bios_setting_current_value);
+	priv->bios_setting_current_value = g_strdup(value);
+}
+
+/**
+ * fwupd_security_attr_set_title:
+ * @self: a #FwupdSecurityAttr
+ * @title: (nullable): the attribute title
+ *
+ * Sets the attribute title.
+ *
+ * Since: 1.8.2
+ **/
+void
+fwupd_security_attr_set_title(FwupdSecurityAttr *self, const gchar *title)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FWUPD_IS_SECURITY_ATTR(self));
+
+	/* not changed */
+	if (g_strcmp0(priv->title, title) == 0)
+		return;
+
+	g_free(priv->title);
+	priv->title = g_strdup(title);
+}
+
+/**
+ * fwupd_security_attr_set_description:
+ * @self: a #FwupdSecurityAttr
+ * @description: (nullable): the attribute description
+ *
+ * Sets the attribute description.
+ *
+ * Since: 1.8.2
+ **/
+void
+fwupd_security_attr_set_description(FwupdSecurityAttr *self, const gchar *description)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FWUPD_IS_SECURITY_ATTR(self));
+
+	/* not changed */
+	if (g_strcmp0(priv->description, description) == 0)
+		return;
+
+	g_free(priv->description);
+	priv->description = g_strdup(description);
+}
+
 /**
  * fwupd_security_attr_set_plugin:
  * @self: a #FwupdSecurityAttr
@@ -539,6 +727,52 @@ fwupd_security_attr_get_name(FwupdSecurityAttr *self)
 	return priv->name;
 }
 
+/**
+ * fwupd_security_attr_get_title:
+ * @self: a #FwupdSecurityAttr
+ *
+ * Gets the attribute title, which is typically a two word title.
+ *
+ * The fwupd client program may be able to get translations for this value using a method call
+ * like `dgettext("fwupd",str)`.
+ *
+ * Returns: the attribute title, or %NULL if unset
+ *
+ * Since: 1.8.2
+ **/
+const gchar *
+fwupd_security_attr_get_title(FwupdSecurityAttr *self)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FWUPD_IS_SECURITY_ATTR(self), NULL);
+	return priv->title;
+}
+
+/**
+ * fwupd_security_attr_get_description:
+ * @self: a #FwupdSecurityAttr
+ *
+ * Gets the attribute description which is a few lines of prose that normal users will understand.
+ *
+ * The fwupd client program may be able to get translations for this value using a method call
+ * like `dgettext("fwupd",str)`.
+ *
+ * NOTE: The returned string may contain placeholders such as `$HostVendor$` or `$HostProduct$`
+ * and these should be replaced with the values from [method@FwupdClient.get_host_vendor] and
+ * [method@FwupdClient.get_host_product].
+ *
+ * Returns: the attribute description, or %NULL if unset
+ *
+ * Since: 1.8.2
+ **/
+const gchar *
+fwupd_security_attr_get_description(FwupdSecurityAttr *self)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FWUPD_IS_SECURITY_ATTR(self), NULL);
+	return priv->description;
+}
+
 /**
  * fwupd_security_attr_get_plugin:
  * @self: a #FwupdSecurityAttr
@@ -609,6 +843,23 @@ fwupd_security_attr_add_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags fla
 	priv->flags |= flag;
 }
 
+/**
+ * fwupd_security_attr_remove_flag:
+ * @self: a #FwupdSecurityAttr
+ * @flag: the #FwupdSecurityAttrFlags, e.g. %FWUPD_SECURITY_ATTR_FLAG_OBSOLETED
+ *
+ * Removes a specific attribute flag from the attribute.
+ *
+ * Since: 1.8.3
+ **/
+void
+fwupd_security_attr_remove_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag)
+{
+	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FWUPD_IS_SECURITY_ATTR(self));
+	priv->flags &= ~flag;
+}
+
 /**
  * fwupd_security_attr_has_flag:
  * @self: a #FwupdSecurityAttr
@@ -679,6 +930,13 @@ fwupd_security_attr_set_result(FwupdSecurityAttr *self, FwupdSecurityAttrResult
 {
 	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
 	g_return_if_fail(FWUPD_IS_SECURITY_ATTR(self));
+
+	/* fixup any legacy attributes to the 'modern' value */
+	if (g_strcmp0(priv->appstream_id, FWUPD_SECURITY_ATTR_ID_ENCRYPTED_RAM) == 0 &&
+	    result == FWUPD_SECURITY_ATTR_RESULT_NOT_ENCRYPTED) {
+		result = FWUPD_SECURITY_ATTR_RESULT_NOT_SUPPORTED;
+	}
+
 	priv->result = result;
 }
 
@@ -773,6 +1031,18 @@ fwupd_security_attr_to_variant(FwupdSecurityAttr *self)
 				      FWUPD_RESULT_KEY_NAME,
 				      g_variant_new_string(priv->name));
 	}
+	if (priv->title != NULL) {
+		g_variant_builder_add(&builder,
+				      "{sv}",
+				      FWUPD_RESULT_KEY_SUMMARY,
+				      g_variant_new_string(priv->title));
+	}
+	if (priv->description != NULL) {
+		g_variant_builder_add(&builder,
+				      "{sv}",
+				      FWUPD_RESULT_KEY_DESCRIPTION,
+				      g_variant_new_string(priv->description));
+	}
 	if (priv->plugin != NULL) {
 		g_variant_builder_add(&builder,
 				      "{sv}",
@@ -833,6 +1103,24 @@ fwupd_security_attr_to_variant(FwupdSecurityAttr *self)
 				      FWUPD_RESULT_KEY_METADATA,
 				      fwupd_hash_kv_to_variant(priv->metadata));
 	}
+	if (priv->bios_setting_id != NULL) {
+		g_variant_builder_add(&builder,
+				      "{sv}",
+				      FWUPD_RESULT_KEY_BIOS_SETTING_ID,
+				      g_variant_new_string(priv->bios_setting_id));
+	}
+	if (priv->bios_setting_target_value != NULL) {
+		g_variant_builder_add(&builder,
+				      "{sv}",
+				      FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE,
+				      g_variant_new_string(priv->bios_setting_target_value));
+	}
+	if (priv->bios_setting_current_value != NULL) {
+		g_variant_builder_add(&builder,
+				      "{sv}",
+				      FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE,
+				      g_variant_new_string(priv->bios_setting_current_value));
+	}
 	return g_variant_new("a{sv}", &builder);
 }
 
@@ -901,6 +1189,14 @@ fwupd_security_attr_from_key_value(FwupdSecurityAttr *self, const gchar *key, GV
 		fwupd_security_attr_set_name(self, g_variant_get_string(value, NULL));
 		return;
 	}
+	if (g_strcmp0(key, FWUPD_RESULT_KEY_SUMMARY) == 0) {
+		fwupd_security_attr_set_title(self, g_variant_get_string(value, NULL));
+		return;
+	}
+	if (g_strcmp0(key, FWUPD_RESULT_KEY_DESCRIPTION) == 0) {
+		fwupd_security_attr_set_description(self, g_variant_get_string(value, NULL));
+		return;
+	}
 	if (g_strcmp0(key, FWUPD_RESULT_KEY_PLUGIN) == 0) {
 		fwupd_security_attr_set_plugin(self, g_variant_get_string(value, NULL));
 		return;
@@ -937,18 +1233,22 @@ fwupd_security_attr_from_key_value(FwupdSecurityAttr *self, const gchar *key, GV
 		priv->metadata = fwupd_variant_to_hash_kv(value);
 		return;
 	}
-}
-
-static void
-fwupd_pad_kv_str(GString *str, const gchar *key, const gchar *value)
-{
-	/* ignore */
-	if (key == NULL || value == NULL)
+	if (g_strcmp0(key, FWUPD_RESULT_KEY_BIOS_SETTING_ID) == 0) {
+		fwupd_security_attr_set_bios_setting_id(self, g_variant_get_string(value, NULL));
 		return;
-	g_string_append_printf(str, "  %s: ", key);
-	for (gsize i = strlen(key); i < 20; i++)
-		g_string_append(str, " ");
-	g_string_append_printf(str, "%s\n", value);
+	}
+	if (g_strcmp0(key, FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE) == 0) {
+		fwupd_security_attr_set_bios_setting_target_value(
+		    self,
+		    g_variant_get_string(value, NULL));
+		return;
+	}
+	if (g_strcmp0(key, FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE) == 0) {
+		fwupd_security_attr_set_bios_setting_current_value(
+		    self,
+		    g_variant_get_string(value, NULL));
+		return;
+	}
 }
 
 static void
@@ -970,18 +1270,6 @@ fwupd_pad_kv_tfl(GString *str, const gchar *key, FwupdSecurityAttrFlags security
 	fwupd_pad_kv_str(str, key, tmp->str);
 }
 
-static void
-fwupd_pad_kv_int(GString *str, const gchar *key, guint32 value)
-{
-	g_autofree gchar *tmp = NULL;
-
-	/* ignore */
-	if (value == 0)
-		return;
-	tmp = g_strdup_printf("%" G_GUINT32_FORMAT, value);
-	fwupd_pad_kv_str(str, key, tmp);
-}
-
 /**
  * fwupd_security_attr_from_json:
  * @self: a #FwupdSecurityAttr
@@ -1024,6 +1312,12 @@ fwupd_security_attr_from_json(FwupdSecurityAttr *self, JsonNode *json_node, GErr
 	fwupd_security_attr_set_name(
 	    self,
 	    json_object_get_string_member_with_default(obj, FWUPD_RESULT_KEY_NAME, NULL));
+	fwupd_security_attr_set_title(
+	    self,
+	    json_object_get_string_member_with_default(obj, FWUPD_RESULT_KEY_SUMMARY, NULL));
+	fwupd_security_attr_set_description(
+	    self,
+	    json_object_get_string_member_with_default(obj, FWUPD_RESULT_KEY_DESCRIPTION, NULL));
 	fwupd_security_attr_set_plugin(
 	    self,
 	    json_object_get_string_member_with_default(obj, FWUPD_RESULT_KEY_PLUGIN, NULL));
@@ -1036,6 +1330,21 @@ fwupd_security_attr_from_json(FwupdSecurityAttr *self, JsonNode *json_node, GErr
 	fwupd_security_attr_set_created(
 	    self,
 	    json_object_get_int_member_with_default(obj, FWUPD_RESULT_KEY_CREATED, 0));
+	fwupd_security_attr_set_bios_setting_id(
+	    self,
+	    json_object_get_string_member_with_default(obj,
+						       FWUPD_RESULT_KEY_BIOS_SETTING_ID,
+						       NULL));
+	fwupd_security_attr_set_bios_setting_target_value(
+	    self,
+	    json_object_get_string_member_with_default(obj,
+						       FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE,
+						       NULL));
+	fwupd_security_attr_set_bios_setting_current_value(
+	    self,
+	    json_object_get_string_member_with_default(obj,
+						       FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE,
+						       NULL));
 
 	/* also optional */
 	if (json_object_has_member(obj, FWUPD_RESULT_KEY_HSI_RESULT)) {
@@ -1110,8 +1419,20 @@ fwupd_security_attr_to_json(FwupdSecurityAttr *self, JsonBuilder *builder)
 				     FWUPD_RESULT_KEY_HSI_RESULT_FALLBACK,
 				     fwupd_security_attr_result_to_string(priv->result_fallback));
 	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_NAME, priv->name);
+	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_SUMMARY, priv->title);
+	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_DESCRIPTION, priv->description);
 	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_PLUGIN, priv->plugin);
 	fwupd_common_json_add_string(builder, FWUPD_RESULT_KEY_URI, priv->url);
+	fwupd_common_json_add_string(builder,
+				     FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE,
+				     priv->bios_setting_target_value);
+	fwupd_common_json_add_string(builder,
+				     FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE,
+				     priv->bios_setting_current_value);
+	fwupd_common_json_add_string(builder,
+				     FWUPD_RESULT_KEY_BIOS_SETTING_ID,
+				     priv->bios_setting_id);
+
 	if (priv->flags != FWUPD_SECURITY_ATTR_FLAG_NONE) {
 		json_builder_set_member_name(builder, FWUPD_RESULT_KEY_FLAGS);
 		json_builder_begin_array(builder);
@@ -1143,21 +1464,6 @@ fwupd_security_attr_to_json(FwupdSecurityAttr *self, JsonBuilder *builder)
 	}
 }
 
-static void
-fwupd_pad_kv_unx(GString *str, const gchar *key, guint64 value)
-{
-	g_autoptr(GDateTime) date = NULL;
-	g_autofree gchar *tmp = NULL;
-
-	/* ignore */
-	if (value == 0)
-		return;
-
-	date = g_date_time_new_from_unix_utc((gint64)value);
-	tmp = g_date_time_format(date, "%F");
-	fwupd_pad_kv_str(str, key, tmp);
-}
-
 /**
  * fwupd_security_attr_to_string:
  * @self: a #FwupdSecurityAttr
@@ -1190,8 +1496,18 @@ fwupd_security_attr_to_string(FwupdSecurityAttr *self)
 	if (priv->flags != FWUPD_SECURITY_ATTR_FLAG_NONE)
 		fwupd_pad_kv_tfl(str, FWUPD_RESULT_KEY_FLAGS, priv->flags);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_NAME, priv->name);
+	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_SUMMARY, priv->title);
+	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_DESCRIPTION, priv->description);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_PLUGIN, priv->plugin);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_URI, priv->url);
+	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_BIOS_SETTING_ID, priv->bios_setting_id);
+	fwupd_pad_kv_str(str,
+			 FWUPD_RESULT_KEY_BIOS_SETTING_TARGET_VALUE,
+			 priv->bios_setting_target_value);
+	fwupd_pad_kv_str(str,
+			 FWUPD_RESULT_KEY_BIOS_SETTING_CURRENT_VALUE,
+			 priv->bios_setting_current_value);
+
 	for (guint i = 0; i < priv->obsoletes->len; i++) {
 		const gchar *appstream_id = g_ptr_array_index(priv->obsoletes, i);
 		fwupd_pad_kv_str(str, "Obsolete", appstream_id);
@@ -1223,6 +1539,7 @@ static void
 fwupd_security_attr_init(FwupdSecurityAttr *self)
 {
 	FwupdSecurityAttrPrivate *priv = GET_PRIVATE(self);
+	priv->level = FWUPD_SECURITY_ATTR_LEVEL_NONE;
 	priv->obsoletes = g_ptr_array_new_with_free_func(g_free);
 	priv->guids = g_ptr_array_new_with_free_func(g_free);
 	priv->created = (guint64)g_get_real_time() / G_USEC_PER_SEC;
@@ -1236,8 +1553,13 @@ fwupd_security_attr_finalize(GObject *object)
 
 	if (priv->metadata != NULL)
 		g_hash_table_unref(priv->metadata);
+	g_free(priv->bios_setting_id);
+	g_free(priv->bios_setting_target_value);
+	g_free(priv->bios_setting_current_value);
 	g_free(priv->appstream_id);
 	g_free(priv->name);
+	g_free(priv->title);
+	g_free(priv->description);
 	g_free(priv->plugin);
 	g_free(priv->url);
 	g_ptr_array_unref(priv->obsoletes);
@@ -1344,12 +1666,16 @@ fwupd_security_attr_copy(FwupdSecurityAttr *self)
 
 	fwupd_security_attr_set_appstream_id(new, priv->appstream_id);
 	fwupd_security_attr_set_name(new, priv->name);
+	fwupd_security_attr_set_title(new, priv->title);
+	fwupd_security_attr_set_description(new, priv->description);
 	fwupd_security_attr_set_plugin(new, priv->plugin);
 	fwupd_security_attr_set_url(new, priv->url);
 	fwupd_security_attr_set_level(new, priv->level);
 	fwupd_security_attr_set_flags(new, priv->flags);
 	fwupd_security_attr_set_result(new, priv->result);
 	fwupd_security_attr_set_created(new, priv->created);
+	fwupd_security_attr_set_bios_setting_id(new, priv->bios_setting_id);
+
 	for (guint i = 0; i < priv->guids->len; i++) {
 		const gchar *guid = g_ptr_array_index(priv->guids, i);
 		fwupd_security_attr_add_guid(new, guid);
@@ -1377,6 +1703,9 @@ fwupd_security_attr_copy(FwupdSecurityAttr *self)
  *
  * Creates a new security attribute.
  *
+ * Plugins should not use this method, and should instead use `fu_plugin_security_attr_new()` or
+ * `fu_security_attr_new()`.
+ *
  * Returns: a new #FwupdSecurityAttr
  *
  * Since: 1.5.0
