@@ -15,11 +15,17 @@ G_DECLARE_DERIVABLE_TYPE(FuBackend, fu_backend, FU, BACKEND, GObject)
 struct _FuBackendClass {
 	GObjectClass parent_class;
 	/* signals */
-	gboolean (*setup)(FuBackend *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
-	gboolean (*coldplug)(FuBackend *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+	gboolean (*setup)(FuBackend *self,
+			  FuProgress *progress,
+			  GError **error) G_GNUC_WARN_UNUSED_RESULT;
+	gboolean (*coldplug)(FuBackend *self,
+			     FuProgress *progress,
+			     GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	void (*registered)(FuBackend *self, FuDevice *device);
+	void (*invalidate)(FuBackend *self);
+	void (*to_string)(FuBackend *self, guint indent, GString *str);
 	/*< private >*/
-	gpointer padding[28];
+	gpointer padding[26];
 };
 
 const gchar *
@@ -35,9 +41,11 @@ fu_backend_get_devices(FuBackend *self);
 FuDevice *
 fu_backend_lookup_by_id(FuBackend *self, const gchar *device_id);
 gboolean
-fu_backend_setup(FuBackend *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_backend_setup(FuBackend *self, FuProgress *progress, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 gboolean
-fu_backend_coldplug(FuBackend *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_backend_coldplug(FuBackend *self,
+		    FuProgress *progress,
+		    GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
 fu_backend_device_added(FuBackend *self, FuDevice *device);
 void
@@ -46,3 +54,7 @@ void
 fu_backend_device_changed(FuBackend *self, FuDevice *device);
 void
 fu_backend_registered(FuBackend *self, FuDevice *device);
+void
+fu_backend_invalidate(FuBackend *self);
+void
+fu_backend_add_string(FuBackend *self, guint idt, GString *str);
