@@ -14,6 +14,7 @@
 #include "fu-common.h"
 #include "fu-device-private.h"
 #include "fu-firmware-common.h"
+#include "fu-string.h"
 
 #define DEFAULT_PROXY_TIMEOUT 5000
 
@@ -171,24 +172,19 @@ fu_bluez_device_set_modalias(FuBluezDevice *self, const gchar *modalias)
 		fu_firmware_strparse_uint16_safe(modalias, modaliaslen, 21, &rev, NULL);
 	}
 
-	if (vid != 0x0 && pid != 0x0 && rev != 0x0) {
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("BLUETOOTH\\VID_%04X&PID_%04X&REV_%04X", vid, pid, rev);
-		fu_device_add_instance_id(FU_DEVICE(self), devid);
-	}
-	if (vid != 0x0 && pid != 0x0) {
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("BLUETOOTH\\VID_%04X&PID_%04X", vid, pid);
-		fu_device_add_instance_id(FU_DEVICE(self), devid);
-	}
+	/* add generated IDs */
+	if (vid != 0x0)
+		fu_device_add_instance_u16(FU_DEVICE(self), "VID", vid);
+	if (pid != 0x0)
+		fu_device_add_instance_u16(FU_DEVICE(self), "PID", pid);
+	fu_device_add_instance_u16(FU_DEVICE(self), "REV", rev);
+	fu_device_build_instance_id_quirk(FU_DEVICE(self), NULL, "BLUETOOTH", "VID", NULL);
+	fu_device_build_instance_id(FU_DEVICE(self), NULL, "BLUETOOTH", "VID", "PID", NULL);
+	fu_device_build_instance_id(FU_DEVICE(self), NULL, "BLUETOOTH", "VID", "PID", "REV", NULL);
+
+	/* set vendor ID */
 	if (vid != 0x0) {
-		g_autofree gchar *devid = NULL;
-		g_autofree gchar *vendor_id = NULL;
-		devid = g_strdup_printf("BLUETOOTH\\VID_%04X", vid);
-		fu_device_add_instance_id_full(FU_DEVICE(self),
-					       devid,
-					       FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
-		vendor_id = g_strdup_printf("BLUETOOTH:%04X", vid);
+		g_autofree gchar *vendor_id = g_strdup_printf("BLUETOOTH:%04X", vid);
 		fu_device_add_vendor_id(FU_DEVICE(self), vendor_id);
 	}
 
@@ -196,7 +192,7 @@ fu_bluez_device_set_modalias(FuBluezDevice *self, const gchar *modalias)
 	if (rev != 0x0 &&
 	    fu_device_get_version_format(FU_DEVICE(self)) == FWUPD_VERSION_FORMAT_UNKNOWN) {
 		g_autofree gchar *version = NULL;
-		version = fu_common_version_from_uint16(rev, FWUPD_VERSION_FORMAT_BCD);
+		version = fu_version_from_uint16(rev, FWUPD_VERSION_FORMAT_BCD);
 		fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_BCD);
 		fu_device_set_version(FU_DEVICE(self), version);
 	}
@@ -214,10 +210,7 @@ fu_bluez_device_to_string(FuDevice *device, guint idt, GString *str)
 		g_hash_table_iter_init(&iter, priv->uuids);
 		while (g_hash_table_iter_next(&iter, &key, &value)) {
 			FuBluezDeviceUuidHelper *uuid_helper = (FuBluezDeviceUuidHelper *)value;
-			fu_common_string_append_kv(str,
-						   idt + 1,
-						   (const gchar *)key,
-						   uuid_helper->path);
+			fu_string_append(str, idt + 1, (const gchar *)key, uuid_helper->path);
 		}
 	}
 }
