@@ -15,8 +15,6 @@
 
 GPtrArray *
 fu_common_get_block_devices(GError **error);
-gboolean
-fu_common_fnmatch_impl(const gchar *pattern, const gchar *str);
 guint64
 fu_common_get_memory_size_impl(void);
 
