@@ -8,6 +8,7 @@
 
 #include "config.h"
 
+#include "fu-bios-settings-private.h"
 #include "fu-context-private.h"
 #include "fu-hwids.h"
 #include "fu-smbios-private.h"
@@ -32,6 +33,7 @@ typedef struct {
 	FuLidState lid_state;
 	guint battery_level;
 	guint battery_threshold;
+	FuBiosSettings *host_bios_settings;
 } FuContextPrivate;
 
 enum { SIGNAL_SECURITY_CHANGED, SIGNAL_LAST };
@@ -116,6 +118,81 @@ fu_context_get_smbios_integer(FuContext *self, guint8 type, guint8 offset)
 	return fu_smbios_get_integer(priv->smbios, type, offset, NULL);
 }
 
+/**
+ * fu_context_reload_bios_settings:
+ * @self: a #FuContext
+ * @error: (nullable): optional return location for an error
+ *
+ * Refreshes the list of firmware attributes on the system.
+ *
+ * Since: 1.8.4
+ **/
+gboolean
+fu_context_reload_bios_settings(FuContext *self, GError **error)
+{
+	FuContextPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FU_IS_CONTEXT(self), FALSE);
+	return fu_bios_settings_setup(priv->host_bios_settings, error);
+}
+
+/**
+ * fu_context_get_bios_settings:
+ * @self: a #FuContext
+ *
+ * Returns all the firmware attributes defined in the system.
+ *
+ * Returns: (transfer full): A #FuBiosSettings
+ *
+ * Since: 1.8.4
+ **/
+FuBiosSettings *
+fu_context_get_bios_settings(FuContext *self)
+{
+	FuContextPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FU_IS_CONTEXT(self), NULL);
+	return g_object_ref(priv->host_bios_settings);
+}
+
+/**
+ * fu_context_get_bios_setting:
+ * @self: a #FuContext
+ * @name: a BIOS setting title, e.g. `BootOrderLock`
+ *
+ * Finds out if a system supports a given BIOS setting.
+ *
+ * Returns: (transfer none): #FwupdBiosSetting if the attr exists.
+ *
+ * Since: 1.8.4
+ **/
+FwupdBiosSetting *
+fu_context_get_bios_setting(FuContext *self, const gchar *name)
+{
+	FuContextPrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FU_IS_CONTEXT(self), NULL);
+	g_return_val_if_fail(name != NULL, NULL);
+	return fu_bios_settings_get_attr(priv->host_bios_settings, name);
+}
+
+/**
+ * fu_context_get_bios_setting_pending_reboot:
+ * @self: a #FuContext
+ *
+ * Determine if updates to BIOS settings are pending until next boot.
+ *
+ * Returns: %TRUE if updates are pending.
+ *
+ * Since: 1.8.4
+ **/
+gboolean
+fu_context_get_bios_setting_pending_reboot(FuContext *self)
+{
+	FuContextPrivate *priv = GET_PRIVATE(self);
+	gboolean ret;
+	g_return_val_if_fail(FU_IS_CONTEXT(self), FALSE);
+	fu_bios_settings_get_pending_reboot(priv->host_bios_settings, &ret, NULL);
+	return ret;
+}
+
 /**
  * fu_context_has_hwid_guid:
  * @self: a #FuContext
@@ -537,6 +614,9 @@ fu_context_load_hwinfo(FuContext *self, GError **error)
 		}
 	}
 
+	/* set it up so that udev will load firmware attributes */
+	fu_context_add_udev_subsystem(self, "firmware-attributes");
+
 	/* always */
 	return TRUE;
 }
@@ -674,7 +754,7 @@ fu_context_set_lid_state(FuContext *self, FuLidState lid_state)
  *
  * Gets the system battery level in percent.
  *
- * Returns: percentage value, or %FU_BATTERY_VALUE_INVALID for unknown
+ * Returns: percentage value, or %FWUPD_BATTERY_LEVEL_INVALID for unknown
  *
  * Since: 1.6.0
  **/
@@ -700,7 +780,7 @@ fu_context_set_battery_level(FuContext *self, guint battery_level)
 {
 	FuContextPrivate *priv = GET_PRIVATE(self);
 	g_return_if_fail(FU_IS_CONTEXT(self));
-	g_return_if_fail(battery_level <= FU_BATTERY_VALUE_INVALID);
+	g_return_if_fail(battery_level <= FWUPD_BATTERY_LEVEL_INVALID);
 	if (priv->battery_level == battery_level)
 		return;
 	priv->battery_level = battery_level;
@@ -714,7 +794,7 @@ fu_context_set_battery_level(FuContext *self, guint battery_level)
  *
  * Gets the system battery threshold in percent.
  *
- * Returns: percentage value, or %FU_BATTERY_VALUE_INVALID for unknown
+ * Returns: percentage value, or %FWUPD_BATTERY_LEVEL_INVALID for unknown
  *
  * Since: 1.6.0
  **/
@@ -740,7 +820,7 @@ fu_context_set_battery_threshold(FuContext *self, guint battery_threshold)
 {
 	FuContextPrivate *priv = GET_PRIVATE(self);
 	g_return_if_fail(FU_IS_CONTEXT(self));
-	g_return_if_fail(battery_threshold <= FU_BATTERY_VALUE_INVALID);
+	g_return_if_fail(battery_threshold <= FWUPD_BATTERY_LEVEL_INVALID);
 	if (priv->battery_threshold == battery_threshold)
 		return;
 	priv->battery_threshold = battery_threshold;
@@ -809,6 +889,7 @@ fu_context_finalize(GObject *object)
 	g_hash_table_unref(priv->hwid_flags);
 	g_object_unref(priv->quirks);
 	g_object_unref(priv->smbios);
+	g_object_unref(priv->host_bios_settings);
 	g_hash_table_unref(priv->firmware_gtypes);
 	g_ptr_array_unref(priv->udev_subsystems);
 
@@ -867,8 +948,8 @@ fu_context_class_init(FuContextClass *klass)
 				  NULL,
 				  NULL,
 				  0,
-				  FU_BATTERY_VALUE_INVALID,
-				  FU_BATTERY_VALUE_INVALID,
+				  FWUPD_BATTERY_LEVEL_INVALID,
+				  FWUPD_BATTERY_LEVEL_INVALID,
 				  G_PARAM_READWRITE | G_PARAM_STATIC_NAME);
 	g_object_class_install_property(object_class, PROP_BATTERY_LEVEL, pspec);
 
@@ -883,8 +964,8 @@ fu_context_class_init(FuContextClass *klass)
 				  NULL,
 				  NULL,
 				  0,
-				  FU_BATTERY_VALUE_INVALID,
-				  FU_BATTERY_VALUE_INVALID,
+				  FWUPD_BATTERY_LEVEL_INVALID,
+				  FWUPD_BATTERY_LEVEL_INVALID,
 				  G_PARAM_READWRITE | G_PARAM_STATIC_NAME);
 	g_object_class_install_property(object_class, PROP_BATTERY_THRESHOLD, pspec);
 
@@ -915,14 +996,15 @@ static void
 fu_context_init(FuContext *self)
 {
 	FuContextPrivate *priv = GET_PRIVATE(self);
-	priv->battery_level = FU_BATTERY_VALUE_INVALID;
-	priv->battery_threshold = FU_BATTERY_VALUE_INVALID;
+	priv->battery_level = FWUPD_BATTERY_LEVEL_INVALID;
+	priv->battery_threshold = FWUPD_BATTERY_LEVEL_INVALID;
 	priv->smbios = fu_smbios_new();
 	priv->hwids = fu_hwids_new();
 	priv->hwid_flags = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
 	priv->udev_subsystems = g_ptr_array_new_with_free_func(g_free);
 	priv->firmware_gtypes = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
 	priv->quirks = fu_quirks_new();
+	priv->host_bios_settings = fu_bios_settings_new();
 }
 
 /**
