@@ -7,13 +7,13 @@
 #pragma once
 
 #include <fwupd.h>
-#include <glib-object.h>
 
-#include "fu-common-version.h"
 #include "fu-context.h"
+#include "fu-device-locker.h"
 #include "fu-firmware.h"
 #include "fu-progress.h"
 #include "fu-security-attrs.h"
+#include "fu-version-common.h"
 
 #define FU_TYPE_DEVICE (fu_device_get_type())
 G_DECLARE_DERIVABLE_TYPE(FuDevice, fu_device, FU, DEVICE, FwupdDevice)
@@ -56,9 +56,11 @@ struct _FuDeviceClass {
 			     GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	gboolean (*reload)(FuDevice *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	gboolean (*prepare)(FuDevice *self,
+			    FuProgress *progress,
 			    FwupdInstallFlags flags,
 			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	gboolean (*cleanup)(FuDevice *self,
+			    FuProgress *progress,
 			    FwupdInstallFlags flags,
 			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	void (*report_metadata_pre)(FuDevice *self, GHashTable *metadata);
@@ -135,9 +137,7 @@ typedef gboolean (*FuDeviceRetryFunc)(FuDevice *self,
 				      GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 FuDevice *
-fu_device_new(void);
-FuDevice *
-fu_device_new_with_context(FuContext *ctx);
+fu_device_new(FuContext *ctx);
 
 /* helpful casting macros */
 #define fu_device_has_flag(d, v)	   fwupd_device_has_flag(FWUPD_DEVICE(d), v)
@@ -447,6 +447,25 @@ typedef guint64 FuDeviceInternalFlags;
  */
 #define FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED (1ull << 23)
 
+/**
+ * FU_DEVICE_INTERNAL_AUTO_PAUSE_POLLING:
+ *
+ * Pause polling when reading or writing to the device
+ *
+ * Since: 1.8.1
+ */
+#define FU_DEVICE_INTERNAL_AUTO_PAUSE_POLLING (1ull << 24)
+
+/**
+ * FU_DEVICE_INTERNAL_FLAG_ONLY_WAIT_FOR_REPLUG:
+ *
+ * Only use the device removal delay when explicitly waiting for a replug, rather than every time
+ * the device is removed.
+ *
+ * Since: 1.8.1
+ */
+#define FU_DEVICE_INTERNAL_FLAG_ONLY_WAIT_FOR_REPLUG (1ull << 25)
+
 /* accessors */
 gchar *
 fu_device_to_string(FuDevice *self);
@@ -524,6 +543,12 @@ void
 fu_device_inhibit(FuDevice *self, const gchar *inhibit_id, const gchar *reason);
 void
 fu_device_uninhibit(FuDevice *self, const gchar *inhibit_id);
+void
+fu_device_add_problem(FuDevice *self, FwupdDeviceProblem problem);
+void
+fu_device_remove_problem(FuDevice *self, FwupdDeviceProblem problem);
+gboolean
+fu_device_has_inhibit(FuDevice *self, const gchar *inhibit_id);
 const gchar *
 fu_device_get_physical_id(FuDevice *self);
 void
@@ -560,6 +585,10 @@ guint
 fu_device_get_remove_delay(FuDevice *self);
 void
 fu_device_set_remove_delay(FuDevice *self, guint remove_delay);
+guint
+fu_device_get_acquiesce_delay(FuDevice *self);
+void
+fu_device_set_acquiesce_delay(FuDevice *self, guint acquiesce_delay);
 void
 fu_device_set_firmware_size(FuDevice *self, guint64 size);
 void
@@ -632,13 +661,11 @@ fu_device_detach_full(FuDevice *self,
 gboolean
 fu_device_reload(FuDevice *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 gboolean
-fu_device_prepare(FuDevice *self,
-		  FwupdInstallFlags flags,
-		  GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_device_prepare(FuDevice *self, FuProgress *progress, FwupdInstallFlags flags, GError **error)
+    G_GNUC_WARN_UNUSED_RESULT;
 gboolean
-fu_device_cleanup(FuDevice *self,
-		  FwupdInstallFlags flags,
-		  GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_device_cleanup(FuDevice *self, FuProgress *progress, FwupdInstallFlags flags, GError **error)
+    G_GNUC_WARN_UNUSED_RESULT;
 void
 fu_device_incorporate(FuDevice *self, FuDevice *donor);
 void
@@ -699,3 +726,26 @@ gboolean
 fu_device_has_private_flag(FuDevice *self, guint64 flag);
 void
 fu_device_emit_request(FuDevice *self, FwupdRequest *request);
+FwupdSecurityAttr *
+fu_device_security_attr_new(FuDevice *self, const gchar *appstream_id);
+
+void
+fu_device_add_instance_str(FuDevice *self, const gchar *key, const gchar *value);
+void
+fu_device_add_instance_strsafe(FuDevice *self, const gchar *key, const gchar *value);
+void
+fu_device_add_instance_strup(FuDevice *self, const gchar *key, const gchar *value);
+void
+fu_device_add_instance_u4(FuDevice *self, const gchar *key, guint8 value);
+void
+fu_device_add_instance_u8(FuDevice *self, const gchar *key, guint8 value);
+void
+fu_device_add_instance_u16(FuDevice *self, const gchar *key, guint16 value);
+void
+fu_device_add_instance_u32(FuDevice *self, const gchar *key, guint32 value);
+gboolean
+fu_device_build_instance_id(FuDevice *self, GError **error, const gchar *subsystem, ...);
+gboolean
+fu_device_build_instance_id_quirk(FuDevice *self, GError **error, const gchar *subsystem, ...);
+FuDeviceLocker *
+fu_device_poll_locker_new(FuDevice *self, GError **error);
