@@ -9,9 +9,11 @@
 #include <fwupd.h>
 #include <string.h>
 
+#include "fu-byte-array.h"
 #include "fu-common.h"
 #include "fu-efi-signature-list.h"
 #include "fu-efi-signature-private.h"
+#include "fu-mem.h"
 
 /**
  * FuEfiSignatureList:
@@ -27,6 +29,8 @@ struct _FuEfiSignatureList {
 
 G_DEFINE_TYPE(FuEfiSignatureList, fu_efi_signature_list, FU_TYPE_FIRMWARE)
 
+const guint8 FU_EFI_SIGLIST_HEADER_MAGIC[] = {0x26, 0x16, 0xC4, 0xC1, 0x4C};
+
 static gboolean
 fu_efi_signature_list_parse_item(FuEfiSignatureList *self,
 				 FuEfiSignatureKind sig_kind,
@@ -121,12 +125,12 @@ fu_efi_signature_list_parse_list(FuEfiSignatureList *self,
 	} else if (g_strcmp0(sig_type, "a5c059a1-94e4-4aa7-87b5-ab155c2bf072") == 0) {
 		sig_kind = FU_EFI_SIGNATURE_KIND_X509;
 	}
-	if (!fu_common_read_uint32_safe(buf,
-					bufsz,
-					*offset + 0x10,
-					&sig_list_size,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(buf,
+				    bufsz,
+				    *offset + 0x10,
+				    &sig_list_size,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	if (sig_list_size < 0x1c || sig_list_size > 1024 * 1024) {
 		g_set_error(error,
@@ -136,12 +140,12 @@ fu_efi_signature_list_parse_list(FuEfiSignatureList *self,
 			    sig_list_size);
 		return FALSE;
 	}
-	if (!fu_common_read_uint32_safe(buf,
-					bufsz,
-					*offset + 0x14,
-					&sig_header_size,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(buf,
+				    bufsz,
+				    *offset + 0x14,
+				    &sig_header_size,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	if (sig_header_size > 1024 * 1024) {
 		g_set_error(error,
@@ -151,12 +155,7 @@ fu_efi_signature_list_parse_list(FuEfiSignatureList *self,
 			    sig_size);
 		return FALSE;
 	}
-	if (!fu_common_read_uint32_safe(buf,
-					bufsz,
-					*offset + 0x18,
-					&sig_size,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(buf, bufsz, *offset + 0x18, &sig_size, G_LITTLE_ENDIAN, error))
 		return FALSE;
 	if (sig_size < sizeof(fwupd_guid_t) || sig_size > 1024 * 1024) {
 		g_set_error(error,
@@ -191,7 +190,36 @@ fu_efi_signature_list_get_version(FuEfiSignatureList *self)
 	const gchar *ignored_guids[] = {FU_EFI_SIGNATURE_GUID_OVMF,
 					FU_EFI_SIGNATURE_GUID_OVMF_LEGACY,
 					NULL};
+	g_autofree gchar *checksum_last = NULL;
 	g_autoptr(GPtrArray) sigs = NULL;
+	struct {
+		const gchar *checksum;
+		guint version;
+	} known_checksums[] = {
+	    /* DBXUpdate-20100307.x64.bin */
+	    {"5391c3a2fb112102a6aa1edc25ae77e19f5d6f09cd09eeb2509922bfcd5992ea", 9},
+	    /* DBXUpdate-20140413.x64.bin */
+	    {"90fbe70e69d633408d3e170c6832dbb2d209e0272527dfb63d49d29572a6f44c", 13},
+	    /* DBXUpdate-20160809.x64.bin */
+	    {"45c7c8ae750acfbb48fc37527d6412dd644daed8913ccd8a24c94d856967df8e", 77},
+	    /* DBXUpdate-20200729.x64.bin */
+	    {"540801dd345dc1c33ef431b35bf4c0e68bd319b577b9abe1a9cff1cbc39f548f", 190},
+	    /* DBXUpdate-20200729.aa64.bin */
+	    {"8c8183ad9b96fe1f3c74dedb8087469227b642afe2e80f8fd22e0137c11c7d90", 19},
+	    /* DBXUpdate-20200729.ia32.bin */
+	    {"a7dfcc3a8d6ab30f93f31748dbc8ea38415cf52bb9ad8085672cd9ab8938d5de", 41},
+	    /* DBXUpdate-20210429.x64.bin */
+	    {"af79b14064601bc0987d4747af1e914a228c05d622ceda03b7a4f67014fee767", 211},
+	    /* DBXUpdate-20210429.aa64.bin */
+	    {"b133de42a37376f5d91439af3d61d38201f10377c36dacd9c2610f52aa124a91", 21},
+	    /* DBXUpdate-20210429.ia32.bin */
+	    {"a8a3300e33a0a2692839ccba84803c5e742d12501b6d58c46eb87f32017f2cff", 55},
+	    /* DBXUpdate-20220812.x64.bin */
+	    {"90aec5c4995674a849c1d1384463f3b02b5aa625a5c320fc4fe7d9bb58a62398", 217},
+	    /* DBXUpdate-20220812.aa64.bin - only X509 certificates removed */
+	    /* DBXUpdate-20220812.ia32.bin - only X509 certificates removed */
+	    {NULL, 0}};
+
 	sigs = fu_firmware_get_images(FU_FIRMWARE(self));
 	for (guint i = 0; i < sigs->len; i++) {
 		FuEfiSignature *sig = g_ptr_array_index(sigs, i);
@@ -199,47 +227,105 @@ fu_efi_signature_list_get_version(FuEfiSignatureList *self)
 			continue;
 		if (g_strv_contains(ignored_guids, fu_efi_signature_get_owner(sig)))
 			continue;
+
+		/* save the last hash in the list */
+		if (i == sigs->len - 1) {
+			g_autoptr(GError) error_local = NULL;
+			checksum_last = fu_firmware_get_checksum(FU_FIRMWARE(sig),
+								 G_CHECKSUM_SHA256,
+								 &error_local);
+			if (checksum_last == NULL) {
+				g_warning("failed to get checksum for signature %u: %s",
+					  i,
+					  error_local->message);
+			}
+		}
+
 		csum_cnt++;
 	}
+
+	/*
+	 * Microsoft seems to actually remove checksums in UEFI dbx updates, which I'm guessing is
+	 * a result from OEM pressure about SPI usage -- but local dbx updates are append-only.
+	 *
+	 * That means that if you remove hashes then you can have a different set of dbx checksums
+	 * on your machine depending on whether you went A->B->C->D or A->D...
+	 *
+	 * If we use the metric of "count the number of SHA256 checksums from MS" then we might
+	 * overcount (due to the now-removed entries) -- in some cases enough to not actually apply
+	 * the new update at all.
+	 *
+	 * In these cases look at the *last* dbx checksum and compare to the set we know to see if
+	 * we need to artificially lower the reported version. This isn't helped by having *zero*
+	 * visibility in the reason that entries were removed or added.
+	 *
+	 * This also fixes the DBX update 20200729 which added 4 duplicate entries, which should be
+	 * rectified during the SetVariable(), so they're only really a problem for transactional
+	 * size limits. But we all noticed that load-bearing *should* word there, didn't we.
+	 */
+	for (guint i = 0; checksum_last != NULL && known_checksums[i].checksum != NULL; i++) {
+		if (g_strcmp0(checksum_last, known_checksums[i].checksum) == 0) {
+			if (csum_cnt != known_checksums[i].version) {
+				g_debug("fixing signature list version from %u to %u as "
+					"last dbx checksum was %s",
+					csum_cnt,
+					known_checksums[i].version,
+					checksum_last);
+				csum_cnt = known_checksums[i].version;
+			}
+			break;
+		}
+	}
+
 	return g_strdup_printf("%u", csum_cnt);
 }
 
+static gboolean
+fu_efi_signature_list_check_magic(FuFirmware *firmware, GBytes *fw, gsize offset, GError **error)
+{
+	fwupd_guid_t guid = {0x0};
+	g_autofree gchar *sig_type = NULL;
+
+	/* read EFI_SIGNATURE_LIST */
+	if (!fu_memcpy_safe((guint8 *)&guid,
+			    sizeof(guid),
+			    0x0, /* dst */
+			    g_bytes_get_data(fw, NULL),
+			    g_bytes_get_size(fw),
+			    offset, /* src */
+			    sizeof(guid),
+			    error)) {
+		g_prefix_error(error, "failed to read magic: ");
+		return FALSE;
+	}
+	sig_type = fwupd_guid_to_string(&guid, FWUPD_GUID_FLAG_MIXED_ENDIAN);
+	if (g_strcmp0(sig_type, "c1c41626-504c-4092-aca9-41f936934328") != 0 &&
+	    g_strcmp0(sig_type, "a5c059a1-94e4-4aa7-87b5-ab155c2bf072") != 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INVALID_FILE,
+				    "invalid magic for file");
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_efi_signature_list_parse(FuFirmware *firmware,
 			    GBytes *fw,
-			    guint64 addr_start,
-			    guint64 addr_end,
+			    gsize offset,
 			    FwupdInstallFlags flags,
 			    GError **error)
 {
 	FuEfiSignatureList *self = FU_EFI_SIGNATURE_LIST(firmware);
 	gsize bufsz = 0;
-	gsize offset_fs = 0;
 	const guint8 *buf = g_bytes_get_data(fw, &bufsz);
 	g_autofree gchar *version_str = NULL;
 
-	/* this allows us to skip the efi permissions uint32_t or even the
-	 * Microsoft PKCS-7 signature */
-	if ((flags & FWUPD_INSTALL_FLAG_NO_SEARCH) == 0) {
-		if (bufsz < 5) {
-			g_set_error(error,
-				    G_IO_ERROR,
-				    G_IO_ERROR_FAILED,
-				    "signature invalid: 0x%x",
-				    (guint)bufsz);
-			return FALSE;
-		}
-		for (gsize i = 0; i < bufsz - 5; i++) {
-			if (memcmp(buf + i, "\x26\x16\xc4\xc1\x4c", 5) == 0) {
-				g_debug("found EFI_SIGNATURE_LIST @0x%x", (guint)i);
-				offset_fs = i;
-				break;
-			}
-		}
-	}
-
 	/* parse each EFI_SIGNATURE_LIST */
-	for (gsize offset = offset_fs; offset < bufsz;) {
+	while (offset < bufsz) {
 		if (!fu_efi_signature_list_parse_list(self, buf, bufsz, &offset, error))
 			return FALSE;
 	}
@@ -299,6 +385,7 @@ static void
 fu_efi_signature_list_class_init(FuEfiSignatureListClass *klass)
 {
 	FuFirmwareClass *klass_firmware = FU_FIRMWARE_CLASS(klass);
+	klass_firmware->check_magic = fu_efi_signature_list_check_magic;
 	klass_firmware->parse = fu_efi_signature_list_parse;
 	klass_firmware->write = fu_efi_signature_list_write;
 }
