@@ -8,7 +8,9 @@
 
 #include "config.h"
 
+#include "fu-dump.h"
 #include "fu-hid-device.h"
+#include "fu-string.h"
 
 #define FU_HID_REPORT_GET 0x01
 #define FU_HID_REPORT_SET 0x09
@@ -46,12 +48,12 @@ fu_hid_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuHidDevice *self = FU_HID_DEVICE(device);
 	FuHidDevicePrivate *priv = GET_PRIVATE(self);
-	fu_common_string_append_kb(str, idt, "InterfaceAutodetect", priv->interface_autodetect);
-	fu_common_string_append_kx(str, idt, "Interface", priv->interface);
+	fu_string_append_kb(str, idt, "InterfaceAutodetect", priv->interface_autodetect);
+	fu_string_append_kx(str, idt, "Interface", priv->interface);
 	if (priv->ep_addr_in != 0)
-		fu_common_string_append_kx(str, idt, "EpAddrIn", priv->ep_addr_in);
+		fu_string_append_kx(str, idt, "EpAddrIn", priv->ep_addr_in);
 	if (priv->ep_addr_out != 0)
-		fu_common_string_append_kx(str, idt, "EpAddrOut", priv->ep_addr_out);
+		fu_string_append_kx(str, idt, "EpAddrOut", priv->ep_addr_out);
 }
 
 static void
@@ -211,7 +213,7 @@ fu_hid_device_close(FuDevice *device, GError **error)
 /**
  * fu_hid_device_set_interface:
  * @self: a #FuHidDevice
- * @interface: an interface number, e.g. `0x03`
+ * @interface_number: an interface number, e.g. `0x03`
  *
  * Sets the HID USB interface number.
  *
@@ -222,11 +224,11 @@ fu_hid_device_close(FuDevice *device, GError **error)
  * Since: 1.4.0
  **/
 void
-fu_hid_device_set_interface(FuHidDevice *self, guint8 interface)
+fu_hid_device_set_interface(FuHidDevice *self, guint8 interface_number)
 {
 	FuHidDevicePrivate *priv = GET_PRIVATE(self);
 	g_return_if_fail(FU_HID_DEVICE(self));
-	priv->interface = interface;
+	priv->interface = interface_number;
 	priv->interface_autodetect = FALSE;
 }
 
@@ -286,7 +288,7 @@ fu_hid_device_set_report_internal(FuHidDevice *self, FuHidDeviceRetryHelper *hel
 		if (g_getenv("FU_HID_DEVICE_VERBOSE") != NULL) {
 			g_autofree gchar *title = NULL;
 			title = g_strdup_printf("HID::SetReport [EP=0x%02x]", priv->ep_addr_out);
-			fu_common_dump_raw(G_LOG_DOMAIN, title, helper->buf, helper->bufsz);
+			fu_dump_raw(G_LOG_DOMAIN, title, helper->buf, helper->bufsz);
 		}
 		if (!g_usb_device_interrupt_transfer(usb_device,
 						     priv->ep_addr_out,
@@ -310,7 +312,7 @@ fu_hid_device_set_report_internal(FuHidDevice *self, FuHidDeviceRetryHelper *hel
 			title = g_strdup_printf("HID::SetReport [wValue=0x%04x ,wIndex=%u]",
 						wvalue,
 						priv->interface);
-			fu_common_dump_raw(G_LOG_DOMAIN, title, helper->buf, helper->bufsz);
+			fu_dump_raw(G_LOG_DOMAIN, title, helper->buf, helper->bufsz);
 		}
 		if (!g_usb_device_control_transfer(usb_device,
 						   G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
@@ -426,7 +428,7 @@ fu_hid_device_get_report_internal(FuHidDevice *self, FuHidDeviceRetryHelper *hel
 		if (g_getenv("FU_HID_DEVICE_VERBOSE") != NULL) {
 			g_autofree gchar *title = NULL;
 			title = g_strdup_printf("HID::GetReport [EP=0x%02x]", priv->ep_addr_in);
-			fu_common_dump_raw(G_LOG_DOMAIN, title, helper->buf, helper->bufsz);
+			fu_dump_raw(G_LOG_DOMAIN, title, helper->buf, helper->bufsz);
 		}
 	} else {
 		guint16 wvalue = (FU_HID_REPORT_TYPE_INPUT << 8) | helper->value;
@@ -440,7 +442,7 @@ fu_hid_device_get_report_internal(FuHidDevice *self, FuHidDeviceRetryHelper *hel
 			title = g_strdup_printf("HID::GetReport [wValue=0x%04x, wIndex=%u]",
 						wvalue,
 						priv->interface);
-			fu_common_dump_raw(G_LOG_DOMAIN, title, helper->buf, actual_len);
+			fu_dump_raw(G_LOG_DOMAIN, title, helper->buf, actual_len);
 		}
 		if (!g_usb_device_control_transfer(usb_device,
 						   G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
@@ -463,7 +465,7 @@ fu_hid_device_get_report_internal(FuHidDevice *self, FuHidDeviceRetryHelper *hel
 			title = g_strdup_printf("HID::GetReport [wValue=0x%04x, wIndex=%u]",
 						wvalue,
 						priv->interface);
-			fu_common_dump_raw(G_LOG_DOMAIN, title, helper->buf, actual_len);
+			fu_dump_raw(G_LOG_DOMAIN, title, helper->buf, actual_len);
 		}
 	}
 	if ((helper->flags & FU_HID_DEVICE_FLAG_ALLOW_TRUNC) == 0 && actual_len != helper->bufsz) {
