@@ -15,10 +15,15 @@
 #include <string.h>
 #include <unistd.h>
 
+#include "fu-bytes.h"
 #include "fu-context-private.h"
 #include "fu-device-private.h"
+#include "fu-kernel.h"
 #include "fu-mutex.h"
+#include "fu-path.h"
 #include "fu-plugin-private.h"
+#include "fu-security-attr.h"
+#include "fu-string.h"
 
 /**
  * FuPlugin:
@@ -35,6 +40,7 @@ typedef struct {
 	GModule *module;
 	guint order;
 	guint priority;
+	gboolean done_init;
 	GPtrArray *rules[FU_PLUGIN_RULE_LAST];
 	GPtrArray *devices; /* (nullable) (element-type FuDevice) */
 	GHashTable *runtime_versions;
@@ -72,6 +78,7 @@ typedef gboolean (*FuPluginDeviceProgressFunc)(FuPlugin *self,
 					       GError **error);
 typedef gboolean (*FuPluginFlaggedDeviceFunc)(FuPlugin *self,
 					      FuDevice *device,
+					      FuProgress *progress,
 					      FwupdInstallFlags flags,
 					      GError **error);
 typedef gboolean (*FuPluginDeviceArrayFunc)(FuPlugin *self, GPtrArray *devices, GError **error);
@@ -297,7 +304,7 @@ fu_plugin_guess_name_from_fn(const gchar *filename)
  * @filename: the shared object filename to open
  * @error: (nullable): optional return location for an error
  *
- * Opens the plugin module
+ * Opens the plugin module, and calls `->load()` on it.
  *
  * Returns: TRUE for success, FALSE for fail
  *
@@ -348,14 +355,89 @@ fu_plugin_open(FuPlugin *self, const gchar *filename, GError **error)
 	}
 
 	/* optional */
-	if (vfuncs->init != NULL) {
-		g_debug("init(%s)", filename);
-		vfuncs->init(self);
+	if (vfuncs->load != NULL) {
+		FuContext *ctx = fu_plugin_get_context(self);
+		g_debug("load(%s)", filename);
+		vfuncs->load(ctx);
 	}
 
 	return TRUE;
 }
 
+static gchar *
+fu_plugin_flags_to_string(FwupdPluginFlags flags)
+{
+	g_autoptr(GString) str = g_string_new(NULL);
+	for (guint i = 0; i < 64; i++) {
+		FwupdPluginFlags flag = (guint64)1 << i;
+		if ((flags & flag) == 0)
+			continue;
+		if (str->len > 0)
+			g_string_append_c(str, ',');
+		g_string_append(str, fwupd_plugin_flag_to_string(flag));
+	}
+	if (str->len == 0)
+		return NULL;
+	return g_string_free(g_steal_pointer(&str), FALSE);
+}
+
+/**
+ * fu_plugin_add_string:
+ * @self: a #FuPlugin
+ * @idt: indent level
+ * @str: a string to append to
+ *
+ * Add daemon-specific device metadata to an existing string.
+ *
+ * Since: 1.8.4
+ **/
+void
+fu_plugin_add_string(FuPlugin *self, guint idt, GString *str)
+{
+	FuPluginPrivate *priv = GET_PRIVATE(self);
+	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
+	const gchar *name = fwupd_plugin_get_name(FWUPD_PLUGIN(self));
+	g_autofree gchar *flags = NULL;
+
+	g_return_if_fail(FU_IS_PLUGIN(self));
+	g_return_if_fail(str != NULL);
+
+	/* attributes */
+	fu_string_append(str, idt, G_OBJECT_TYPE_NAME(self), "");
+	if (name != NULL)
+		fu_string_append(str, idt + 1, "Name", name);
+	flags = fu_plugin_flags_to_string(fwupd_plugin_get_flags(FWUPD_PLUGIN(self)));
+	if (flags != NULL)
+		fu_string_append(str, idt + 1, "Flags", flags);
+	if (priv->order != 0)
+		fu_string_append_ku(str, idt + 1, "Order", priv->order);
+	if (priv->priority != 0)
+		fu_string_append_ku(str, idt + 1, "Priority", priv->priority);
+
+	/* optional */
+	if (vfuncs->to_string != NULL)
+		vfuncs->to_string(self, idt + 1, str);
+}
+
+/**
+ * fu_plugin_to_string:
+ * @self: a #FuPlugin
+ *
+ * This allows us to easily print the plugin metadata.
+ *
+ * Returns: a string value, or %NULL for invalid.
+ *
+ * Since: 1.8.4
+ **/
+gchar *
+fu_plugin_to_string(FuPlugin *self)
+{
+	g_autoptr(GString) str = g_string_new(NULL);
+	g_return_val_if_fail(FU_IS_PLUGIN(self), NULL);
+	fu_plugin_add_string(self, 0, str);
+	return g_string_free(g_steal_pointer(&str), FALSE);
+}
+
 /* order of usefulness to the user */
 static const gchar *
 fu_plugin_build_device_update_error(FuPlugin *self)
@@ -422,7 +504,7 @@ fu_plugin_config_monitor_changed_cb(GFileMonitor *monitor,
 static gchar *
 fu_plugin_get_config_filename(FuPlugin *self)
 {
-	g_autofree gchar *conf_dir = fu_common_get_path(FU_PATH_KIND_SYSCONFDIR_PKG);
+	g_autofree gchar *conf_dir = fu_path_from_kind(FU_PATH_KIND_SYSCONFDIR_PKG);
 	g_autofree gchar *conf_file = g_strdup_printf("%s.conf", fu_plugin_get_name(self));
 	return g_build_filename(conf_dir, conf_file, NULL);
 }
@@ -499,8 +581,8 @@ fu_plugin_device_add(FuPlugin *self, FuDevice *device)
  * fu_plugin_get_devices:
  * @self: a #FuPlugin
  *
- * Returns all devices added by the plugin using fu_plugin_device_add() and
- * not yet removed with fu_plugin_device_remove().
+ * Returns all devices added by the plugin using [method@FuPlugin.device_add] and
+ * not yet removed with [method@FuPlugin.device_remove].
  *
  * Returns: (transfer none) (element-type FuDevice): devices
  *
@@ -523,7 +605,7 @@ fu_plugin_get_devices(FuPlugin *self)
  * Registers the device with other plugins so they can set metadata.
  *
  * Plugins do not have to call this manually as this is done automatically
- * when using fu_plugin_device_add(). They may wish to use this manually
+ * when using [method@FuPlugin.device_add]. They may wish to use this manually
  * if for instance the coldplug should be ignored based on the metadata
  * set from other plugins.
  *
@@ -574,28 +656,6 @@ fu_plugin_device_remove(FuPlugin *self, FuDevice *device)
 	g_signal_emit(self, signals[SIGNAL_DEVICE_REMOVED], 0, device);
 }
 
-/**
- * fu_plugin_has_custom_flag:
- * @self: a #FuPlugin
- * @flag: a custom text flag, specific to the plugin, e.g. `uefi-force-enable`
- *
- * Returns if a per-plugin HwId custom flag exists, typically added from a DMI quirk.
- *
- * Returns: %TRUE if the quirk entry exists
- *
- * Since: 1.3.1
- **/
-gboolean
-fu_plugin_has_custom_flag(FuPlugin *self, const gchar *flag)
-{
-	FuPluginPrivate *priv = GET_PRIVATE(self);
-
-	g_return_val_if_fail(FU_IS_PLUGIN(self), FALSE);
-	g_return_val_if_fail(flag != NULL, FALSE);
-
-	return fu_context_has_hwid_flag(priv->ctx, flag);
-}
-
 /**
  * fu_plugin_check_supported:
  * @self: a #FuPlugin
@@ -637,7 +697,10 @@ static gboolean
 fu_plugin_device_attach(FuPlugin *self, FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuDevice *proxy = fu_device_get_proxy_with_fallback(device);
+	FuDeviceClass *proxy_klass = FU_DEVICE_GET_CLASS(proxy);
 	g_autoptr(FuDeviceLocker) locker = NULL;
+	if (proxy_klass->attach == NULL)
+		return TRUE;
 	locker = fu_device_locker_new(proxy, error);
 	if (locker == NULL)
 		return FALSE;
@@ -648,7 +711,10 @@ static gboolean
 fu_plugin_device_detach(FuPlugin *self, FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuDevice *proxy = fu_device_get_proxy_with_fallback(device);
+	FuDeviceClass *proxy_klass = FU_DEVICE_GET_CLASS(proxy);
 	g_autoptr(FuDeviceLocker) locker = NULL;
+	if (proxy_klass->detach == NULL)
+		return TRUE;
 	locker = fu_device_locker_new(proxy, error);
 	if (locker == NULL)
 		return FALSE;
@@ -659,7 +725,10 @@ static gboolean
 fu_plugin_device_activate(FuPlugin *self, FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuDevice *proxy = fu_device_get_proxy_with_fallback(device);
+	FuDeviceClass *proxy_klass = FU_DEVICE_GET_CLASS(proxy);
 	g_autoptr(FuDeviceLocker) locker = NULL;
+	if (proxy_klass->activate == NULL)
+		return TRUE;
 	locker = fu_device_locker_new(proxy, error);
 	if (locker == NULL)
 		return FALSE;
@@ -690,15 +759,15 @@ fu_plugin_device_write_firmware(FuPlugin *self,
 		/* progress */
 		fu_progress_set_id(progress, G_STRLOC);
 		fu_progress_add_flag(progress, FU_PROGRESS_FLAG_NO_PROFILE);
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25);
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 75);
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25, NULL);
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 75, NULL);
 
 		fw_old = fu_device_dump_firmware(device, fu_progress_get_child(progress), error);
 		if (fw_old == NULL) {
 			g_prefix_error(error, "failed to backup old firmware: ");
 			return FALSE;
 		}
-		localstatedir = fu_common_get_path(FU_PATH_KIND_LOCALSTATEDIR_PKG);
+		localstatedir = fu_path_from_kind(FU_PATH_KIND_LOCALSTATEDIR_PKG);
 		fn = g_strdup_printf("%s.bin", fu_device_get_version(device));
 		path = g_build_filename(
 		    localstatedir,
@@ -708,7 +777,7 @@ fu_plugin_device_write_firmware(FuPlugin *self,
 		    fn,
 		    NULL);
 		fu_progress_step_done(progress);
-		if (!fu_common_set_contents_bytes(path, fw_old, error))
+		if (!fu_bytes_set_contents(path, fw_old, error))
 			return FALSE;
 		if (!fu_device_write_firmware(device,
 					      fw,
@@ -792,7 +861,7 @@ fu_plugin_device_read_firmware(FuPlugin *self,
  * Since: 0.8.0
  **/
 gboolean
-fu_plugin_runner_startup(FuPlugin *self, GError **error)
+fu_plugin_runner_startup(FuPlugin *self, FuProgress *progress, GError **error)
 {
 	FuPluginPrivate *priv = GET_PRIVATE(self);
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
@@ -800,6 +869,14 @@ fu_plugin_runner_startup(FuPlugin *self, GError **error)
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GFile) file = g_file_new_for_path(config_filename);
 
+	g_return_val_if_fail(FU_IS_PLUGIN(self), FALSE);
+
+	/* progress */
+	fu_progress_set_name(progress, fu_plugin_get_name(self));
+
+	/* be helpful for unit tests */
+	fu_plugin_runner_init(self);
+
 	/* not enabled */
 	if (fu_plugin_has_flag(self, FWUPD_PLUGIN_FLAG_DISABLED))
 		return TRUE;
@@ -808,7 +885,7 @@ fu_plugin_runner_startup(FuPlugin *self, GError **error)
 	if (vfuncs->startup == NULL)
 		return TRUE;
 	g_debug("startup(%s)", fu_plugin_get_name(self));
-	if (!vfuncs->startup(self, &error_local)) {
+	if (!vfuncs->startup(self, progress, &error_local)) {
 		if (error_local == NULL) {
 			g_critical("unset plugin error in startup(%s)", fu_plugin_get_name(self));
 			g_set_error_literal(&error_local,
@@ -836,6 +913,38 @@ fu_plugin_runner_startup(FuPlugin *self, GError **error)
 	return TRUE;
 }
 
+/**
+ * fu_plugin_runner_init:
+ * @self: a #FuPlugin
+ *
+ * Runs the init routine for the plugin, if enabled.
+ *
+ * Since: 1.8.1
+ **/
+void
+fu_plugin_runner_init(FuPlugin *self)
+{
+	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
+	FuPluginPrivate *priv = GET_PRIVATE(self);
+
+	g_return_if_fail(FU_IS_PLUGIN(self));
+
+	/* already done */
+	if (priv->done_init)
+		return;
+
+	/* not enabled */
+	if (fu_plugin_has_flag(self, FWUPD_PLUGIN_FLAG_DISABLED))
+		return;
+
+	/* optional */
+	if (vfuncs->init != NULL) {
+		g_debug("init(%s)", fu_plugin_get_name(self));
+		vfuncs->init(self);
+		priv->done_init = TRUE;
+	}
+}
+
 static gboolean
 fu_plugin_runner_device_generic(FuPlugin *self,
 				FuDevice *device,
@@ -914,6 +1023,7 @@ fu_plugin_runner_device_generic_progress(FuPlugin *self,
 static gboolean
 fu_plugin_runner_flagged_device_generic(FuPlugin *self,
 					FuDevice *device,
+					FuProgress *progress,
 					FwupdInstallFlags flags,
 					const gchar *symbol_name,
 					FuPluginFlaggedDeviceFunc func,
@@ -929,7 +1039,7 @@ fu_plugin_runner_flagged_device_generic(FuPlugin *self,
 	if (func == NULL)
 		return TRUE;
 	g_debug("%s(%s)", symbol_name + 10, fu_plugin_get_name(self));
-	if (!func(self, device, flags, &error_local)) {
+	if (!func(self, device, progress, flags, &error_local)) {
 		if (error_local == NULL) {
 			g_critical("unset plugin error in %s(%s)",
 				   fu_plugin_get_name(self),
@@ -989,6 +1099,7 @@ fu_plugin_runner_device_array_generic(FuPlugin *self,
 /**
  * fu_plugin_runner_coldplug:
  * @self: a #FuPlugin
+ * @progress: a #FuProgress
  * @error: (nullable): optional return location for an error
  *
  * Runs the coldplug routine for the plugin
@@ -998,12 +1109,17 @@ fu_plugin_runner_device_array_generic(FuPlugin *self,
  * Since: 0.8.0
  **/
 gboolean
-fu_plugin_runner_coldplug(FuPlugin *self, GError **error)
+fu_plugin_runner_coldplug(FuPlugin *self, FuProgress *progress, GError **error)
 {
 	FuPluginPrivate *priv = GET_PRIVATE(self);
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
 	g_autoptr(GError) error_local = NULL;
 
+	g_return_val_if_fail(FU_IS_PLUGIN(self), FALSE);
+
+	/* progress */
+	fu_progress_set_name(progress, fu_plugin_get_name(self));
+
 	/* not enabled */
 	if (fu_plugin_has_flag(self, FWUPD_PLUGIN_FLAG_DISABLED))
 		return TRUE;
@@ -1016,7 +1132,7 @@ fu_plugin_runner_coldplug(FuPlugin *self, GError **error)
 	if (vfuncs->coldplug == NULL)
 		return TRUE;
 	g_debug("coldplug(%s)", fu_plugin_get_name(self));
-	if (!vfuncs->coldplug(self, &error_local)) {
+	if (!vfuncs->coldplug(self, progress, &error_local)) {
 		if (error_local == NULL) {
 			g_critical("unset plugin error in coldplug(%s)", fu_plugin_get_name(self));
 			g_set_error_literal(&error_local,
@@ -1091,8 +1207,9 @@ fu_plugin_runner_composite_cleanup(FuPlugin *self, GPtrArray *devices, GError **
 /**
  * fu_plugin_runner_prepare:
  * @self: a #FuPlugin
- * @flags: install flags
  * @device: a device
+ * @progress: a #FuProgress
+ * @flags: install flags
  * @error: (nullable): optional return location for an error
  *
  * Runs the update_prepare routine for the plugin
@@ -1102,11 +1219,16 @@ fu_plugin_runner_composite_cleanup(FuPlugin *self, GPtrArray *devices, GError **
  * Since: 1.7.0
  **/
 gboolean
-fu_plugin_runner_prepare(FuPlugin *self, FuDevice *device, FwupdInstallFlags flags, GError **error)
+fu_plugin_runner_prepare(FuPlugin *self,
+			 FuDevice *device,
+			 FuProgress *progress,
+			 FwupdInstallFlags flags,
+			 GError **error)
 {
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
 	return fu_plugin_runner_flagged_device_generic(self,
 						       device,
+						       progress,
 						       flags,
 						       "fu_plugin_prepare",
 						       vfuncs->prepare,
@@ -1116,8 +1238,9 @@ fu_plugin_runner_prepare(FuPlugin *self, FuDevice *device, FwupdInstallFlags fla
 /**
  * fu_plugin_runner_cleanup:
  * @self: a #FuPlugin
- * @flags: install flags
  * @device: a device
+ * @progress: a #FuProgress
+ * @flags: install flags
  * @error: (nullable): optional return location for an error
  *
  * Runs the update_cleanup routine for the plugin
@@ -1127,11 +1250,16 @@ fu_plugin_runner_prepare(FuPlugin *self, FuDevice *device, FwupdInstallFlags fla
  * Since: 1.7.0
  **/
 gboolean
-fu_plugin_runner_cleanup(FuPlugin *self, FuDevice *device, FwupdInstallFlags flags, GError **error)
+fu_plugin_runner_cleanup(FuPlugin *self,
+			 FuDevice *device,
+			 FuProgress *progress,
+			 FwupdInstallFlags flags,
+			 GError **error)
 {
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
 	return fu_plugin_runner_flagged_device_generic(self,
 						       device,
+						       progress,
 						       flags,
 						       "fu_plugin_cleanup",
 						       vfuncs->cleanup,
@@ -1301,7 +1429,7 @@ fu_plugin_check_amdgpu_dpaux(FuPlugin *self, GError **error)
 	for (guint i = 0; lines[i] != NULL; i++) {
 		if (g_str_has_prefix(lines[i], "amdgpu ")) {
 			/* released 2019! */
-			return fu_common_check_kernel_version("5.2.0", error);
+			return fu_kernel_check_version("5.2.0", error);
 		}
 	}
 #endif
@@ -1363,7 +1491,7 @@ fu_plugin_add_firmware_gtype(FuPlugin *self, const gchar *id, GType gtype)
 		g_autoptr(GString) str = g_string_new(g_type_name(gtype));
 		if (g_str_has_prefix(str->str, "Fu"))
 			g_string_erase(str, 0, 2);
-		fu_common_string_replace(str, "Firmware", "");
+		fu_string_replace(str, "Firmware", "");
 		id_safe = fu_common_string_uncamelcase(str->str);
 	}
 	fu_context_add_firmware_gtype(priv->ctx, id_safe, gtype);
@@ -1712,7 +1840,7 @@ fu_plugin_runner_verify(FuPlugin *self,
 
 	/* run vfunc */
 	g_debug("verify(%s)", fu_plugin_get_name(self));
-	if (!vfuncs->verify(self, device, flags, &error_local)) {
+	if (!vfuncs->verify(self, device, progress, flags, &error_local)) {
 		g_autoptr(GError) error_attach = NULL;
 		if (error_local == NULL) {
 			g_critical("unset plugin error in verify(%s)", fu_plugin_get_name(self));
@@ -2226,6 +2354,31 @@ fu_plugin_get_config_value(FuPlugin *self, const gchar *key)
 	return g_key_file_get_string(keyfile, fu_plugin_get_name(self), key, NULL);
 }
 
+/**
+ * fu_plugin_security_attr_new:
+ * @self: a #FuPlugin
+ * @appstream_id: (nullable): the AppStream component ID, e.g. `com.intel.BiosGuard`
+ *
+ * Creates a new #FwupdSecurityAttr for this specific plugin.
+ *
+ * Returns: (transfer full): a #FwupdSecurityAttr
+ *
+ * Since: 1.8.4
+ **/
+FwupdSecurityAttr *
+fu_plugin_security_attr_new(FuPlugin *self, const gchar *appstream_id)
+{
+	FuPluginPrivate *priv = fu_plugin_get_instance_private(self);
+	g_autoptr(FwupdSecurityAttr) attr = NULL;
+
+	g_return_val_if_fail(FU_IS_PLUGIN(self), NULL);
+	g_return_val_if_fail(appstream_id != NULL, NULL);
+
+	attr = fu_security_attr_new(priv->ctx, appstream_id);
+	fwupd_security_attr_set_plugin(attr, fu_plugin_get_name(self));
+	return g_steal_pointer(&attr);
+}
+
 /**
  * fu_plugin_set_config_value:
  * @self: a #FuPlugin
@@ -2494,7 +2647,7 @@ fu_plugin_finalize(GObject *object)
 	g_rw_lock_clear(&priv->cache_mutex);
 
 	/* optional */
-	if (vfuncs->destroy != NULL) {
+	if (priv->done_init && vfuncs->destroy != NULL) {
 		g_debug("destroy(%s)", fu_plugin_get_name(self));
 		vfuncs->destroy(self);
 	}
