@@ -23,6 +23,7 @@
 
 #include "fu-device-private.h"
 #include "fu-i2c-device.h"
+#include "fu-string.h"
 #include "fu-udev-device-private.h"
 
 /**
@@ -35,10 +36,10 @@
 
 typedef struct {
 	GUdevDevice *udev_device;
-	guint32 vendor;
-	guint32 model;
-	guint32 subsystem_vendor;
-	guint32 subsystem_model;
+	guint16 vendor;
+	guint16 model;
+	guint16 subsystem_vendor;
+	guint16 subsystem_model;
 	guint8 revision;
 	gchar *subsystem;
 	gchar *bind_id;
@@ -85,41 +86,44 @@ fu_udev_device_emit_changed(FuUdevDevice *self)
 	g_signal_emit(self, signals[SIGNAL_CHANGED], 0);
 }
 
-static guint32
-fu_udev_device_get_sysfs_attr_as_uint32(GUdevDevice *udev_device, const gchar *name)
-{
 #ifdef HAVE_GUDEV
-	guint64 tmp = fu_common_strtoull(g_udev_device_get_sysfs_attr(udev_device, name));
-	if (tmp > G_MAXUINT32) {
-		g_warning("reading %s for %s overflowed",
-			  name,
-			  g_udev_device_get_sysfs_path(udev_device));
-		return G_MAXUINT32;
+static guint16
+fu_udev_device_get_sysfs_attr_as_uint16(GUdevDevice *udev_device, const gchar *name)
+{
+	const gchar *tmp;
+	guint64 tmp64 = 0;
+	g_autoptr(GError) error_local = NULL;
+
+	tmp = g_udev_device_get_sysfs_attr(udev_device, name);
+	if (tmp == NULL)
+		return 0x0;
+	if (!fu_strtoull(tmp, &tmp64, 0, G_MAXUINT16 - 1, &error_local)) {
+		g_warning("reading %s for %s was invalid: %s", name, tmp, error_local->message);
+		return 0x0;
 	}
-	return tmp;
-#else
-	return G_MAXUINT32;
-#endif
+	return tmp64;
 }
 
 static guint8
 fu_udev_device_get_sysfs_attr_as_uint8(GUdevDevice *udev_device, const gchar *name)
 {
-#ifdef HAVE_GUDEV
-	guint64 tmp = fu_common_strtoull(g_udev_device_get_sysfs_attr(udev_device, name));
-	if (tmp > G_MAXUINT8) {
-		g_warning("reading %s for %s overflowed",
+	const gchar *tmp;
+	guint64 tmp64 = 0;
+	g_autoptr(GError) error_local = NULL;
+
+	tmp = g_udev_device_get_sysfs_attr(udev_device, name);
+	if (tmp == NULL)
+		return 0x0;
+	if (!fu_strtoull(tmp, &tmp64, 0, G_MAXUINT8 - 1, &error_local)) {
+		g_warning("reading %s for %s was invalid: %s",
 			  name,
-			  g_udev_device_get_sysfs_path(udev_device));
-		return G_MAXUINT8;
+			  g_udev_device_get_sysfs_path(udev_device),
+			  error_local->message);
+		return 0x0;
 	}
-	return tmp;
-#else
-	return G_MAXUINT8;
-#endif
+	return tmp64;
 }
 
-#ifdef HAVE_GUDEV
 static void
 fu_udev_device_to_string_raw(GUdevDevice *udev_device, guint idt, GString *str)
 {
@@ -128,17 +132,17 @@ fu_udev_device_to_string_raw(GUdevDevice *udev_device, guint idt, GString *str)
 		return;
 	keys = g_udev_device_get_property_keys(udev_device);
 	for (guint i = 0; keys[i] != NULL; i++) {
-		fu_common_string_append_kv(str,
-					   idt,
-					   keys[i],
-					   g_udev_device_get_property(udev_device, keys[i]));
+		fu_string_append(str,
+				 idt,
+				 keys[i],
+				 g_udev_device_get_property(udev_device, keys[i]));
 	}
 	keys = g_udev_device_get_sysfs_attr_keys(udev_device);
 	for (guint i = 0; keys[i] != NULL; i++) {
-		fu_common_string_append_kv(str,
-					   idt,
-					   keys[i],
-					   g_udev_device_get_sysfs_attr(udev_device, keys[i]));
+		fu_string_append(str,
+				 idt,
+				 keys[i],
+				 g_udev_device_get_sysfs_attr(udev_device, keys[i]));
 	}
 }
 #endif
@@ -149,25 +153,36 @@ fu_udev_device_to_string(FuDevice *device, guint idt, GString *str)
 #ifdef HAVE_GUDEV
 	FuUdevDevice *self = FU_UDEV_DEVICE(device);
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+	if (priv->vendor != 0x0)
+		fu_string_append_kx(str, idt, "Vendor", priv->vendor);
+	if (priv->model != 0x0)
+		fu_string_append_kx(str, idt, "Model", priv->model);
+	if (priv->subsystem_vendor != 0x0 || priv->subsystem_model != 0x0) {
+		fu_string_append_kx(str, idt, "SubsystemVendor", priv->subsystem_vendor);
+		fu_string_append_kx(str, idt, "SubsystemModel", priv->subsystem_model);
+	}
+	if (priv->revision != 0x0)
+		fu_string_append_kx(str, idt, "Revision", priv->revision);
+	if (priv->subsystem != NULL)
+		fu_string_append(str, idt, "Subsystem", priv->subsystem);
+	if (priv->driver != NULL)
+		fu_string_append(str, idt, "Driver", priv->driver);
+	if (priv->bind_id != NULL)
+		fu_string_append(str, idt, "BindId", priv->bind_id);
+	if (priv->device_file != NULL)
+		fu_string_append(str, idt, "DeviceFile", priv->device_file);
 	if (priv->udev_device != NULL) {
-		fu_common_string_append_kv(str,
-					   idt,
-					   "SysfsPath",
-					   g_udev_device_get_sysfs_path(priv->udev_device));
-		fu_common_string_append_kv(str, idt, "Subsystem", priv->subsystem);
-		if (priv->driver != NULL)
-			fu_common_string_append_kv(str, idt, "Driver", priv->driver);
-		if (priv->bind_id != NULL)
-			fu_common_string_append_kv(str, idt, "BindId", priv->bind_id);
-		if (priv->device_file != NULL)
-			fu_common_string_append_kv(str, idt, "DeviceFile", priv->device_file);
+		fu_string_append(str,
+				 idt,
+				 "SysfsPath",
+				 g_udev_device_get_sysfs_path(priv->udev_device));
 	}
 	if (g_getenv("FU_UDEV_DEVICE_DEBUG") != NULL) {
 		g_autoptr(GUdevDevice) udev_parent = NULL;
 		fu_udev_device_to_string_raw(priv->udev_device, idt, str);
 		udev_parent = g_udev_device_get_parent(priv->udev_device);
 		if (udev_parent != NULL) {
-			fu_common_string_append_kv(str, idt, "Parent", NULL);
+			fu_string_append(str, idt, "Parent", NULL);
 			fu_udev_device_to_string_raw(udev_parent, idt + 1, str);
 		}
 	}
@@ -300,18 +315,67 @@ fu_udev_device_probe_serio(FuUdevDevice *self, GError **error)
 	/* firmware ID */
 	tmp = g_udev_device_get_property(priv->udev_device, "SERIO_FIRMWARE_ID");
 	if (tmp != NULL) {
-		g_autofree gchar *id_safe = NULL;
 		/* this prefix is not useful */
 		if (g_str_has_prefix(tmp, "PNP: "))
 			tmp += 5;
-		id_safe = fu_common_instance_id_strsafe(tmp);
-		if (id_safe != NULL) {
-			g_autofree gchar *devid = g_strdup_printf("SERIO\\FWID_%s", id_safe);
-			fu_device_add_instance_id(FU_DEVICE(self), devid);
-		}
+		fu_device_add_instance_strsafe(FU_DEVICE(self), "FWID", tmp);
+		if (!fu_device_build_instance_id(FU_DEVICE(self), error, "SERIO", "FWID", NULL))
+			return FALSE;
 	}
 	return TRUE;
 }
+
+static guint16
+fu_udev_device_get_property_as_uint16(GUdevDevice *udev_device, const gchar *key)
+{
+	const gchar *tmp = g_udev_device_get_property(udev_device, key);
+	guint64 value = 0;
+	g_autofree gchar *str = NULL;
+
+	if (tmp == NULL)
+		return 0x0;
+	str = g_strdup_printf("0x%s", tmp);
+	if (!fu_strtoull(str, &value, 0x0, G_MAXUINT16, NULL))
+		return 0x0;
+	return (guint16)value;
+}
+
+static void
+fu_udev_device_set_vendor_from_udev_device(FuUdevDevice *self, GUdevDevice *udev_device)
+{
+	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+	priv->vendor = fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "vendor");
+	priv->model = fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "device");
+	priv->revision = fu_udev_device_get_sysfs_attr_as_uint8(udev_device, "revision");
+	priv->subsystem_vendor =
+	    fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "subsystem_vendor");
+	priv->subsystem_model =
+	    fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "subsystem_device");
+
+	/* fallback to properties as udev might be using a subsystem-specific prober */
+	if (priv->vendor == 0x0)
+		priv->vendor = fu_udev_device_get_property_as_uint16(udev_device, "ID_VENDOR_ID");
+	if (priv->model == 0x0)
+		priv->model = fu_udev_device_get_property_as_uint16(udev_device, "ID_MODEL_ID");
+	if (priv->revision == 0x0)
+		priv->revision = fu_udev_device_get_property_as_uint16(udev_device, "ID_REVISION");
+}
+
+static void
+fu_udev_device_set_vendor_from_parent(FuUdevDevice *self)
+{
+	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+	g_autoptr(GUdevDevice) udev_device = g_object_ref(priv->udev_device);
+	while (TRUE) {
+		g_autoptr(GUdevDevice) parent = g_udev_device_get_parent(udev_device);
+		if (parent == NULL)
+			break;
+		fu_udev_device_set_vendor_from_udev_device(self, parent);
+		if (priv->vendor != 0x0 || priv->model != 0x0 || priv->revision != 0x0)
+			break;
+		g_set_object(&udev_device, parent);
+	}
+}
 #endif
 
 static gboolean
@@ -330,28 +394,12 @@ fu_udev_device_probe(FuDevice *device, GError **error)
 	if (priv->udev_device == NULL)
 		return TRUE;
 
-	/* set ven:dev:rev */
-	priv->vendor = fu_udev_device_get_sysfs_attr_as_uint32(priv->udev_device, "vendor");
-	priv->model = fu_udev_device_get_sysfs_attr_as_uint32(priv->udev_device, "device");
-	priv->revision = fu_udev_device_get_sysfs_attr_as_uint8(priv->udev_device, "revision");
-	priv->subsystem_vendor =
-	    fu_udev_device_get_sysfs_attr_as_uint32(priv->udev_device, "subsystem_vendor");
-	priv->subsystem_model =
-	    fu_udev_device_get_sysfs_attr_as_uint32(priv->udev_device, "subsystem_device");
-
 #ifdef HAVE_GUDEV
-	/* fallback to the parent */
+	/* get IDs, but fallback to the parent, grandparent, great-grandparent, etc */
+	fu_udev_device_set_vendor_from_udev_device(self, priv->udev_device);
 	udev_parent = g_udev_device_get_parent(priv->udev_device);
-	if (udev_parent != NULL && priv->flags & FU_UDEV_DEVICE_FLAG_VENDOR_FROM_PARENT &&
-	    priv->vendor == 0x0 && priv->model == 0x0 && priv->revision == 0x0) {
-		priv->vendor = fu_udev_device_get_sysfs_attr_as_uint32(udev_parent, "vendor");
-		priv->model = fu_udev_device_get_sysfs_attr_as_uint32(udev_parent, "device");
-		priv->revision = fu_udev_device_get_sysfs_attr_as_uint8(udev_parent, "revision");
-		priv->subsystem_vendor =
-		    fu_udev_device_get_sysfs_attr_as_uint32(udev_parent, "subsystem_vendor");
-		priv->subsystem_model =
-		    fu_udev_device_get_sysfs_attr_as_uint32(udev_parent, "subsystem_device");
-	}
+	if (udev_parent != NULL && priv->flags & FU_UDEV_DEVICE_FLAG_VENDOR_FROM_PARENT)
+		fu_udev_device_set_vendor_from_parent(self);
 
 	/* hidraw helpfully encodes the information in a different place */
 	if (udev_parent != NULL && priv->vendor == 0x0 && priv->model == 0x0 &&
@@ -361,7 +409,7 @@ fu_udev_device_probe(FuDevice *device, GError **error)
 			g_auto(GStrv) split = g_strsplit(tmp, ":", -1);
 			if (g_strv_length(split) == 3) {
 				guint64 val = g_ascii_strtoull(split[1], NULL, 16);
-				if (val > G_MAXUINT32) {
+				if (val > G_MAXUINT16) {
 					g_warning("reading %s for %s overflowed",
 						  split[1],
 						  g_udev_device_get_sysfs_path(priv->udev_device));
@@ -459,71 +507,44 @@ fu_udev_device_probe(FuDevice *device, GError **error)
 	}
 
 	/* add GUIDs in order of priority */
-	if (priv->vendor != 0x0000 && priv->model != 0x0000 && priv->subsystem_vendor != 0x0000 &&
-	    priv->subsystem_model != 0x0000) {
-		g_autofree gchar *devid1 = NULL;
-		g_autofree gchar *devid2 = NULL;
-		devid1 = g_strdup_printf("%s\\VEN_%04X&DEV_%04X&SUBSYS_%04X%04X&REV_%02X",
-					 subsystem,
-					 priv->vendor,
-					 priv->model,
-					 priv->subsystem_vendor,
-					 priv->subsystem_model,
-					 priv->revision);
-		fu_device_add_instance_id(device, devid1);
-		devid2 = g_strdup_printf("%s\\VEN_%04X&DEV_%04X&SUBSYS_%04X%04X",
-					 subsystem,
-					 priv->vendor,
-					 priv->model,
-					 priv->subsystem_vendor,
-					 priv->subsystem_model);
-		fu_device_add_instance_id(device, devid2);
-	}
-	if (priv->vendor != 0x0000 && priv->model != 0x0000) {
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("%s\\VEN_%04X&DEV_%04X&REV_%02X",
-					subsystem,
-					priv->vendor,
-					priv->model,
-					priv->revision);
-		fu_device_add_instance_id(device, devid);
-	}
-	if (priv->vendor != 0x0000 && priv->model != 0x0000) {
-		g_autofree gchar *devid = NULL;
-		devid =
-		    g_strdup_printf("%s\\VEN_%04X&DEV_%04X", subsystem, priv->vendor, priv->model);
-		fu_device_add_instance_id(device, devid);
-	}
-	if (priv->vendor != 0x0000) {
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("%s\\VEN_%04X", subsystem, priv->vendor);
-		fu_device_add_instance_id_full(device, devid, FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
+	if (priv->vendor != 0x0000)
+		fu_device_add_instance_u16(device, "VEN", priv->vendor);
+	if (priv->model != 0x0000)
+		fu_device_add_instance_u16(device, "DEV", priv->model);
+	if (priv->subsystem_vendor != 0x0000 || priv->subsystem_model != 0x0000) {
+		g_autofree gchar *subsys =
+		    g_strdup_printf("%04X%04X", priv->subsystem_vendor, priv->subsystem_model);
+		fu_device_add_instance_str(device, "SUBSYS", subsys);
 	}
+	if (priv->revision != 0xFF)
+		fu_device_add_instance_u8(device, "REV", priv->revision);
+
+	fu_device_build_instance_id_quirk(device, NULL, subsystem, "VEN", NULL);
+	fu_device_build_instance_id(device, NULL, subsystem, "VEN", "DEV", NULL);
+	fu_device_build_instance_id(device, NULL, subsystem, "VEN", "DEV", "REV", NULL);
+	fu_device_build_instance_id(device, NULL, subsystem, "VEN", "DEV", "SUBSYS", NULL);
+	fu_device_build_instance_id(device, NULL, subsystem, "VEN", "DEV", "SUBSYS", "REV", NULL);
 
 	/* add device class */
 	tmp = g_udev_device_get_sysfs_attr(priv->udev_device, "class");
-	if (tmp != NULL && g_str_has_prefix(tmp, "0x")) {
-		g_autofree gchar *class_id = g_utf8_strup(tmp + 2, -1);
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("%s\\VEN_%04X&CLASS_%s", subsystem, priv->vendor, class_id);
-		fu_device_add_instance_id_full(device, devid, FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
-	}
+	if (tmp != NULL && g_str_has_prefix(tmp, "0x"))
+		tmp += 2;
+	fu_device_add_instance_strup(device, "CLASS", tmp);
+	fu_device_build_instance_id_quirk(device, NULL, subsystem, "VEN", "CLASS", NULL);
 
 	/* add devtype */
-	tmp = g_udev_device_get_devtype(priv->udev_device);
-	if (tmp != NULL) {
-		g_autofree gchar *devtype = g_utf8_strup(tmp, -1);
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("%s\\TYPE_%s", subsystem, devtype);
-		fu_device_add_instance_id_full(device, devid, FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
-	}
+	fu_device_add_instance_strup(device, "TYPE", g_udev_device_get_devtype(priv->udev_device));
+	fu_device_build_instance_id_quirk(device, NULL, subsystem, "TYPE", NULL);
 
 	/* add the driver */
-	if (priv->driver != NULL) {
-		g_autofree gchar *devid = NULL;
-		devid = g_strdup_printf("%s\\DRIVER_%s", subsystem, priv->driver);
-		fu_device_add_instance_id_full(device, devid, FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
-	}
+	fu_device_add_instance_str(device, "DRIVER", priv->driver);
+	fu_device_build_instance_id_quirk(device, NULL, subsystem, "DRIVER", NULL);
+
+	/* add the modalias */
+	fu_device_add_instance_strsafe(device,
+				       "MODALIAS",
+				       g_udev_device_get_property(priv->udev_device, "MODALIAS"));
+	fu_device_build_instance_id_quirk(device, NULL, subsystem, "MODALIAS", NULL);
 
 	/* add subsystem to match in plugins */
 	if (subsystem != NULL) {
@@ -934,8 +955,19 @@ fu_udev_device_get_number(FuUdevDevice *self)
 #ifdef HAVE_GUDEV
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
 	g_return_val_if_fail(FU_IS_UDEV_DEVICE(self), 0);
-	if (priv->udev_device != NULL)
-		return fu_common_strtoull(g_udev_device_get_number(priv->udev_device));
+	if (priv->udev_device != NULL) {
+		guint64 tmp = 0;
+		g_autoptr(GError) error_local = NULL;
+		if (!fu_strtoull(g_udev_device_get_number(priv->udev_device),
+				 &tmp,
+				 0x0,
+				 G_MAXUINT64,
+				 &error_local)) {
+			g_warning("failed to convert udev number: %s", error_local->message);
+			return G_MAXUINT64;
+		}
+		return tmp;
+	}
 #endif
 	return G_MAXUINT64;
 }
@@ -950,7 +982,7 @@ fu_udev_device_get_number(FuUdevDevice *self)
  *
  * Since: 1.1.2
  **/
-guint32
+guint16
 fu_udev_device_get_vendor(FuUdevDevice *self)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
@@ -968,7 +1000,7 @@ fu_udev_device_get_vendor(FuUdevDevice *self)
  *
  * Since: 1.1.2
  **/
-guint32
+guint16
 fu_udev_device_get_model(FuUdevDevice *self)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
@@ -986,7 +1018,7 @@ fu_udev_device_get_model(FuUdevDevice *self)
  *
  * Since: 1.5.0
  **/
-guint32
+guint16
 fu_udev_device_get_subsystem_vendor(FuUdevDevice *self)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
@@ -1004,7 +1036,7 @@ fu_udev_device_get_subsystem_vendor(FuUdevDevice *self)
  *
  * Since: 1.5.0
  **/
-guint32
+guint16
 fu_udev_device_get_subsystem_model(FuUdevDevice *self)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
@@ -1054,18 +1086,54 @@ fu_udev_device_get_parent_subsystems(FuUdevDevice *self)
 		g_string_truncate(str, str->len - 1);
 	return g_string_free(str, FALSE);
 }
+
+static gboolean
+fu_udev_device_match_subsystem_devtype(GUdevDevice *udev_device,
+				       const gchar *subsystem,
+				       const gchar *devtype)
+{
+	if (subsystem != NULL) {
+		if (g_strcmp0(g_udev_device_get_subsystem(udev_device), subsystem) != 0)
+			return FALSE;
+	}
+	if (devtype != NULL) {
+		if (g_strcmp0(g_udev_device_get_devtype(udev_device), devtype) != 0)
+			return FALSE;
+	}
+	return TRUE;
+}
+
+static GUdevDevice *
+fu_udev_device_get_parent_with_subsystem_devtype(GUdevDevice *udev_device,
+						 const gchar *subsystem,
+						 const gchar *devtype)
+{
+	g_autoptr(GUdevDevice) udev_device_tmp = g_object_ref(udev_device);
+	while (udev_device_tmp != NULL) {
+		g_autoptr(GUdevDevice) parent = NULL;
+		if (fu_udev_device_match_subsystem_devtype(udev_device_tmp, subsystem, devtype))
+			return g_object_ref(udev_device_tmp);
+		parent = g_udev_device_get_parent(udev_device_tmp);
+		g_set_object(&udev_device_tmp, parent);
+	}
+	return NULL;
+}
 #endif
 
 /**
  * fu_udev_device_set_physical_id:
  * @self: a #FuUdevDevice
- * @subsystems: a subsystem string, e.g. `pci,usb`
+ * @subsystems: a subsystem string, e.g. `pci,usb,scsi:scsi_target`
  * @error: (nullable): optional return location for an error
  *
  * Sets the physical ID from the device subsystem. Plugins should choose the
  * subsystem that is "deepest" in the udev tree, for instance choosing `usb`
  * over `pci` for a mouse device.
  *
+ * The devtype can also be specified for a specific device, which is useful when the
+ * subsystem alone is not enough to identify the physical device. e.g. ignoring the
+ * specific LUNs for a SCSI device.
+ *
  * Returns: %TRUE if the physical device was set.
  *
  * Since: 1.1.2
@@ -1075,9 +1143,9 @@ fu_udev_device_set_physical_id(FuUdevDevice *self, const gchar *subsystems, GErr
 {
 #ifdef HAVE_GUDEV
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
-	const gchar *subsystem = NULL;
 	const gchar *tmp;
 	g_autofree gchar *physical_id = NULL;
+	g_autofree gchar *subsystem = NULL;
 	g_auto(GStrv) split = NULL;
 	g_autoptr(GUdevDevice) udev_device = NULL;
 
@@ -1089,18 +1157,19 @@ fu_udev_device_set_physical_id(FuUdevDevice *self, const gchar *subsystems, GErr
 	if (priv->udev_device == NULL)
 		return TRUE;
 
-	/* look for each subsystem in turn */
+	/* look for each subsystem[:devtype] in turn */
 	split = g_strsplit(subsystems, ",", -1);
 	for (guint i = 0; split[i] != NULL; i++) {
-		subsystem = split[i];
-		if (g_strcmp0(priv->subsystem, subsystem) == 0) {
-			udev_device = g_object_ref(priv->udev_device);
+		g_auto(GStrv) subsys_devtype = g_strsplit(split[i], ":", 2);
+
+		/* matching on devtype is optional */
+		udev_device = fu_udev_device_get_parent_with_subsystem_devtype(priv->udev_device,
+									       subsys_devtype[0],
+									       subsys_devtype[1]);
+		if (udev_device != NULL) {
+			subsystem = g_strdup(subsys_devtype[0]);
 			break;
 		}
-		udev_device =
-		    g_udev_device_get_parent_with_subsystem(priv->udev_device, subsystem, NULL);
-		if (udev_device != NULL)
-			break;
 	}
 	if (udev_device == NULL) {
 		g_autofree gchar *str = fu_udev_device_get_parent_subsystems(self);
@@ -1429,20 +1498,27 @@ fu_udev_device_close(FuDevice *device, GError **error)
  * @request: request number
  * @buf: a buffer to use, which *must* be large enough for the request
  * @rc: (out) (nullable): the raw return value from the ioctl
+ * @timeout: timeout in ms for the retry action, see %FU_UDEV_DEVICE_FLAG_IOCTL_RETRY
  * @error: (nullable): optional return location for an error
  *
  * Control a device using a low-level request.
  *
  * Returns: %TRUE for success
  *
- * Since: 1.3.3
+ * Since: 1.8.2
  **/
 gboolean
-fu_udev_device_ioctl(FuUdevDevice *self, gulong request, guint8 *buf, gint *rc, GError **error)
+fu_udev_device_ioctl(FuUdevDevice *self,
+		     gulong request,
+		     guint8 *buf,
+		     gint *rc,
+		     guint timeout,
+		     GError **error)
 {
 #ifdef HAVE_IOCTL_H
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
 	gint rc_tmp;
+	g_autoptr(GTimer) timer = g_timer_new();
 
 	g_return_val_if_fail(FU_IS_UDEV_DEVICE(self), FALSE);
 	g_return_val_if_fail(request != 0x0, FALSE);
@@ -1460,7 +1536,14 @@ fu_udev_device_ioctl(FuUdevDevice *self, gulong request, guint8 *buf, gint *rc,
 		return FALSE;
 	}
 
-	rc_tmp = ioctl(priv->fd, request, buf);
+	/* poll if required  up to the timeout */
+	do {
+		rc_tmp = ioctl(priv->fd, request, buf);
+		if (rc_tmp >= 0)
+			break;
+	} while ((priv->flags & FU_UDEV_DEVICE_FLAG_IOCTL_RETRY) &&
+		 (errno == EINTR || errno == EAGAIN) &&
+		 g_timer_elapsed(timer, NULL) < timeout * 1000.f);
 	if (rc != NULL)
 		*rc = rc_tmp;
 	if (rc_tmp < 0) {
@@ -1472,11 +1555,19 @@ fu_udev_device_ioctl(FuUdevDevice *self, gulong request, guint8 *buf, gint *rc,
 					    "permission denied");
 			return FALSE;
 		}
+		if (errno == ENOTTY) {
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_NOT_SUPPORTED,
+					    "permission denied");
+			return FALSE;
+		}
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_INTERNAL,
-			    "ioctl error: %s",
-			    strerror(errno));
+			    "ioctl error: %s [%i]",
+			    strerror(errno),
+			    errno);
 #else
 		g_set_error(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "unspecified ioctl error");
 #endif
@@ -1493,7 +1584,7 @@ fu_udev_device_ioctl(FuUdevDevice *self, gulong request, guint8 *buf, gint *rc,
 }
 
 /**
- * fu_udev_device_pread_full:
+ * fu_udev_device_pread:
  * @self: a #FuUdevDevice
  * @port: offset address
  * @buf: (in): data
@@ -1504,14 +1595,10 @@ fu_udev_device_ioctl(FuUdevDevice *self, gulong request, guint8 *buf, gint *rc,
  *
  * Returns: %TRUE for success
  *
- * Since: 1.4.5
+ * Since: 1.8.2
  **/
 gboolean
-fu_udev_device_pread_full(FuUdevDevice *self,
-			  goffset port,
-			  guint8 *buf,
-			  gsize bufsz,
-			  GError **error)
+fu_udev_device_pread(FuUdevDevice *self, goffset port, guint8 *buf, gsize bufsz, GError **error)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
 
@@ -1602,7 +1689,7 @@ fu_udev_device_seek(FuUdevDevice *self, goffset offset, GError **error)
 }
 
 /**
- * fu_udev_device_pwrite_full:
+ * fu_udev_device_pwrite:
  * @self: a #FuUdevDevice
  * @port: offset address
  * @buf: (out): data
@@ -1613,14 +1700,14 @@ fu_udev_device_seek(FuUdevDevice *self, goffset offset, GError **error)
  *
  * Returns: %TRUE for success
  *
- * Since: 1.4.5
+ * Since: 1.8.2
  **/
 gboolean
-fu_udev_device_pwrite_full(FuUdevDevice *self,
-			   goffset port,
-			   const guint8 *buf,
-			   gsize bufsz,
-			   GError **error)
+fu_udev_device_pwrite(FuUdevDevice *self,
+		      goffset port,
+		      const guint8 *buf,
+		      gsize bufsz,
+		      GError **error)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
 
@@ -1658,25 +1745,6 @@ fu_udev_device_pwrite_full(FuUdevDevice *self,
 #endif
 }
 
-/**
- * fu_udev_device_pwrite:
- * @self: a #FuUdevDevice
- * @port: offset address
- * @data: value
- * @error: (nullable): optional return location for an error
- *
- * Write to a file descriptor at a given offset.
- *
- * Returns: %TRUE for success
- *
- * Since: 1.3.3
- **/
-gboolean
-fu_udev_device_pwrite(FuUdevDevice *self, goffset port, guint8 data, GError **error)
-{
-	return fu_udev_device_pwrite_full(self, port, &data, 0x01, error);
-}
-
 /**
  * fu_udev_device_get_parent_name
  * @self: a #FuUdevDevice
@@ -1743,7 +1811,10 @@ fu_udev_device_get_sysfs_attr(FuUdevDevice *self, const gchar *attr, GError **er
 
 	return result;
 #else
-	g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_FAILED, "not supported");
+	g_set_error_literal(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_FAILED,
+			    "getting attributes is not supported as no GUdev support");
 	return NULL;
 #endif
 }
@@ -1768,7 +1839,6 @@ fu_udev_device_get_sysfs_attr_uint64(FuUdevDevice *self,
 				     GError **error)
 {
 	const gchar *tmp;
-	guint64 tmp64;
 
 	g_return_val_if_fail(FU_IS_UDEV_DEVICE(self), FALSE);
 	g_return_val_if_fail(attr != NULL, FALSE);
@@ -1777,29 +1847,7 @@ fu_udev_device_get_sysfs_attr_uint64(FuUdevDevice *self,
 	tmp = fu_udev_device_get_sysfs_attr(self, attr, error);
 	if (tmp == NULL)
 		return FALSE;
-	tmp64 = fu_common_strtoull(tmp);
-	if (value != NULL)
-		*value = tmp64;
-	return TRUE;
-}
-
-/**
- * fu_udev_device_pread:
- * @self: a #FuUdevDevice
- * @port: offset address
- * @data: (out): value
- * @error: (nullable): optional return location for an error
- *
- * Read from a file descriptor at a given offset.
- *
- * Returns: %TRUE for success
- *
- * Since: 1.3.3
- **/
-gboolean
-fu_udev_device_pread(FuUdevDevice *self, goffset port, guint8 *data, GError **error)
-{
-	return fu_udev_device_pread_full(self, port, data, 0x1, error);
+	return fu_strtoull(tmp, value, 0, G_MAXUINT64, error);
 }
 
 /**
@@ -1940,8 +1988,8 @@ fu_udev_device_get_siblings_with_subsystem(FuUdevDevice *self, const gchar *cons
 		 * located device's parent, they are siblings */
 		if (g_strcmp0(udev_parent_path, enumerated_parent_path) == 0) {
 			FuUdevDevice *dev =
-			    fu_udev_device_new_with_context(fu_device_get_context(FU_DEVICE(self)),
-							    g_steal_pointer(&enumerated_device));
+			    fu_udev_device_new(fu_device_get_context(FU_DEVICE(self)),
+					       g_steal_pointer(&enumerated_device));
 			g_ptr_array_add(out, dev);
 		}
 	}
@@ -1971,7 +2019,7 @@ fu_udev_device_get_parent_with_subsystem(FuUdevDevice *self, const gchar *subsys
 	device_tmp = g_udev_device_get_parent_with_subsystem(priv->udev_device, subsystem, NULL);
 	if (device_tmp == NULL)
 		return NULL;
-	return fu_udev_device_new_with_context(fu_device_get_context(FU_DEVICE(self)), device_tmp);
+	return fu_udev_device_new(fu_device_get_context(FU_DEVICE(self)), device_tmp);
 #else
 	return NULL;
 #endif
@@ -2014,8 +2062,8 @@ fu_udev_device_get_children_with_subsystem(FuUdevDevice *self, const gchar *cons
 		 * same as self */
 		if (g_strcmp0(self_path, enumerated_parent_path) == 0) {
 			FuUdevDevice *dev =
-			    fu_udev_device_new_with_context(fu_device_get_context(FU_DEVICE(self)),
-							    g_steal_pointer(&enumerated_device));
+			    fu_udev_device_new(fu_device_get_context(FU_DEVICE(self)),
+					       g_steal_pointer(&enumerated_device));
 			g_ptr_array_add(out, dev);
 		}
 	}
@@ -2100,6 +2148,7 @@ fu_udev_device_init(FuUdevDevice *self)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
 	priv->flags = FU_UDEV_DEVICE_FLAG_OPEN_READ | FU_UDEV_DEVICE_FLAG_OPEN_WRITE;
+	fu_device_set_acquiesce_delay(FU_DEVICE(self), 2500);
 }
 
 static void
@@ -2211,7 +2260,7 @@ fu_udev_device_class_init(FuUdevDeviceClass *klass)
 }
 
 /**
- * fu_udev_device_new_with_context:
+ * fu_udev_device_new:
  * @ctx: (nullable): a #FuContext
  * @udev_device: a #GUdevDevice
  *
@@ -2219,37 +2268,10 @@ fu_udev_device_class_init(FuUdevDeviceClass *klass)
  *
  * Returns: (transfer full): a #FuUdevDevice
  *
- * Since: 1.7.1
+ * Since: 1.8.2
  **/
 FuUdevDevice *
-fu_udev_device_new_with_context(FuContext *ctx, GUdevDevice *udev_device)
+fu_udev_device_new(FuContext *ctx, GUdevDevice *udev_device)
 {
-#ifdef HAVE_GUDEV
-	/* create the correct object depending on the subsystem */
-	if (g_strcmp0(g_udev_device_get_subsystem(udev_device), "i2c-dev") == 0) {
-		return g_object_new(FU_TYPE_I2C_DEVICE,
-				    "context",
-				    ctx,
-				    "udev-device",
-				    udev_device,
-				    NULL);
-	}
-#endif
 	return g_object_new(FU_TYPE_UDEV_DEVICE, "context", ctx, "udev-device", udev_device, NULL);
 }
-
-/**
- * fu_udev_device_new:
- * @udev_device: a #GUdevDevice
- *
- * Creates a new #FuUdevDevice.
- *
- * Returns: (transfer full): a #FuUdevDevice
- *
- * Since: 1.1.2
- **/
-FuUdevDevice *
-fu_udev_device_new(GUdevDevice *udev_device)
-{
-	return fu_udev_device_new_with_context(NULL, udev_device);
-}
