@@ -306,17 +306,19 @@ static void
 fu_ccgx_dmc_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuCcgxDmcDevice *self = FU_CCGX_DMC_DEVICE(device);
-	fu_common_string_append_kv(str,
-				   idt,
-				   "UpdateModel",
-				   fu_ccgx_dmc_update_model_type_to_string(self->update_model));
-	fu_common_string_append_kv(str,
-				   idt,
-				   "FwImageType",
-				   fu_ccgx_fw_image_type_to_string(self->fw_image_type));
-	fu_common_string_append_kx(str, idt, "EpBulkOut", self->ep_bulk_out);
-	fu_common_string_append_kx(str, idt, "EpIntrIn", self->ep_intr_in);
-	fu_common_string_append_kx(str, idt, "TriggerCode", self->trigger_code);
+	fu_string_append(str,
+			 idt,
+			 "UpdateModel",
+			 fu_ccgx_dmc_update_model_type_to_string(self->update_model));
+	if (self->fw_image_type != FW_IMAGE_TYPE_UNKNOWN) {
+		fu_string_append(str,
+				 idt,
+				 "FwImageType",
+				 fu_ccgx_fw_image_type_to_string(self->fw_image_type));
+	}
+	fu_string_append_kx(str, idt, "EpBulkOut", self->ep_bulk_out);
+	fu_string_append_kx(str, idt, "EpIntrIn", self->ep_intr_in);
+	fu_string_append_kx(str, idt, "TriggerCode", self->trigger_code);
 }
 
 static gboolean
@@ -364,8 +366,8 @@ fu_ccgx_dmc_write_firmware_record(FuCcgxDmcDevice *self,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 99);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 99, NULL);
 
 	/* write start row and number of rows to a device */
 	if (!fu_ccgx_dmc_device_send_write_command(self,
@@ -463,9 +465,9 @@ fu_ccgx_dmc_write_firmware(FuDevice *device,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 1, "fwct");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98, "img");
 
 	/* get fwct record */
 	fwct_blob = fu_ccgx_dmc_firmware_get_fwct_record(FU_CCGX_DMC_FIRMWARE(firmware));
@@ -616,33 +618,36 @@ fu_ccgx_dmc_device_attach(FuDevice *device, FuProgress *progress, GError **error
 	if (fu_device_get_update_state(self) != FWUPD_UPDATE_STATE_SUCCESS)
 		return TRUE;
 
+	if (manual_replug) {
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION);
+		fu_device_add_problem(device, FWUPD_DEVICE_PROBLEM_UPDATE_PENDING);
+	} else {
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
+	}
+
 	if (self->update_model == DMC_UPDATE_MODEL_DOWNLOAD_TRIGGER) {
 		if (self->trigger_code > 0) {
 			if (!fu_ccgx_dmc_device_send_download_trigger(self,
 								      self->trigger_code,
 								      error)) {
+				if (manual_replug == FALSE) {
+					fu_device_remove_flag(device,
+							      FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
+				}
 				g_prefix_error(error, "download trigger error: ");
 				return FALSE;
 			}
 		}
 	} else if (self->update_model == DMC_UPDATE_MODEL_PENDING_RESET) {
 		if (!fu_ccgx_dmc_device_send_sort_reset(self, manual_replug, error)) {
+			if (manual_replug == FALSE) {
+				fu_device_remove_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
+			}
 			g_prefix_error(error, "soft reset error: ");
 			return FALSE;
 		}
 	}
 
-	if (manual_replug) {
-		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION);
-		fu_device_inhibit(device,
-				  "update-pending",
-				  "A pending update will be completed next time the device "
-				  "is unplugged from your computer");
-		return TRUE;
-	}
-
-	fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
-
 	return TRUE;
 }
 
@@ -680,7 +685,7 @@ fu_ccgx_dmc_device_setup(FuDevice *device, GError **error)
 
 	/* set composite version */
 	version_raw = dock_status.composite_version;
-	version = fu_common_version_from_uint32(version_raw, FWUPD_VERSION_FORMAT_QUAD);
+	version = fu_version_from_uint32(version_raw, FWUPD_VERSION_FORMAT_QUAD);
 	fu_device_set_version(FU_DEVICE(self), version);
 	fu_device_set_version_raw(FU_DEVICE(self), version_raw);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
@@ -703,7 +708,7 @@ fu_ccgx_dmc_device_set_quirk_kv(FuDevice *device,
 	guint64 tmp;
 
 	if (g_strcmp0(key, "CcgxDmcTriggerCode") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT16, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT16, error))
 			return FALSE;
 		self->trigger_code = tmp;
 		return TRUE;
@@ -723,14 +728,14 @@ fu_ccgx_dmc_device_set_quirk_kv(FuDevice *device,
 }
 
 static void
-fu_ccgx_hid_device_set_progress(FuDevice *self, FuProgress *progress)
+fu_ccgx_dmc_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_NO_PROFILE);	/* actually 0, 20, 0, 80! */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 75);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 25);	/* reload */
+	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_NO_PROFILE); /* actually 0, 20, 0, 80! */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 75, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 25, "reload");
 }
 
 static void
@@ -745,6 +750,7 @@ fu_ccgx_dmc_device_init(FuCcgxDmcDevice *self)
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_DUAL_IMAGE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SELF_RECOVERY);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_ONLY_WAIT_FOR_REPLUG);
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_CCGX_DMC_DEVICE_FLAG_HAS_MANUAL_REPLUG,
 					"has-manual-replug");
@@ -760,5 +766,5 @@ fu_ccgx_dmc_device_class_init(FuCcgxDmcDeviceClass *klass)
 	klass_device->attach = fu_ccgx_dmc_device_attach;
 	klass_device->setup = fu_ccgx_dmc_device_setup;
 	klass_device->set_quirk_kv = fu_ccgx_dmc_device_set_quirk_kv;
-	klass_device->set_progress = fu_ccgx_hid_device_set_progress;
+	klass_device->set_progress = fu_ccgx_dmc_device_set_progress;
 }
