@@ -154,10 +154,6 @@ fu_cros_ec_usb_device_probe(FuDevice *device, GError **error)
 {
 	FuCrosEcUsbDevice *self = FU_CROS_EC_USB_DEVICE(device);
 
-	/* FuUsbDevice->probe */
-	if (!FU_DEVICE_CLASS(fu_cros_ec_usb_device_parent_class)->probe(device, error))
-		return FALSE;
-
 	/* very much like usb_updater2's usb_findit() */
 
 	if (!fu_cros_ec_usb_device_find_interface(FU_USB_DEVICE(device), error)) {
@@ -768,6 +764,29 @@ fu_cros_ec_usb_device_jump_to_rw(FuDevice *device)
 	return TRUE;
 }
 
+static gboolean
+fu_cros_ec_usb_device_stay_in_ro(FuDevice *device, GError **error)
+{
+	gsize response_size = 1;
+	guint8 response;
+	guint16 subcommand = UPDATE_EXTRA_CMD_STAY_IN_RO;
+	guint8 command_body[2]; /* Max command body size. */
+	gsize command_body_size = 0;
+
+	if (!fu_cros_ec_usb_device_send_subcommand(device,
+						   subcommand,
+						   command_body,
+						   command_body_size,
+						   &response,
+						   &response_size,
+						   FALSE,
+						   error)) {
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 static gboolean
 fu_cros_ec_usb_device_write_firmware(FuDevice *device,
 				     FuFirmware *firmware,
@@ -782,22 +801,10 @@ fu_cros_ec_usb_device_write_firmware(FuDevice *device,
 	fu_device_remove_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_SPECIAL);
 
 	if (fu_device_has_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_REBOOTING_TO_RO)) {
-		gsize response_size = 1;
-		guint8 response;
-		guint16 subcommand = UPDATE_EXTRA_CMD_STAY_IN_RO;
-		guint8 command_body[2]; /* Max command body size. */
-		gsize command_body_size = 0;
 		START_RESP start_resp;
 
 		fu_device_remove_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_REBOOTING_TO_RO);
-		if (!fu_cros_ec_usb_device_send_subcommand(device,
-							   subcommand,
-							   command_body,
-							   command_body_size,
-							   &response,
-							   &response_size,
-							   FALSE,
-							   error)) {
+		if (!fu_cros_ec_usb_device_stay_in_ro(device, error)) {
 			g_prefix_error(error, "failed to send stay-in-ro subcommand: ");
 			return FALSE;
 		}
@@ -964,6 +971,8 @@ fu_cros_ec_usb_device_detach(FuDevice *device, FuProgress *progress, GError **er
 		return TRUE;
 
 	if (self->in_bootloader) {
+		/* If EC just rebooted - prevent jumping to RW during the update */
+		fu_device_add_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_REBOOTING_TO_RO);
 		g_debug("skipping immediate reboot in case of already in bootloader");
 		/* in RO so skip reboot */
 		return TRUE;
@@ -1009,20 +1018,17 @@ fu_cros_ec_usb_device_to_string(FuDevice *device, guint idt, GString *str)
 	FuCrosEcUsbDevice *self = FU_CROS_EC_USB_DEVICE(device);
 	g_autofree gchar *min_rollback = NULL;
 
-	fu_common_string_append_kv(str, idt, "GitHash", self->version.sha1);
-	fu_common_string_append_kb(str, idt, "Dirty", self->version.dirty);
-	fu_common_string_append_ku(str, idt, "ProtocolVersion", self->protocol_version);
-	fu_common_string_append_ku(str, idt, "HeaderType", self->header_type);
-	fu_common_string_append_ku(str, idt, "MaxPDUSize", self->targ.common.maximum_pdu_size);
-	fu_common_string_append_kx(str,
-				   idt,
-				   "FlashProtectionStatus",
-				   self->targ.common.flash_protection);
-	fu_common_string_append_kv(str, idt, "RawVersion", self->targ.common.version);
-	fu_common_string_append_ku(str, idt, "KeyVersion", self->targ.common.key_version);
+	fu_string_append(str, idt, "GitHash", self->version.sha1);
+	fu_string_append_kb(str, idt, "Dirty", self->version.dirty);
+	fu_string_append_ku(str, idt, "ProtocolVersion", self->protocol_version);
+	fu_string_append_ku(str, idt, "HeaderType", self->header_type);
+	fu_string_append_ku(str, idt, "MaxPDUSize", self->targ.common.maximum_pdu_size);
+	fu_string_append_kx(str, idt, "FlashProtectionStatus", self->targ.common.flash_protection);
+	fu_string_append(str, idt, "RawVersion", self->targ.common.version);
+	fu_string_append_ku(str, idt, "KeyVersion", self->targ.common.key_version);
 	min_rollback = g_strdup_printf("%" G_GINT32_FORMAT, self->targ.common.min_rollback);
-	fu_common_string_append_kv(str, idt, "MinRollback", min_rollback);
-	fu_common_string_append_kx(str, idt, "WriteableOffset", self->writeable_offset);
+	fu_string_append(str, idt, "MinRollback", min_rollback);
+	fu_string_append_kx(str, idt, "WriteableOffset", self->writeable_offset);
 }
 
 static void
@@ -1030,10 +1036,10 @@ fu_cros_ec_usb_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
