@@ -20,10 +20,8 @@
 #include "fu-dell-dock-common.h"
 
 static void
-fu_plugin_dell_dock_init(FuPlugin *plugin)
+fu_plugin_dell_dock_load(FuContext *ctx)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
-
 	fu_context_add_quirk_key(ctx, "DellDockBlobBuildOffset");
 	fu_context_add_quirk_key(ctx, "DellDockBlobMajorOffset");
 	fu_context_add_quirk_key(ctx, "DellDockBlobMinorOffset");
@@ -33,7 +31,11 @@ fu_plugin_dell_dock_init(FuPlugin *plugin)
 	fu_context_add_quirk_key(ctx, "DellDockInstallDurationI2C");
 	fu_context_add_quirk_key(ctx, "DellDockUnlockTarget");
 	fu_context_add_quirk_key(ctx, "DellDockVersionLowest");
+}
 
+static void
+fu_plugin_dell_dock_init(FuPlugin *plugin)
+{
 	/* allow these to be built by quirks */
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_DELL_DOCK_STATUS);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_DELL_DOCK_MST);
@@ -47,10 +49,8 @@ fu_plugin_dell_dock_init(FuPlugin *plugin)
 static gboolean
 fu_plugin_dell_dock_create_node(FuPlugin *plugin, FuDevice *device, GError **error)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
 	g_autoptr(FuDeviceLocker) locker = NULL;
 
-	fu_device_set_context(device, ctx);
 	locker = fu_device_locker_new(device, error);
 	if (locker == NULL)
 		return FALSE;
@@ -63,7 +63,10 @@ fu_plugin_dell_dock_create_node(FuPlugin *plugin, FuDevice *device, GError **err
 static gboolean
 fu_plugin_dell_dock_probe(FuPlugin *plugin, FuDevice *proxy, GError **error)
 {
-	const gchar *instance;
+	const gchar *instance_id_mst;
+	const gchar *instance_id_status;
+	g_autofree const gchar *instance_guid_mst = NULL;
+	g_autofree const gchar *instance_guid_status = NULL;
 	g_autoptr(FuDellDockEc) ec_device = NULL;
 	g_autoptr(FuDellDockMst) mst_device = NULL;
 	g_autoptr(FuDellDockStatus) status_device = NULL;
@@ -75,36 +78,41 @@ fu_plugin_dell_dock_probe(FuPlugin *plugin, FuDevice *proxy, GError **error)
 		return FALSE;
 
 	/* create mst endpoint */
-	mst_device = fu_dell_dock_mst_new();
-	if (fu_dell_dock_get_ec_type(FU_DEVICE(ec_device)) == ATOMIC_BASE)
-		instance = DELL_DOCK_VMM6210_INSTANCE_ID;
+	mst_device = fu_dell_dock_mst_new(ctx);
+	if (fu_dell_dock_get_dock_type(FU_DEVICE(ec_device)) == DOCK_BASE_TYPE_ATOMIC)
+		instance_id_mst = DELL_DOCK_VMM6210_INSTANCE_ID;
 	else
-		instance = DELL_DOCK_VM5331_INSTANCE_ID;
-	fu_device_set_context(FU_DEVICE(mst_device), ctx);
-	fu_device_add_guid(FU_DEVICE(mst_device), fwupd_guid_hash_string(instance));
+		instance_id_mst = DELL_DOCK_VM5331_INSTANCE_ID;
+	fu_device_add_instance_id(FU_DEVICE(mst_device), instance_id_mst);
+	instance_guid_mst = fwupd_guid_hash_string(instance_id_mst);
+	fu_device_add_guid(FU_DEVICE(mst_device), instance_guid_mst);
+	if (!fu_device_probe(FU_DEVICE(mst_device), error))
+		return FALSE;
 	fu_device_add_child(FU_DEVICE(ec_device), FU_DEVICE(mst_device));
-	fu_device_add_instance_id(FU_DEVICE(mst_device), instance);
 	if (!fu_plugin_dell_dock_create_node(plugin, FU_DEVICE(mst_device), error))
 		return FALSE;
 
 	/* create package version endpoint */
-	status_device = fu_dell_dock_status_new();
-	if (fu_dell_dock_get_ec_type(FU_DEVICE(ec_device)) == ATOMIC_BASE)
-		instance = DELL_DOCK_ATOMIC_STATUS_INSTANCE_ID;
+	status_device = fu_dell_dock_status_new(ctx);
+	if (fu_dell_dock_get_dock_type(FU_DEVICE(ec_device)) == DOCK_BASE_TYPE_ATOMIC)
+		instance_id_status = DELL_DOCK_ATOMIC_STATUS_INSTANCE_ID;
 	else if (fu_dell_dock_module_is_usb4(FU_DEVICE(ec_device)))
-		instance = DELL_DOCK_DOCK2_INSTANCE_ID;
+		instance_id_status = DELL_DOCK_DOCK2_INSTANCE_ID;
 	else
-		instance = DELL_DOCK_DOCK1_INSTANCE_ID;
-	fu_device_set_context(FU_DEVICE(status_device), ctx);
-	fu_device_add_guid(FU_DEVICE(status_device), fwupd_guid_hash_string(instance));
+		instance_id_status = DELL_DOCK_DOCK1_INSTANCE_ID;
+	instance_guid_status = fwupd_guid_hash_string(instance_id_status);
+	fu_device_add_guid(FU_DEVICE(status_device), fwupd_guid_hash_string(instance_guid_status));
 	fu_device_add_child(FU_DEVICE(ec_device), FU_DEVICE(status_device));
-	fu_device_add_instance_id(FU_DEVICE(status_device), instance);
+	fu_device_add_instance_id(FU_DEVICE(status_device), instance_id_status);
 	if (!fu_plugin_dell_dock_create_node(plugin, FU_DEVICE(status_device), error))
 		return FALSE;
 
 	/* create TBT endpoint if Thunderbolt SKU and Thunderbolt link inactive */
 	if (fu_dell_dock_ec_needs_tbt(FU_DEVICE(ec_device))) {
 		g_autoptr(FuDellDockTbt) tbt_device = fu_dell_dock_tbt_new(proxy);
+		g_autofree const gchar *instance_guid_tbt =
+		    fwupd_guid_hash_string(DELL_DOCK_TBT_INSTANCE_ID);
+		fu_device_add_guid(FU_DEVICE(tbt_device), instance_guid_tbt);
 		fu_device_add_child(FU_DEVICE(ec_device), FU_DEVICE(tbt_device));
 		if (!fu_plugin_dell_dock_create_node(plugin, FU_DEVICE(tbt_device), error))
 			return FALSE;
@@ -136,11 +144,13 @@ fu_plugin_dell_dock_backend_device_added(FuPlugin *plugin, FuDevice *device, GEr
 {
 	g_autoptr(FuDeviceLocker) locker = NULL;
 	g_autoptr(FuDellDockHub) hub = NULL;
-	const gchar *key = NULL;
+	const gchar *hub_cache_key = "hub-usb3-gen1";
 	GPtrArray *devices;
 	FuDevice *ec_device;
+	FuDevice *hub_dev;
 	guint device_vid;
 	guint device_pid;
+	guint8 dock_type;
 
 	/* not interesting */
 	if (!FU_IS_USB_DEVICE(device))
@@ -169,27 +179,39 @@ fu_plugin_dell_dock_backend_device_added(FuPlugin *plugin, FuDevice *device, GEr
 	if (locker == NULL)
 		return FALSE;
 
+	/* probe extend devices under Usb3.1 Gen 2 Hub */
 	if (fu_device_has_private_flag(FU_DEVICE(hub), FU_DELL_DOCK_HUB_FLAG_HAS_BRIDGE)) {
-		/* only add the device with parent to cache */
-		key = fu_device_get_id(FU_DEVICE(hub));
-		if (fu_plugin_cache_lookup(plugin, key) != NULL) {
-			g_debug("Ignoring already added device %s", key);
-			return TRUE;
-		}
-		/* probe for extended devices */
 		if (!fu_plugin_dell_dock_probe(plugin, FU_DEVICE(hub), error))
 			return FALSE;
-		fu_plugin_cache_add(plugin, key, FU_DEVICE(hub));
 	}
 
-	/* add hub instance id after ec probed */
+	/* process hub devices if ec device is added */
 	devices = fu_plugin_get_devices(plugin);
 	ec_device = fu_plugin_dell_dock_get_ec(devices);
-	if (ec_device != NULL) {
-		guint8 ec_type = fu_dell_dock_get_ec_type(ec_device);
-		fu_dell_dock_hub_add_instance(FU_DEVICE(hub), ec_type);
+	if (ec_device == NULL) {
+		fu_plugin_cache_add(plugin, hub_cache_key, FU_DEVICE(hub));
+		return TRUE;
 	}
+
+	/* determine dock type by ec */
+	dock_type = fu_dell_dock_get_dock_type(ec_device);
+	if (dock_type == DOCK_BASE_TYPE_UNKNOWN) {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_READ,
+			    "can't read base dock type from EC");
+		return FALSE;
+	}
+	fu_dell_dock_hub_add_instance(FU_DEVICE(hub), dock_type);
 	fu_plugin_device_add(plugin, FU_DEVICE(hub));
+
+	/* add hub instance id for the cached device */
+	hub_dev = fu_plugin_cache_lookup(plugin, hub_cache_key);
+	if (hub_dev != NULL) {
+		fu_dell_dock_hub_add_instance(FU_DEVICE(hub_dev), dock_type);
+		fu_plugin_device_add(plugin, FU_DEVICE(hub_dev));
+		fu_plugin_cache_remove(plugin, hub_cache_key);
+	}
 	return TRUE;
 }
 
@@ -223,13 +245,17 @@ fu_plugin_dell_dock_separate_activation(FuPlugin *plugin)
 static void
 fu_plugin_dell_dock_device_registered(FuPlugin *plugin, FuDevice *device)
 {
+	/* dell dock delays the activation so skips device restart */
+	if (fu_device_has_guid(device, DELL_DOCK_TBT_INSTANCE_ID))
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_SKIPS_RESTART);
+
 	/* usb4 device from thunderbolt plugin */
 	if (g_strcmp0(fu_device_get_plugin(device), "thunderbolt") == 0 &&
 	    fu_device_has_guid(device, DELL_DOCK_USB4_INSTANCE_ID)) {
 		g_autofree gchar *msg = NULL;
 		msg = g_strdup_printf("firmware update inhibited by [%s] plugin",
 				      fu_plugin_get_name(plugin));
-		fu_device_inhibit(device, "usb4-blocked", msg);
+		fu_device_inhibit(device, "hidden", msg);
 		return;
 	}
 
@@ -331,6 +357,7 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_dell_dock_load;
 	vfuncs->init = fu_plugin_dell_dock_init;
 	vfuncs->device_registered = fu_plugin_dell_dock_device_registered;
 	vfuncs->backend_device_added = fu_plugin_dell_dock_backend_device_added;
