@@ -7,16 +7,14 @@
 
 #include "config.h"
 
+#include <fwupdplugin.h>
+
 #include <fcntl.h>
 #include <glib/gstdio.h>
 #include <smbios_c/system_info.h>
 #include <string.h>
-#include <unistd.h>
-
-#ifdef HAVE_TSS2
 #include <tss2/tss2_esys.h>
-#endif
-#include <fwupdplugin.h>
+#include <unistd.h>
 
 #include "fu-plugin-dell.h"
 
@@ -115,13 +113,13 @@ static guint16
 fu_dell_get_system_id(FuPlugin *plugin)
 {
 	FuContext *ctx = fu_plugin_get_context(plugin);
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	const gchar *system_id_str = NULL;
 	guint16 system_id = 0;
 	gchar *endptr = NULL;
 
 	/* don't care for test suite */
-	if (data->smi_obj->fake_smbios)
+	if (priv->smi_obj->fake_smbios)
 		return 0;
 
 	system_id_str = fu_context_get_hwid_value(ctx, FU_HWIDS_KEY_PRODUCT_SKU);
@@ -216,24 +214,24 @@ fu_plugin_dell_inject_fake_data(FuPlugin *plugin,
 				guint8 *buf,
 				gboolean can_switch_modes)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 
-	if (!data->smi_obj->fake_smbios)
+	if (!priv->smi_obj->fake_smbios)
 		return;
 	for (guint i = 0; i < 4; i++)
-		data->smi_obj->output[i] = output[i];
-	data->fake_vid = vid;
-	data->fake_pid = pid;
-	data->smi_obj->fake_buffer = buf;
-	data->can_switch_modes = TRUE;
+		priv->smi_obj->output[i] = output[i];
+	priv->fake_vid = vid;
+	priv->fake_pid = pid;
+	priv->smi_obj->fake_buffer = buf;
+	priv->can_switch_modes = TRUE;
 }
 
 static gboolean
 fu_plugin_dell_capsule_supported(FuPlugin *plugin)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 
-	return data->smi_obj->fake_smbios || data->capsule_supported;
+	return priv->smi_obj->fake_smbios || priv->capsule_supported;
 }
 
 static gboolean
@@ -256,7 +254,7 @@ fu_plugin_dock_node(FuPlugin *plugin,
 		return FALSE;
 	}
 
-	dev = fu_device_new_with_context(ctx);
+	dev = fu_device_new(ctx);
 	fu_device_set_physical_id(dev, platform);
 	fu_device_set_logical_id(dev, component_guid);
 	if (component_desc != NULL) {
@@ -293,7 +291,7 @@ fu_plugin_dock_node(FuPlugin *plugin,
 gboolean
 fu_plugin_dell_backend_device_added(FuPlugin *plugin, FuDevice *device, GError **error)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	FwupdVersionFormat version_format = FWUPD_VERSION_FORMAT_DELL_BIOS;
 	guint16 pid;
 	guint16 vid;
@@ -317,13 +315,13 @@ fu_plugin_dell_backend_device_added(FuPlugin *plugin, FuDevice *device, GError *
 
 	/* don't look up immediately if a dock is connected as that would
 	   mean a SMI on every USB device that showed up on the system */
-	if (!data->smi_obj->fake_smbios) {
+	if (!priv->smi_obj->fake_smbios) {
 		vid = fu_usb_device_get_vid(FU_USB_DEVICE(device));
 		pid = fu_usb_device_get_pid(FU_USB_DEVICE(device));
 		platform = fu_device_get_physical_id(FU_DEVICE(device));
 	} else {
-		vid = data->fake_vid;
-		pid = data->fake_pid;
+		vid = priv->fake_vid;
+		pid = priv->fake_pid;
 		platform = "fake";
 	}
 
@@ -339,7 +337,7 @@ fu_plugin_dell_backend_device_added(FuPlugin *plugin, FuDevice *device, GError *
 	}
 
 	buf.buf = NULL;
-	if (!fu_dell_query_dock(data->smi_obj, &buf)) {
+	if (!fu_dell_query_dock(priv->smi_obj, &buf)) {
 		g_debug("no dock detected");
 		return TRUE;
 	}
@@ -412,8 +410,8 @@ fu_plugin_dell_backend_device_added(FuPlugin *plugin, FuDevice *device, GError *
 			continue;
 		}
 
-		fw_str = fu_common_version_from_uint32(dock_info->components[i].fw_version,
-						       version_format);
+		fw_str =
+		    fu_version_from_uint32(dock_info->components[i].fw_version, version_format);
 		if (!fu_plugin_dock_node(plugin,
 					 platform,
 					 buf.record->dock_info_header.dock_type,
@@ -433,7 +431,7 @@ fu_plugin_dell_backend_device_added(FuPlugin *plugin, FuDevice *device, GError *
 	/* if an old EC or invalid EC version found, create updatable parent */
 	if (old_ec)
 		flash_ver_str =
-		    fu_common_version_from_uint32(dock_info->flash_pkg_version, version_format);
+		    fu_version_from_uint32(dock_info->flash_pkg_version, version_format);
 	if (!fu_plugin_dock_node(plugin,
 				 platform,
 				 buf.record->dock_info_header.dock_type,
@@ -539,7 +537,6 @@ fu_plugin_dell_get_results(FuPlugin *plugin, FuDevice *device, GError **error)
 	return TRUE;
 }
 
-#ifdef HAVE_TSS2
 static void
 Esys_Finalize_autoptr_cleanup(ESYS_CONTEXT *esys_context)
 {
@@ -587,14 +584,12 @@ fu_plugin_dell_get_tpm_capability(ESYS_CONTEXT *ctx, guint32 query)
 			result[i] = 0x20;
 	}
 
-	return fu_common_strstrip(result);
+	return fu_strstrip(result);
 }
-#endif
 
 static gboolean
 fu_plugin_dell_add_tpm_model(FuDevice *dev, GError **error)
 {
-#ifdef HAVE_TSS2
 	TSS2_RC rc;
 	const gchar *base = "DELL-TPM";
 	g_autoptr(ESYS_CONTEXT) ctx = NULL;
@@ -667,7 +662,7 @@ fu_plugin_dell_add_tpm_model(FuDevice *dev, GError **error)
 	fu_device_add_instance_id(dev, v1_v2);
 	fu_device_add_instance_id(dev, v1_v2_v3);
 	fu_device_add_instance_id(dev, v1_v2_v3_v4);
-#endif
+
 	return TRUE;
 }
 
@@ -675,7 +670,7 @@ gboolean
 fu_plugin_dell_detect_tpm(FuPlugin *plugin, GError **error)
 {
 	FuContext *ctx = fu_plugin_get_context(plugin);
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	const gchar *tpm_mode;
 	const gchar *tpm_mode_alt;
 	guint16 system_id = 0;
@@ -693,12 +688,12 @@ fu_plugin_dell_detect_tpm(FuPlugin *plugin, GError **error)
 	g_autoptr(FuDevice) dev = NULL;
 	g_autoptr(GError) error_tss = NULL;
 
-	fu_dell_clear_smi(data->smi_obj);
-	out = (struct tpm_status *)data->smi_obj->output;
+	fu_dell_clear_smi(priv->smi_obj);
+	out = (struct tpm_status *)priv->smi_obj->output;
 
 	/* execute TPM Status Query */
-	data->smi_obj->input[0] = DACI_FLASH_ARG_TPM;
-	if (!fu_dell_execute_simple_smi(data->smi_obj,
+	priv->smi_obj->input[0] = DACI_FLASH_ARG_TPM;
+	if (!fu_dell_execute_simple_smi(priv->smi_obj,
 					DACI_FLASH_INTERFACE_CLASS,
 					DACI_FLASH_INTERFACE_SELECT))
 		return FALSE;
@@ -712,7 +707,7 @@ fu_plugin_dell_detect_tpm(FuPlugin *plugin, GError **error)
 	/* HW version is output in second /input/ arg
 	 * it may be relevant as next gen TPM is enabled
 	 */
-	g_debug("TPM HW version: 0x%x", data->smi_obj->input[1]);
+	g_debug("TPM HW version: 0x%x", priv->smi_obj->input[1]);
 	g_debug("TPM Status: 0x%x", out->status);
 
 	/* test TPM enabled (Bit 0) */
@@ -734,8 +729,8 @@ fu_plugin_dell_detect_tpm(FuPlugin *plugin, GError **error)
 	}
 
 	system_id = fu_dell_get_system_id(plugin);
-	if (data->smi_obj->fake_smbios)
-		can_switch_modes = data->can_switch_modes;
+	if (priv->smi_obj->fake_smbios)
+		can_switch_modes = priv->can_switch_modes;
 	else if (system_id == 0)
 		return FALSE;
 
@@ -755,14 +750,14 @@ fu_plugin_dell_detect_tpm(FuPlugin *plugin, GError **error)
 	g_debug("Creating primary TPM GUID %s and secondary TPM GUID %s",
 		tpm_guid_raw,
 		tpm_guid_raw_alt);
-	version_str = fu_common_version_from_uint32(out->fw_version, FWUPD_VERSION_FORMAT_QUAD);
+	version_str = fu_version_from_uint32(out->fw_version, FWUPD_VERSION_FORMAT_QUAD);
 
 	/* make it clear that the TPM is a discrete device of the product */
 	pretty_tpm_name = g_strdup_printf("TPM %s", tpm_mode);
 	pretty_tpm_name_alt = g_strdup_printf("TPM %s", tpm_mode_alt);
 
 	/* build Standard device nodes */
-	dev = fu_device_new_with_context(ctx);
+	dev = fu_device_new(ctx);
 	fu_device_set_physical_id(dev, "DEVNAME=/dev/tpm0");
 	fu_device_set_logical_id(dev, "UEFI");
 	fu_device_add_instance_id(dev, tpm_guid_raw);
@@ -799,7 +794,7 @@ fu_plugin_dell_detect_tpm(FuPlugin *plugin, GError **error)
 
 	/* build alternate device node */
 	if (can_switch_modes) {
-		dev_alt = fu_device_new_with_context(ctx);
+		dev_alt = fu_device_new(ctx);
 		fu_device_set_id(dev_alt, tpm_id_alt);
 		fu_device_add_instance_id(dev_alt, tpm_guid_raw_alt);
 		fu_device_set_vendor(dev, "Dell Inc.");
@@ -862,10 +857,8 @@ fu_plugin_dell_device_registered(FuPlugin *plugin, FuDevice *device)
 }
 
 static void
-fu_plugin_dell_init(FuPlugin *plugin)
+fu_plugin_dell_load(FuContext *ctx)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
-	FuPluginData *data = fu_plugin_alloc_data(plugin, sizeof(FuPluginData));
 	g_autofree gchar *tmp = NULL;
 
 	tmp = g_strdup_printf("%d.%d",
@@ -873,17 +866,23 @@ fu_plugin_dell_init(FuPlugin *plugin)
 			      smbios_get_library_version_minor());
 	fu_context_add_runtime_version(ctx, "com.dell.libsmbios", tmp);
 	g_debug("Using libsmbios %s", tmp);
+}
 
-	data->smi_obj = g_malloc0(sizeof(FuDellSmiObj));
+static void
+fu_plugin_dell_init(FuPlugin *plugin)
+{
+	FuPluginData *priv = fu_plugin_alloc_data(plugin, sizeof(FuPluginData));
+
+	priv->smi_obj = g_malloc0(sizeof(FuDellSmiObj));
 	if (g_getenv("FWUPD_DELL_VERBOSE") != NULL)
-		g_setenv("LIBSMBIOS_C_DEBUG_OUTPUT_ALL", "1", TRUE);
+		(void)g_setenv("LIBSMBIOS_C_DEBUG_OUTPUT_ALL", "1", TRUE);
 	else
-		g_setenv("TSS2_LOG", "esys+none,tcti+none", FALSE);
+		(void)g_setenv("TSS2_LOG", "esys+none,tcti+none", FALSE);
 	if (fu_dell_supported(plugin))
-		data->smi_obj->smi = dell_smi_factory(DELL_SMI_DEFAULTS);
-	data->smi_obj->fake_smbios = FALSE;
+		priv->smi_obj->smi = dell_smi_factory(DELL_SMI_DEFAULTS);
+	priv->smi_obj->fake_smbios = FALSE;
 	if (g_getenv("FWUPD_DELL_FAKE_SMBIOS") != NULL)
-		data->smi_obj->fake_smbios = TRUE;
+		priv->smi_obj->fake_smbios = TRUE;
 
 	/* make sure that UEFI plugin is ready to receive devices */
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_RUN_AFTER, "uefi_capsule");
@@ -892,23 +891,31 @@ fu_plugin_dell_init(FuPlugin *plugin)
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_BETTER_THAN, "tpm");
 }
 
+static void
+fu_plugin_dell_to_string(FuPlugin *plugin, guint idt, GString *str)
+{
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	fu_string_append_kb(str, idt, "CanSwitchModes", priv->can_switch_modes);
+	fu_string_append_kb(str, idt, "CapsuleSupported", priv->capsule_supported);
+}
+
 static void
 fu_plugin_dell_destroy(FuPlugin *plugin)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
-	if (data->smi_obj->smi)
-		dell_smi_obj_free(data->smi_obj->smi);
-	g_free(data->smi_obj);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	if (priv->smi_obj->smi)
+		dell_smi_obj_free(priv->smi_obj->smi);
+	g_free(priv->smi_obj);
 }
 
 static gboolean
-fu_plugin_dell_startup(FuPlugin *plugin, GError **error)
+fu_plugin_dell_startup(FuPlugin *plugin, FuProgress *progress, GError **error)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	g_autofree gchar *sysfsfwdir = NULL;
 	g_autofree gchar *esrtdir = NULL;
 
-	if (data->smi_obj->fake_smbios) {
+	if (priv->smi_obj->fake_smbios) {
 		g_debug("Called with fake SMBIOS implementation. "
 			"We're ignoring test for SBMIOS table and ESRT. "
 			"Individual calls will need to be properly staged.");
@@ -923,7 +930,7 @@ fu_plugin_dell_startup(FuPlugin *plugin, GError **error)
 		return FALSE;
 	}
 
-	if (data->smi_obj->smi == NULL) {
+	if (priv->smi_obj->smi == NULL) {
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_INTERNAL,
@@ -936,10 +943,10 @@ fu_plugin_dell_startup(FuPlugin *plugin, GError **error)
 	 *
 	 * Once unlocked, that will enable flashing capsules here too.
 	 */
-	sysfsfwdir = fu_common_get_path(FU_PATH_KIND_SYSFSDIR_FW);
+	sysfsfwdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
 	esrtdir = g_build_filename(sysfsfwdir, "efi", "esrt", NULL);
 	if (g_file_test(esrtdir, G_FILE_TEST_EXISTS))
-		data->capsule_supported = TRUE;
+		priv->capsule_supported = TRUE;
 
 	/* capsules not supported */
 	if (!fu_plugin_dell_capsule_supported(plugin)) {
@@ -952,7 +959,7 @@ fu_plugin_dell_startup(FuPlugin *plugin, GError **error)
 }
 
 static gboolean
-fu_plugin_dell_coldplug(FuPlugin *plugin, GError **error)
+fu_plugin_dell_coldplug(FuPlugin *plugin, FuProgress *progress, GError **error)
 {
 	/* look for switchable TPM */
 	if (!fu_plugin_dell_detect_tpm(plugin, error))
@@ -964,8 +971,10 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_dell_load;
 	vfuncs->init = fu_plugin_dell_init;
 	vfuncs->destroy = fu_plugin_dell_destroy;
+	vfuncs->to_string = fu_plugin_dell_to_string;
 	vfuncs->startup = fu_plugin_dell_startup;
 	vfuncs->coldplug = fu_plugin_dell_coldplug;
 	vfuncs->backend_device_added = fu_plugin_dell_backend_device_added;
