@@ -102,7 +102,7 @@ fu_plugin_dell_tpm_func(gconstpointer user_data)
 				       "device-register",
 				       G_CALLBACK(fu_engine_plugin_device_register_cb),
 				       self->plugin_uefi_capsule);
-	ret = fu_plugin_runner_coldplug(self->plugin_dell, &error);
+	ret = fu_plugin_runner_coldplug(self->plugin_dell, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -231,24 +231,30 @@ fu_plugin_dell_tpm_func(gconstpointer user_data)
 	g_assert_nonnull(device_v12);
 	g_assert_false(fu_device_has_flag(device_v12, FWUPD_DEVICE_FLAG_UPDATABLE));
 
+	/* ensure flags set */
+	ret = fu_device_probe(device_v20, &error);
+	g_assert_no_error(error);
+	g_assert_true(ret);
+
 	/* With one flash left we need an override */
 	ret = fu_plugin_runner_write_firmware(self->plugin_uefi_capsule,
 					      device_v20,
 					      blob_fw,
 					      progress,
-					      FWUPD_INSTALL_FLAG_NONE,
+					      FWUPD_INSTALL_FLAG_NO_SEARCH,
 					      &error);
 	g_assert_error(error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED);
 	g_assert_false(ret);
 	g_clear_error(&error);
 
 	/* test override */
-	ret = fu_plugin_runner_write_firmware(self->plugin_uefi_capsule,
-					      device_v20,
-					      blob_fw,
-					      progress,
-					      FWUPD_INSTALL_FLAG_FORCE,
-					      &error);
+	ret =
+	    fu_plugin_runner_write_firmware(self->plugin_uefi_capsule,
+					    device_v20,
+					    blob_fw,
+					    progress,
+					    FWUPD_INSTALL_FLAG_NO_SEARCH | FWUPD_INSTALL_FLAG_FORCE,
+					    &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -271,8 +277,7 @@ fu_plugin_dell_dock_func(gconstpointer user_data)
 	gulong added_id;
 	gulong register_id;
 
-	fake_usb_device =
-	    fu_usb_device_new_with_context(fu_plugin_get_context(self->plugin_dell), NULL);
+	fake_usb_device = fu_usb_device_new(fu_plugin_get_context(self->plugin_dell), NULL);
 	devices = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 	added_id = g_signal_connect(FU_PLUGIN(self->plugin_uefi_capsule),
 				    "device-added",
@@ -297,7 +302,7 @@ fu_plugin_dell_dock_func(gconstpointer user_data)
 	g_clear_error(&error);
 	g_assert_cmpint(devices->len, ==, 0);
 
-	/* inject a USB dongle matching correct VID/PID */
+	/* inject a USB receiver matching correct VID/PID */
 	out[0] = 0;
 	out[1] = 0;
 	fu_plugin_dell_inject_fake_data(self->plugin_dell,
@@ -502,6 +507,7 @@ fu_test_self_init(FuTest *self)
 {
 	gboolean ret;
 	g_autoptr(FuContext) ctx = fu_context_new();
+	g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 	g_autoptr(GError) error = NULL;
 	g_autofree gchar *pluginfn_uefi = NULL;
 	g_autofree gchar *pluginfn_dell = NULL;
@@ -520,7 +526,7 @@ fu_test_self_init(FuTest *self)
 	ret = fu_plugin_open(self->plugin_uefi_capsule, pluginfn_uefi, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
-	ret = fu_plugin_runner_startup(self->plugin_uefi_capsule, &error);
+	ret = fu_plugin_runner_startup(self->plugin_uefi_capsule, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -530,7 +536,7 @@ fu_test_self_init(FuTest *self)
 	ret = fu_plugin_open(self->plugin_dell, pluginfn_dell, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
-	ret = fu_plugin_runner_startup(self->plugin_dell, &error);
+	ret = fu_plugin_runner_startup(self->plugin_dell, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 }
@@ -561,13 +567,14 @@ main(int argc, char **argv)
 
 	/* change path */
 	testdatadir = g_test_build_filename(G_TEST_DIST, "tests", NULL);
-	g_setenv("FWUPD_SYSFSFWDIR", testdatadir, TRUE);
+	(void)g_setenv("FWUPD_SYSFSFWDIR", testdatadir, TRUE);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", testdatadir, TRUE);
 
 	/* change behavior */
-	sysfsdir = fu_common_get_path(FU_PATH_KIND_SYSFSDIR_FW);
-	g_setenv("FWUPD_UEFI_ESP_PATH", sysfsdir, TRUE);
-	g_setenv("FWUPD_UEFI_TEST", "1", TRUE);
-	g_setenv("FWUPD_DELL_FAKE_SMBIOS", "1", FALSE);
+	sysfsdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
+	(void)g_setenv("FWUPD_UEFI_ESP_PATH", sysfsdir, TRUE);
+	(void)g_setenv("FWUPD_UEFI_TEST", "1", TRUE);
+	(void)g_setenv("FWUPD_DELL_FAKE_SMBIOS", "1", FALSE);
 
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
