@@ -88,7 +88,7 @@ fu_dfu_target_avr_mass_erase(FuDfuTarget *target, FuProgress *progress, GError *
 	guint8 buf[3];
 
 	/* this takes a long time on some devices */
-	fu_dfu_device_set_timeout(fu_dfu_target_get_device(target), 5000);
+	fu_dfu_device_set_timeout(FU_DFU_DEVICE(fu_device_get_proxy(FU_DEVICE(target))), 5000);
 
 	/* format buffer */
 	buf[0] = DFU_AVR32_GROUP_EXEC;
@@ -112,8 +112,8 @@ fu_dfu_target_avr_attach(FuDfuTarget *target, FuProgress *progress, GError **err
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 50);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 50);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 50, "download-chunk");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 50, "download-zero");
 
 	/* format buffer */
 	buf[0] = DFU_AVR32_GROUP_EXEC;
@@ -178,7 +178,7 @@ fu_dfu_target_avr_select_memory_unit(FuDfuTarget *target,
 	guint8 buf[4];
 
 	/* check legacy protocol quirk */
-	if (fu_device_has_private_flag(FU_DEVICE(fu_dfu_target_get_device(target)),
+	if (fu_device_has_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
 				       FU_DFU_DEVICE_FLAG_LEGACY_PROTOCOL)) {
 		g_debug("ignoring select memory unit as legacy protocol");
 		return TRUE;
@@ -265,7 +265,7 @@ fu_dfu_target_avr32_select_memory_page(FuDfuTarget *target,
 	buf[0] = DFU_AVR32_GROUP_SELECT;
 	buf[1] = DFU_AVR32_CMD_SELECT_MEMORY;
 	buf[2] = DFU_AVR32_MEMORY_PAGE;
-	fu_common_write_uint16(&buf[3], memory_page, G_BIG_ENDIAN);
+	fu_memwrite_uint16(&buf[3], memory_page, G_BIG_ENDIAN);
 	data_in = g_bytes_new_static(buf, sizeof(buf));
 	g_debug("selecting memory page 0x%02x", (guint)memory_page);
 	if (!fu_dfu_target_download_chunk(target, 0, data_in, progress, error)) {
@@ -299,8 +299,8 @@ fu_dfu_target_avr_read_memory(FuDfuTarget *target,
 	/* format buffer */
 	buf[0] = DFU_AVR32_GROUP_UPLOAD;
 	buf[1] = DFU_AVR32_CMD_READ_MEMORY;
-	fu_common_write_uint16(&buf[2], addr_start, G_BIG_ENDIAN);
-	fu_common_write_uint16(&buf[4], addr_end, G_BIG_ENDIAN);
+	fu_memwrite_uint16(&buf[2], addr_start, G_BIG_ENDIAN);
+	fu_memwrite_uint16(&buf[4], addr_end, G_BIG_ENDIAN);
 	data_in = g_bytes_new_static(buf, sizeof(buf));
 	g_debug("reading memory from 0x%04x to 0x%04x", (guint)addr_start, (guint)addr_end);
 	if (!fu_dfu_target_download_chunk(target, 0, data_in, progress, error)) {
@@ -363,10 +363,10 @@ fu_dfu_target_avr32_get_chip_signature(FuDfuTarget *target, FuProgress *progress
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25, "mem-unit");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25, "mem-page");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25, "read-memory");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 25, "upload");
 
 	/* select unit, and request 4 bytes */
 	if (!fu_dfu_target_avr_select_memory_unit(target,
@@ -411,8 +411,8 @@ fu_dfu_target_avr_get_chip_signature_for_addr(FuDfuTarget *target,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 10);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 90);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 10, "req");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 90, "res");
 
 	/* request a single byte */
 	if (!fu_dfu_target_avr_read_command(target,
@@ -504,7 +504,7 @@ fu_dfu_target_avr_setup(FuDfuTarget *target, GError **error)
 		return TRUE;
 
 	/* different methods for AVR vs. AVR32 */
-	if (fu_device_has_private_flag(FU_DEVICE(fu_dfu_target_get_device(target)),
+	if (fu_device_has_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
 				       FU_DFU_DEVICE_FLAG_LEGACY_PROTOCOL)) {
 		chunk_sig = fu_dfu_target_avr_get_chip_signature(target, progress, error);
 		if (chunk_sig == NULL)
@@ -520,7 +520,7 @@ fu_dfu_target_avr_setup(FuDfuTarget *target, GError **error)
 	/* get data back */
 	buf = g_bytes_get_data(chunk_sig, &sz);
 	if (g_getenv("FWUPD_DFU_VERBOSE") != NULL)
-		fu_common_dump_bytes(G_LOG_DOMAIN, "AVR:CID", chunk_sig);
+		fu_dump_bytes(G_LOG_DOMAIN, "AVR:CID", chunk_sig);
 	if (sz != 4) {
 		g_set_error(error,
 			    FWUPD_ERROR,
@@ -531,10 +531,11 @@ fu_dfu_target_avr_setup(FuDfuTarget *target, GError **error)
 	}
 	memcpy(&device_id_be, buf, 4);
 	priv->device_id = GINT32_FROM_BE(device_id_be);
+
 	if (buf[0] == ATMEL_MANUFACTURER_CODE1) {
-		chip_id_guid = g_strdup_printf("DFU_AVR\\CID_0x%08x", (guint)priv->device_id);
+		chip_id_guid = g_strdup_printf("0x%08x", (guint)priv->device_id);
 	} else if (buf[0] == ATMEL_MANUFACTURER_CODE2) {
-		chip_id_guid = g_strdup_printf("DFU_AVR\\CID_0x%06x", (guint)priv->device_id >> 8);
+		chip_id_guid = g_strdup_printf("0x%06x", (guint)priv->device_id >> 8);
 	} else {
 		g_set_error(error,
 			    FWUPD_ERROR,
@@ -548,14 +549,16 @@ fu_dfu_target_avr_setup(FuDfuTarget *target, GError **error)
 	}
 
 	/* set the alt-name using the chip ID via a quirk */
-	device = fu_dfu_target_get_device(target);
-	fu_device_add_instance_id(FU_DEVICE(device), chip_id_guid);
+	device = FU_DFU_DEVICE(fu_device_get_proxy(FU_DEVICE(target)));
+	fu_device_add_instance_str(FU_DEVICE(device), "CID", chip_id_guid);
+	if (!fu_device_build_instance_id(FU_DEVICE(device), error, "DFU_AVR", "CID", NULL))
+		return FALSE;
 	chip_id = fu_dfu_device_get_chip_id(device);
 	if (chip_id == NULL) {
-		fu_dfu_device_remove_attribute(fu_dfu_target_get_device(target),
-					       FU_DFU_DEVICE_ATTR_CAN_DOWNLOAD);
-		fu_dfu_device_remove_attribute(fu_dfu_target_get_device(target),
-					       FU_DFU_DEVICE_ATTR_CAN_UPLOAD);
+		fu_device_remove_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
+					      FU_DFU_DEVICE_FLAG_CAN_DOWNLOAD);
+		fu_device_remove_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
+					      FU_DFU_DEVICE_FLAG_CAN_UPLOAD);
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_NOT_SUPPORTED,
@@ -564,7 +567,7 @@ fu_dfu_target_avr_setup(FuDfuTarget *target, GError **error)
 			    chip_id_guid);
 		return FALSE;
 	}
-	fu_dfu_target_set_alt_name(target, chip_id);
+	fu_device_set_logical_id(FU_DEVICE(target), chip_id);
 
 	return TRUE;
 }
@@ -605,7 +608,7 @@ fu_dfu_target_avr_download_element_chunks(FuDfuTarget *target,
 		/* select page if required */
 		if (fu_chunk_get_page(chk) != *page_last) {
 			g_autoptr(FuProgress) progress_tmp = fu_progress_new(G_STRLOC);
-			if (fu_device_has_private_flag(FU_DEVICE(fu_dfu_target_get_device(target)),
+			if (fu_device_has_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
 						       FU_DFU_DEVICE_FLAG_LEGACY_PROTOCOL)) {
 				if (!fu_dfu_target_avr_select_memory_page(target,
 									  fu_chunk_get_page(chk),
@@ -626,10 +629,10 @@ fu_dfu_target_avr_download_element_chunks(FuDfuTarget *target,
 		buf = g_malloc0(fu_chunk_get_data_sz(chk) + header_sz + sizeof(footer));
 		buf[0] = DFU_AVR32_GROUP_DOWNLOAD;
 		buf[1] = DFU_AVR32_CMD_PROGRAM_START;
-		fu_common_write_uint16(&buf[2], fu_chunk_get_address(chk), G_BIG_ENDIAN);
-		fu_common_write_uint16(&buf[4],
-				       fu_chunk_get_address(chk) + fu_chunk_get_data_sz(chk) - 1,
-				       G_BIG_ENDIAN);
+		fu_memwrite_uint16(&buf[2], fu_chunk_get_address(chk), G_BIG_ENDIAN);
+		fu_memwrite_uint16(&buf[4],
+				   fu_chunk_get_address(chk) + fu_chunk_get_data_sz(chk) - 1,
+				   G_BIG_ENDIAN);
 		memcpy(&buf[header_sz], fu_chunk_get_data(chk), fu_chunk_get_data_sz(chk));
 		memcpy(&buf[header_sz + fu_chunk_get_data_sz(chk)], footer, sizeof(footer));
 
@@ -671,8 +674,8 @@ fu_dfu_target_avr_download_element(FuDfuTarget *target,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 10);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 90);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 10, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 90, NULL);
 
 	/* select a memory and erase everything */
 	if (!fu_dfu_target_avr_select_memory_unit(target,
@@ -713,7 +716,7 @@ fu_dfu_target_avr_download_element(FuDfuTarget *target,
 	}
 
 	/* the original AVR protocol uses a half-size control block */
-	if (fu_device_has_private_flag(FU_DEVICE(fu_dfu_target_get_device(target)),
+	if (fu_device_has_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
 				       FU_DFU_DEVICE_FLAG_LEGACY_PROTOCOL)) {
 		header_sz = ATMEL_AVR_CONTROL_BLOCK_SIZE;
 	}
@@ -748,8 +751,8 @@ fu_dfu_target_avr_upload_element_chunk(FuDfuTarget *target,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 70);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 30);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 70, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 30, NULL);
 
 	/* prepare to read */
 	if (!fu_dfu_target_avr_read_memory(target,
@@ -806,7 +809,7 @@ fu_dfu_target_avr_upload_element_chunks(FuDfuTarget *target,
 		/* select page if required */
 		if (fu_chunk_get_page(chk) != page_last) {
 			g_autoptr(FuProgress) progress_tmp = fu_progress_new(G_STRLOC);
-			if (fu_device_has_private_flag(FU_DEVICE(fu_dfu_target_get_device(target)),
+			if (fu_device_has_private_flag(fu_device_get_proxy(FU_DEVICE(target)),
 						       FU_DFU_DEVICE_FLAG_LEGACY_PROTOCOL)) {
 				if (!fu_dfu_target_avr_select_memory_page(target,
 									  fu_chunk_get_page(chk),
@@ -832,7 +835,7 @@ fu_dfu_target_avr_upload_element_chunks(FuDfuTarget *target,
 		g_ptr_array_add(blobs, blob_tmp);
 
 		/* this page has valid data */
-		if (!fu_common_bytes_is_empty(blob_tmp)) {
+		if (!fu_bytes_is_empty(blob_tmp)) {
 			g_debug("chunk %u has data (page %" G_GUINT32_FORMAT ")",
 				i,
 				fu_chunk_get_page(chk));
@@ -881,8 +884,8 @@ fu_dfu_target_avr_upload_element(FuDfuTarget *target,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 5);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 95);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 5, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 95, NULL);
 
 	/* select unit */
 	if (!fu_dfu_target_avr_select_memory_unit(target,
