@@ -13,8 +13,12 @@
 static void
 fu_plugin_dfu_init(FuPlugin *plugin)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_DFU_DEVICE);
+}
+
+static void
+fu_plugin_dfu_load(FuContext *ctx)
+{
 	fu_context_add_quirk_key(ctx, "DfuAltName");
 	fu_context_add_quirk_key(ctx, "DfuForceTimeout");
 	fu_context_add_quirk_key(ctx, "DfuForceVersion");
@@ -24,5 +28,6 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_dfu_load;
 	vfuncs->init = fu_plugin_dfu_init;
 }
