@@ -6,7 +6,8 @@
 
 #include "config.h"
 
-#include <fwupd.h>
+#include <fwupdplugin.h>
+
 #include <string.h>
 
 #include "fu-ep963x-common.h"
@@ -18,16 +19,42 @@ struct _FuEp963xFirmware {
 
 G_DEFINE_TYPE(FuEp963xFirmware, fu_ep963x_firmware, FU_TYPE_FIRMWARE)
 
+static gboolean
+fu_ep963x_firmware_check_magic(FuFirmware *firmware, GBytes *fw, gsize offset, GError **error)
+{
+	guint8 magic[5] = {0x0};
+
+	if (!fu_memcpy_safe(magic,
+			    sizeof(magic),
+			    0, /* dst */
+			    g_bytes_get_data(fw, NULL),
+			    g_bytes_get_size(fw),
+			    offset + 16,
+			    sizeof(magic),
+			    error)) {
+		g_prefix_error(error, "failed to read magic: ");
+		return FALSE;
+	}
+	if (memcmp(magic, "EP963", sizeof(magic)) != 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INVALID_FILE,
+				    "invalid EP963x binary file");
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_ep963x_firmware_parse(FuFirmware *firmware,
 			 GBytes *fw,
-			 guint64 addr_start,
-			 guint64 addr_end,
+			 gsize offset,
 			 FwupdInstallFlags flags,
 			 GError **error)
 {
-	gsize len = 0x0;
-	const guint8 *data = g_bytes_get_data(fw, &len);
+	gsize len = g_bytes_get_size(fw);
 
 	/* check size */
 	if (len != FU_EP963_FIRMWARE_SIZE) {
@@ -40,15 +67,6 @@ fu_ep963x_firmware_parse(FuFirmware *firmware,
 		return FALSE;
 	}
 
-	/* check signature */
-	if (memcmp(data + 16, "EP963", 5) != 0) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_INTERNAL,
-				    "invalid EP963x binary file");
-		return FALSE;
-	}
-
 	/* success */
 	fu_firmware_set_bytes(firmware, fw);
 	return TRUE;
@@ -63,6 +81,7 @@ static void
 fu_ep963x_firmware_class_init(FuEp963xFirmwareClass *klass)
 {
 	FuFirmwareClass *klass_firmware = FU_FIRMWARE_CLASS(klass);
+	klass_firmware->check_magic = fu_ep963x_firmware_check_magic;
 	klass_firmware->parse = fu_ep963x_firmware_parse;
 }
 
