@@ -10,6 +10,13 @@
 
 #include "fu-fastboot-device.h"
 
+static void
+fu_plugin_fastboot_load(FuContext *ctx)
+{
+	fu_context_add_quirk_key(ctx, "FastbootBlockSize");
+	fu_context_add_quirk_key(ctx, "FastbootOperationDelay");
+}
+
 static void
 fu_plugin_fastboot_init(FuPlugin *plugin)
 {
@@ -20,5 +27,6 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_fastboot_load;
 	vfuncs->init = fu_plugin_fastboot_init;
 }
