@@ -13,12 +13,20 @@
 #include "fu-genesys-usbhub-firmware.h"
 
 static void
-fu_plugin_genesys_init(FuPlugin *plugin)
+fu_plugin_genesys_load(FuContext *ctx)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
+	fu_context_add_quirk_key(ctx, "GenesysScalerCfiFlashId");
 	fu_context_add_quirk_key(ctx, "GenesysScalerGpioOutputRegister");
 	fu_context_add_quirk_key(ctx, "GenesysScalerGpioEnableRegister");
 	fu_context_add_quirk_key(ctx, "GenesysScalerGpioValue");
+	fu_context_add_quirk_key(ctx, "GenesysUsbhubReadRequest");
+	fu_context_add_quirk_key(ctx, "GenesysUsbhubSwitchRequest");
+	fu_context_add_quirk_key(ctx, "GenesysUsbhubWriteRequest");
+}
+
+static void
+fu_plugin_genesys_init(FuPlugin *plugin)
+{
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_GENESYS_USBHUB_DEVICE);
 	fu_plugin_add_firmware_gtype(plugin, NULL, FU_TYPE_GENESYS_USBHUB_FIRMWARE);
 	fu_plugin_add_firmware_gtype(plugin, NULL, FU_TYPE_GENESYS_SCALER_FIRMWARE);
@@ -28,5 +36,6 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_genesys_load;
 	vfuncs->init = fu_plugin_genesys_init;
 }
