@@ -19,6 +19,13 @@ fu_plugin_iommu_init(FuPlugin *plugin)
 	fu_plugin_add_udev_subsystem(plugin, "iommu");
 }
 
+static void
+fu_plugin_iommu_to_string(FuPlugin *plugin, guint idt, GString *str)
+{
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	fu_string_append_kb(str, idt, "HasIommu", priv->has_iommu);
+}
+
 static gboolean
 fu_plugin_iommu_backend_device_added(FuPlugin *plugin, FuDevice *device, GError **error)
 {
@@ -37,17 +44,26 @@ fu_plugin_iommu_backend_device_added(FuPlugin *plugin, FuDevice *device, GError
 static void
 fu_plugin_iommu_add_security_attrs(FuPlugin *plugin, FuSecurityAttrs *attrs)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	g_autoptr(FwupdSecurityAttr) attr = NULL;
 
 	/* create attr */
-	attr = fwupd_security_attr_new(FWUPD_SECURITY_ATTR_ID_IOMMU);
-	fwupd_security_attr_set_level(attr, FWUPD_SECURITY_ATTR_LEVEL_IMPORTANT);
-	fwupd_security_attr_set_plugin(attr, fu_plugin_get_name(plugin));
+	attr = fu_plugin_security_attr_new(plugin, FWUPD_SECURITY_ATTR_ID_IOMMU);
 	fu_security_attrs_append(attrs, attr);
 
-	if (!data->has_iommu) {
+	if (priv == NULL) {
+		fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_MISSING_DATA);
+		return;
+	}
+
+	fu_security_attr_add_bios_target_value(attr, "AmdVt", "enable");
+	fu_security_attr_add_bios_target_value(attr, "IOMMU", "enable");
+	fu_security_attr_add_bios_target_value(attr, "VtForDirectIo", "enable");
+
+	if (!priv->has_iommu) {
 		fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_NOT_FOUND);
+		fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM);
+		fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW);
 		return;
 	}
 
@@ -61,6 +77,7 @@ fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
 	vfuncs->init = fu_plugin_iommu_init;
+	vfuncs->to_string = fu_plugin_iommu_to_string;
 	vfuncs->backend_device_added = fu_plugin_iommu_backend_device_added;
 	vfuncs->add_security_attrs = fu_plugin_iommu_add_security_attrs;
 }
