@@ -13,19 +13,26 @@
 static void
 fu_plugin_jabra_init(FuPlugin *plugin)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_JABRA_DEVICE);
+}
+
+static void
+fu_plugin_jabra_load(FuContext *ctx)
+{
 	fu_context_add_quirk_key(ctx, "JabraMagic");
 }
 
 /* slightly weirdly, this takes us from appIDLE back into the actual
  * runtime mode where the device actually works */
 static gboolean
-fu_plugin_jabra_cleanup(FuPlugin *plugin, FuDevice *device, FwupdInstallFlags flags, GError **error)
+fu_plugin_jabra_cleanup(FuPlugin *plugin,
+			FuDevice *device,
+			FuProgress *progress,
+			FwupdInstallFlags flags,
+			GError **error)
 {
 	GUsbDevice *usb_device;
 	g_autoptr(FuDeviceLocker) locker = NULL;
-	g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 	g_autoptr(GError) error_local = NULL;
 
 	/* check for a property on the *dfu* FuDevice, which is also why we
@@ -56,6 +63,7 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_jabra_load;
 	vfuncs->init = fu_plugin_jabra_init;
 	vfuncs->cleanup = fu_plugin_jabra_cleanup;
 }
