@@ -11,11 +11,13 @@
 #include <glib/gstdio.h>
 #include <stdlib.h>
 
+#include "fu-bios-settings-private.h"
 #include "fu-context-private.h"
 #include "fu-device-private.h"
 #include "fu-plugin-private.h"
 
 typedef struct {
+	FuContext *ctx;
 	FuPlugin *plugin_uefi_capsule;
 	FuPlugin *plugin_lenovo_thinklmi;
 } FuTest;
@@ -32,15 +34,25 @@ fu_test_self_init(FuTest *self, GError **error_global)
 {
 	gboolean ret;
 	g_autoptr(FuContext) ctx = fu_context_new();
+	g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 	g_autoptr(GError) error = NULL;
 	g_autofree gchar *pluginfn_uefi = NULL;
 	g_autofree gchar *pluginfn_lenovo = NULL;
 
+	g_test_expect_message("FuBiosSettings", G_LOG_LEVEL_WARNING, "*KERNEL*BUG*");
+
 	ret = fu_context_load_quirks(ctx,
 				     FU_QUIRKS_LOAD_FLAG_NO_CACHE | FU_QUIRKS_LOAD_FLAG_NO_VERIFY,
 				     &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
+	ret = fu_context_load_hwinfo(ctx, &error);
+	g_assert_no_error(error);
+	g_assert_true(ret);
+	ret = fu_context_reload_bios_settings(ctx, &error);
+	g_assert_true(ret);
+	g_assert_no_error(error);
+	g_test_assert_expected_messages();
 
 	self->plugin_uefi_capsule = fu_plugin_new(ctx);
 	pluginfn_uefi = g_test_build_filename(G_TEST_BUILT,
@@ -59,7 +71,7 @@ fu_test_self_init(FuTest *self, GError **error_global)
 	ret = fu_plugin_open(self->plugin_uefi_capsule, pluginfn_uefi, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
-	ret = fu_plugin_runner_startup(self->plugin_uefi_capsule, &error);
+	ret = fu_plugin_runner_startup(self->plugin_uefi_capsule, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -70,9 +82,10 @@ fu_test_self_init(FuTest *self, GError **error_global)
 	ret = fu_plugin_open(self->plugin_lenovo_thinklmi, pluginfn_lenovo, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
-	ret = fu_plugin_runner_startup(self->plugin_lenovo_thinklmi, &error);
+	ret = fu_plugin_runner_startup(self->plugin_lenovo_thinklmi, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
+	self->ctx = fu_plugin_get_context(self->plugin_lenovo_thinklmi);
 	return TRUE;
 }
 
@@ -82,6 +95,7 @@ fu_test_probe_fake_esrt(FuTest *self)
 	gboolean ret;
 	gulong added_id;
 	FuDevice *dev = NULL;
+	g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 	g_autoptr(GError) error = NULL;
 
 	added_id = g_signal_connect(FU_PLUGIN(self->plugin_uefi_capsule),
@@ -89,7 +103,7 @@ fu_test_probe_fake_esrt(FuTest *self)
 				    G_CALLBACK(_plugin_device_added_cb),
 				    &dev);
 
-	ret = fu_plugin_runner_coldplug(self->plugin_uefi_capsule, &error);
+	ret = fu_plugin_runner_coldplug(self->plugin_uefi_capsule, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 	g_assert_nonnull(dev);
@@ -102,10 +116,16 @@ static void
 fu_plugin_lenovo_thinklmi_bootorder_locked(gconstpointer user_data)
 {
 	FuTest *self = (FuTest *)user_data;
+	gboolean ret;
 	g_autoptr(FuDevice) dev = NULL;
+	g_autoptr(GError) error = NULL;
 	g_autofree gchar *test_dir =
 	    g_test_build_filename(G_TEST_DIST, "tests", "firmware-attributes", "locked", NULL);
-	g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
+
+	ret = fu_context_reload_bios_settings(self->ctx, &error);
+	g_assert_true(ret);
+	g_assert_no_error(error);
 
 	dev = fu_test_probe_fake_esrt(self);
 	fu_plugin_runner_device_register(self->plugin_lenovo_thinklmi, dev);
@@ -116,16 +136,43 @@ static void
 fu_plugin_lenovo_thinklmi_bootorder_unlocked(gconstpointer user_data)
 {
 	FuTest *self = (FuTest *)user_data;
+	gboolean ret;
 	g_autoptr(FuDevice) dev = NULL;
+	g_autoptr(GError) error = NULL;
 	g_autofree gchar *test_dir =
 	    g_test_build_filename(G_TEST_DIST, "tests", "firmware-attributes", "unlocked", NULL);
-	g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
 
+	ret = fu_context_reload_bios_settings(self->ctx, &error);
+	g_assert_true(ret);
+	g_assert_no_error(error);
 	dev = fu_test_probe_fake_esrt(self);
 	fu_plugin_runner_device_register(self->plugin_lenovo_thinklmi, dev);
 	g_assert_true(fu_device_has_flag(dev, FWUPD_DEVICE_FLAG_UPDATABLE));
 }
 
+static void
+fu_plugin_lenovo_thinklmi_reboot_pending(gconstpointer user_data)
+{
+	FuTest *self = (FuTest *)user_data;
+	gboolean ret;
+	g_autoptr(FuDevice) dev = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autofree gchar *test_dir = g_test_build_filename(G_TEST_DIST,
+							   "tests",
+							   "firmware-attributes",
+							   "reboot-pending",
+							   NULL);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
+
+	ret = fu_context_reload_bios_settings(self->ctx, &error);
+	g_assert_true(ret);
+	g_assert_no_error(error);
+	dev = fu_test_probe_fake_esrt(self);
+	fu_plugin_runner_device_register(self->plugin_lenovo_thinklmi, dev);
+	g_assert_true(fu_device_has_flag(dev, FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN));
+}
+
 static void
 fu_test_self_free(FuTest *self)
 {
@@ -155,16 +202,16 @@ main(int argc, char **argv)
 	/* starting thinklmi dir to make startup pass */
 	test_dir =
 	    g_test_build_filename(G_TEST_DIST, "tests", "firmware-attributes", "locked", NULL);
-	g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", test_dir, TRUE);
 
 	/* starting ESRT path */
 	testdatadir = g_test_build_filename(G_TEST_DIST, "tests", NULL);
-	g_setenv("FWUPD_SYSFSFWDIR", testdatadir, TRUE);
+	(void)g_setenv("FWUPD_SYSFSFWDIR", testdatadir, TRUE);
 
 	/* change behavior of UEFI plugin for test mode */
-	sysfsdir = fu_common_get_path(FU_PATH_KIND_SYSFSDIR_FW);
-	g_setenv("FWUPD_UEFI_ESP_PATH", sysfsdir, TRUE);
-	g_setenv("FWUPD_UEFI_TEST", "1", TRUE);
+	sysfsdir = fu_path_from_kind(FU_PATH_KIND_SYSFSDIR_FW);
+	(void)g_setenv("FWUPD_UEFI_ESP_PATH", sysfsdir, TRUE);
+	(void)g_setenv("FWUPD_UEFI_TEST", "1", TRUE);
 
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
@@ -182,5 +229,8 @@ main(int argc, char **argv)
 	g_test_add_data_func("/fwupd/plugin{lenovo-think-lmi:bootorder-unlocked}",
 			     self,
 			     fu_plugin_lenovo_thinklmi_bootorder_unlocked);
+	g_test_add_data_func("/fwupd/plugin{lenovo-think-lmi:reboot-pending}",
+			     self,
+			     fu_plugin_lenovo_thinklmi_reboot_pending);
 	return g_test_run();
 }
