@@ -24,12 +24,12 @@ fu_plugin_linux_swap_init(FuPlugin *plugin)
 static void
 fu_plugin_linux_swap_destroy(FuPlugin *plugin)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
-	if (data->file != NULL)
-		g_object_unref(data->file);
-	if (data->monitor != NULL) {
-		g_file_monitor_cancel(data->monitor);
-		g_object_unref(data->monitor);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	if (priv->file != NULL)
+		g_object_unref(priv->file);
+	if (priv->monitor != NULL) {
+		g_file_monitor_cancel(priv->monitor);
+		g_object_unref(priv->monitor);
 	}
 }
 
@@ -46,13 +46,13 @@ fu_plugin_linux_swap_changed_cb(GFileMonitor *monitor,
 }
 
 static gboolean
-fu_plugin_linux_swap_startup(FuPlugin *plugin, GError **error)
+fu_plugin_linux_swap_startup(FuPlugin *plugin, FuProgress *progress, GError **error)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	g_autofree gchar *fn = NULL;
 	g_autofree gchar *procfs = NULL;
 
-	procfs = fu_common_get_path(FU_PATH_KIND_PROCFS);
+	procfs = fu_path_from_kind(FU_PATH_KIND_PROCFS);
 	fn = g_build_filename(procfs, "swaps", NULL);
 	if (!g_file_test(fn, G_FILE_TEST_EXISTS)) {
 		g_set_error_literal(error,
@@ -61,11 +61,11 @@ fu_plugin_linux_swap_startup(FuPlugin *plugin, GError **error)
 				    "Kernel doesn't offer swap support.");
 		return FALSE;
 	}
-	data->file = g_file_new_for_path(fn);
-	data->monitor = g_file_monitor(data->file, G_FILE_MONITOR_NONE, NULL, error);
-	if (data->monitor == NULL)
+	priv->file = g_file_new_for_path(fn);
+	priv->monitor = g_file_monitor(priv->file, G_FILE_MONITOR_NONE, NULL, error);
+	if (priv->monitor == NULL)
 		return FALSE;
-	g_signal_connect(G_FILE_MONITOR(data->monitor),
+	g_signal_connect(G_FILE_MONITOR(priv->monitor),
 			 "changed",
 			 G_CALLBACK(fu_plugin_linux_swap_changed_cb),
 			 plugin);
@@ -75,32 +75,31 @@ fu_plugin_linux_swap_startup(FuPlugin *plugin, GError **error)
 static void
 fu_plugin_linux_swap_add_security_attrs(FuPlugin *plugin, FuSecurityAttrs *attrs)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	gsize bufsz = 0;
 	g_autofree gchar *buf = NULL;
 	g_autoptr(FuLinuxSwap) swap = NULL;
 	g_autoptr(FwupdSecurityAttr) attr = NULL;
 	g_autoptr(GError) error_local = NULL;
 
-	if (data->file == NULL)
+	if (priv == NULL || priv->file == NULL)
 		return;
 
 	/* create attr */
-	attr = fwupd_security_attr_new(FWUPD_SECURITY_ATTR_ID_KERNEL_SWAP);
-	fwupd_security_attr_set_plugin(attr, fu_plugin_get_name(plugin));
+	attr = fu_plugin_security_attr_new(plugin, FWUPD_SECURITY_ATTR_ID_KERNEL_SWAP);
 	fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ISSUE);
 	fu_security_attrs_append(attrs, attr);
 
 	/* load list of swaps */
-	if (!g_file_load_contents(data->file, NULL, &buf, &bufsz, NULL, &error_local)) {
-		g_autofree gchar *fn = g_file_get_path(data->file);
+	if (!g_file_load_contents(priv->file, NULL, &buf, &bufsz, NULL, &error_local)) {
+		g_autofree gchar *fn = g_file_get_path(priv->file);
 		g_warning("could not open %s: %s", fn, error_local->message);
 		fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_NOT_VALID);
 		return;
 	}
 	swap = fu_linux_swap_new(buf, bufsz, &error_local);
 	if (swap == NULL) {
-		g_autofree gchar *fn = g_file_get_path(data->file);
+		g_autofree gchar *fn = g_file_get_path(priv->file);
 		g_warning("could not parse %s: %s", fn, error_local->message);
 		fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_NOT_VALID);
 		return;
@@ -116,6 +115,7 @@ fu_plugin_linux_swap_add_security_attrs(FuPlugin *plugin, FuSecurityAttrs *attrs
 	/* add security attribute */
 	if (!fu_linux_swap_get_encrypted(swap)) {
 		fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_NOT_ENCRYPTED);
+		fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS);
 		return;
 	}
 
