@@ -188,7 +188,6 @@ fu_logitech_hidpp_device_ping(FuLogitechHidPpDevice *self, GError **error)
 		}
 		if (g_error_matches(error_local, G_IO_ERROR, G_IO_ERROR_HOST_UNREACHABLE)) {
 			fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNREACHABLE);
-			fu_device_inhibit(FU_DEVICE(self), "unreachable", "device is unreachable");
 			return TRUE;
 		}
 		g_propagate_error(error, g_steal_pointer(&error_local));
@@ -197,12 +196,10 @@ fu_logitech_hidpp_device_ping(FuLogitechHidPpDevice *self, GError **error)
 
 	/* device no longer asleep */
 	fu_device_remove_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNREACHABLE);
-	fu_device_uninhibit(FU_DEVICE(self), "unreachable");
 	children = fu_device_get_children(FU_DEVICE(self));
 	for (guint i = 0; i < children->len; i++) {
 		FuDevice *radio = g_ptr_array_index(children, i);
 		fu_device_remove_flag(radio, FWUPD_DEVICE_FLAG_UNREACHABLE);
-		fu_device_uninhibit(radio, "unreachable");
 	}
 
 	/* if the device index is unset, grab it from the reply */
@@ -305,7 +302,7 @@ fu_logitech_hidpp_map_to_string(FuLogitechHidPpHidppMap *map, guint idt, GString
 	g_autofree gchar *tmp = g_strdup_printf("%s [0x%04x]",
 						fu_logitech_hidpp_feature_to_string(map->feature),
 						map->feature);
-	fu_common_string_append_kv(str, idt, title, tmp);
+	fu_string_append(str, idt, title, tmp);
 }
 
 static void
@@ -317,10 +314,10 @@ fu_logitech_hidpp_device_to_string(FuDevice *device, guint idt, GString *str)
 	/* FuUdevDevice->to_string */
 	FU_DEVICE_CLASS(fu_logitech_hidpp_device_parent_class)->to_string(device, idt, str);
 
-	fu_common_string_append_ku(str, idt, "HidppVersion", priv->hidpp_version);
-	fu_common_string_append_ku(str, idt, "HidppPid", priv->hidpp_pid);
-	fu_common_string_append_kx(str, idt, "DeviceIdx", priv->device_idx);
-	fu_common_string_append_kv(str, idt, "ModelId", priv->model_id);
+	fu_string_append_ku(str, idt, "HidppVersion", priv->hidpp_version);
+	fu_string_append_ku(str, idt, "HidppPid", priv->hidpp_pid);
+	fu_string_append_kx(str, idt, "DeviceIdx", priv->device_idx);
+	fu_string_append(str, idt, "ModelId", priv->model_id);
 	for (guint i = 0; i < priv->feature_index->len; i++) {
 		FuLogitechHidPpHidppMap *map = g_ptr_array_index(priv->feature_index, i);
 		fu_logitech_hidpp_map_to_string(map, idt, str);
@@ -487,7 +484,6 @@ fu_logitech_hidpp_device_fetch_model_id(FuLogitechHidPpDevice *self, GError **er
 {
 	FuLogitechHidPpDevicePrivate *priv = GET_PRIVATE(self);
 	guint8 idx;
-	g_autofree gchar *devid = NULL;
 	g_autoptr(FuLogitechHidPpHidppMsg) msg = fu_logitech_hidpp_msg_new();
 	g_autoptr(GString) str = g_string_new(NULL);
 
@@ -512,11 +508,9 @@ fu_logitech_hidpp_device_fetch_model_id(FuLogitechHidPpDevice *self, GError **er
 	fu_logitech_hidpp_device_set_model_id(self, str->str);
 
 	/* add one more instance ID */
-	devid = g_strdup_printf("HIDRAW\\VEN_%04X&MOD_%s",
-				(guint)FU_UNIFYING_DEVICE_VID,
-				priv->model_id);
-	fu_device_add_instance_id(FU_DEVICE(self), devid);
-	return TRUE;
+	fu_device_add_instance_u16(FU_DEVICE(self), "VEN", FU_UNIFYING_DEVICE_VID);
+	fu_device_add_instance_str(FU_DEVICE(self), "MOD", priv->model_id);
+	return fu_device_build_instance_id(FU_DEVICE(self), error, "HIDRAW", "VEN", "MOD", NULL);
 }
 
 static gboolean
@@ -693,16 +687,6 @@ fu_logitech_hidpp_device_probe(FuDevice *device, GError **error)
 	FuLogitechHidPpDevice *self = FU_HIDPP_DEVICE(device);
 	FuLogitechHidPpDevicePrivate *priv = GET_PRIVATE(self);
 
-	/*
-	 * FuUdevDevice->probe except for paired devices. We don't want
-	 * paired devices to inherit the logical ids of the receiver.
-	 */
-	if (priv->device_idx == HIDPP_DEVICE_IDX_UNSET ||
-	    priv->device_idx == HIDPP_DEVICE_IDX_BLE) {
-		if (!FU_DEVICE_CLASS(fu_logitech_hidpp_device_parent_class)->probe(device, error))
-			return FALSE;
-	}
-
 	/* set the physical ID */
 	if (!fu_udev_device_set_physical_id(FU_UDEV_DEVICE(device), "hid", error))
 		return FALSE;
@@ -722,7 +706,14 @@ fu_logitech_hidpp_device_probe(FuDevice *device, GError **error)
 		fu_device_set_logical_id(device, id_str->str);
 	}
 
-	return TRUE;
+	/* this is a non-standard extension */
+	fu_device_add_instance_u16(FU_DEVICE(self),
+				   "VID",
+				   fu_udev_device_get_vendor(FU_UDEV_DEVICE(device)));
+	fu_device_add_instance_u16(FU_DEVICE(self),
+				   "PID",
+				   fu_udev_device_get_model(FU_UDEV_DEVICE(device)));
+	return fu_device_build_instance_id(FU_DEVICE(self), error, "UFY", "VID", "PID", NULL);
 }
 
 static gboolean
@@ -800,14 +791,6 @@ fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 	if (!fu_logitech_hidpp_device_fetch_model_id(self, error))
 		return FALSE;
 
-	/* get the firmware information */
-	if (!fu_logitech_hidpp_device_fetch_firmware_info(self, error))
-		return FALSE;
-
-	/* get the battery level */
-	if (!fu_logitech_hidpp_device_fetch_battery_level(self, error))
-		return FALSE;
-
 	/* try using HID++2.0 */
 	idx = fu_logitech_hidpp_device_feature_get_idx(self, HIDPP_FEATURE_GET_DEVICE_NAME_TYPE);
 	if (idx != 0x00) {
@@ -874,6 +857,14 @@ fu_logitech_hidpp_device_setup(FuDevice *device, GError **error)
 		fu_device_add_protocol(FU_DEVICE(self), "com.logitech.unifyingsigned");
 	}
 
+	/* get the firmware information */
+	if (!fu_logitech_hidpp_device_fetch_firmware_info(self, error))
+		return FALSE;
+
+	/* get the battery level */
+	if (!fu_logitech_hidpp_device_fetch_battery_level(self, error))
+		return FALSE;
+
 	/* poll for pings to track active state */
 	fu_device_set_poll_interval(device, FU_HIDPP_DEVICE_POLLING_INTERVAL);
 	return TRUE;
@@ -1118,12 +1109,12 @@ fu_logitech_hidpp_device_write_firmware_pkt(FuLogitechHidPpDevice *self,
 	}
 
 	/* check error */
-	if (!fu_common_read_uint32_safe(msg->data,
-					sizeof(msg->data),
-					0x0,
-					&packet_cnt,
-					G_BIG_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(msg->data,
+				    sizeof(msg->data),
+				    0x0,
+				    &packet_cnt,
+				    G_BIG_ENDIAN,
+				    error))
 		return FALSE;
 	if (g_getenv("FWUPD_LOGITECH_HIDPP_VERBOSE") != NULL)
 		g_debug("packet_cnt=0x%04x", packet_cnt);
@@ -1320,11 +1311,10 @@ static void
 fu_logitech_hidpp_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 97, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, "reload");
 }
 
 static void
@@ -1338,7 +1328,10 @@ fu_logitech_hidpp_device_finalize(GObject *object)
 }
 
 static gboolean
-fu_logitech_hidpp_device_cleanup(FuDevice *device, FwupdInstallFlags flags, GError **error)
+fu_logitech_hidpp_device_cleanup(FuDevice *device,
+				 FuProgress *progress,
+				 FwupdInstallFlags flags,
+				 GError **error)
 {
 	FuDevice *parent = fu_device_get_parent(device);
 	if (parent != NULL)
