@@ -178,10 +178,6 @@ fu_logitech_hidpp_runtime_probe(FuDevice *device, GError **error)
 	g_autoptr(GUdevDevice) udev_parent = NULL;
 	g_autoptr(GUdevDevice) udev_parent_usb_interface = NULL;
 
-	/* FuUdevDevice->probe */
-	if (!FU_DEVICE_CLASS(fu_logitech_hidpp_runtime_parent_class)->probe(device, error))
-		return FALSE;
-
 	/* set the physical ID */
 	if (!fu_udev_device_set_physical_id(FU_UDEV_DEVICE(device), "usb", error))
 		return FALSE;
@@ -276,7 +272,7 @@ fu_logitech_hidpp_runtime_init(FuLogitechHidPpRuntime *self)
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PLAIN);
-	fu_device_add_icon(FU_DEVICE(self), "preferences-desktop-keyboard");
+	fu_device_add_icon(FU_DEVICE(self), "usb-receiver");
 	fu_device_set_name(FU_DEVICE(self), "Unifying Receiver");
 	fu_device_set_summary(FU_DEVICE(self), "Miniaturised USB wireless receiver");
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
