@@ -22,6 +22,8 @@
 #include "fu-firehose-updater.h"
 #endif
 
+#include "fu-sahara-loader.h"
+
 /* Amount of time for the modem to boot in fastboot mode. */
 #define FU_MM_DEVICE_REMOVE_DELAY_RE_ENUMERATE 20000 /* ms */
 
@@ -86,6 +88,7 @@ struct _FuMmDevice {
 	/* firehose update handling */
 	gchar *port_qcdm;
 	gchar *port_edl;
+	FuSaharaLoader *sahara_loader;
 #if MM_CHECK_VERSION(1, 17, 2)
 	FuFirehoseUpdater *firehose_updater;
 #endif
@@ -108,13 +111,13 @@ fu_mm_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuMmDevice *self = FU_MM_DEVICE(device);
 	if (self->port_at != NULL)
-		fu_common_string_append_kv(str, idt, "AtPort", self->port_at);
+		fu_string_append(str, idt, "AtPort", self->port_at);
 	if (self->port_qmi != NULL)
-		fu_common_string_append_kv(str, idt, "QmiPort", self->port_qmi);
+		fu_string_append(str, idt, "QmiPort", self->port_qmi);
 	if (self->port_mbim != NULL)
-		fu_common_string_append_kv(str, idt, "MbimPort", self->port_mbim);
+		fu_string_append(str, idt, "MbimPort", self->port_mbim);
 	if (self->port_qcdm != NULL)
-		fu_common_string_append_kv(str, idt, "QcdmPort", self->port_qcdm);
+		fu_string_append(str, idt, "QcdmPort", self->port_qcdm);
 }
 
 const gchar *
@@ -170,6 +173,9 @@ validate_firmware_update_method(MMModemFirmwareUpdateMethod methods, GError **er
 #endif /* MM_CHECK_VERSION(1,17,1) */
 #if MM_CHECK_VERSION(1, 17, 2)
 		MM_MODEM_FIRMWARE_UPDATE_METHOD_FIREHOSE,
+#endif
+#if MM_CHECK_VERSION(1, 19, 1)
+		MM_MODEM_FIRMWARE_UPDATE_METHOD_FIREHOSE | MM_MODEM_FIRMWARE_UPDATE_METHOD_SAHARA,
 #endif
 	};
 	g_autofree gchar *methods_str = NULL;
@@ -302,10 +308,13 @@ fu_mm_device_probe_default(FuDevice *device, GError **error)
 #if MM_CHECK_VERSION(1, 17, 2)
 	if (self->update_methods & MM_MODEM_FIRMWARE_UPDATE_METHOD_FIREHOSE) {
 		for (guint i = 0; i < n_ports; i++) {
-			if (ports[i].type == MM_MODEM_PORT_TYPE_QCDM) {
+			if (ports[i].type == MM_MODEM_PORT_TYPE_QCDM)
 				self->port_qcdm = g_strdup_printf("/dev/%s", ports[i].name);
-				break;
-			}
+			else if (ports[i].type == MM_MODEM_PORT_TYPE_MBIM)
+				self->port_mbim = g_strdup_printf("/dev/%s", ports[i].name);
+			/* to read secboot status */
+			else if (ports[i].type == MM_MODEM_PORT_TYPE_AT)
+				self->port_at = g_strdup_printf("/dev/%s", ports[i].name);
 		}
 		fu_device_add_protocol(device, "com.qualcomm.firehose");
 	}
@@ -346,9 +355,9 @@ fu_mm_device_probe_default(FuDevice *device, GError **error)
 
 #endif /* MM_CHECK_VERSION(1,17,1) */
 #if MM_CHECK_VERSION(1, 17, 2)
-	/* a qcdm port is required for firehose */
+	/* a qcdm or mbim port is required for firehose */
 	if ((self->update_methods & MM_MODEM_FIRMWARE_UPDATE_METHOD_FIREHOSE) &&
-	    (self->port_qcdm == NULL)) {
+	    (self->port_qcdm == NULL && self->port_mbim == NULL)) {
 		g_set_error_literal(error,
 				    FWUPD_ERROR,
 				    FWUPD_ERROR_NOT_SUPPORTED,
@@ -509,6 +518,11 @@ fu_mm_device_probe_default(FuDevice *device, GError **error)
 		}
 	}
 
+	/* fix up vendor name */
+	if (g_strcmp0(fu_device_get_vendor(device), "QUALCOMM INCORPORATED") == 0)
+		fu_device_set_vendor(device, "Qualcomm");
+
+	/* success */
 	return TRUE;
 }
 
@@ -583,7 +597,7 @@ fu_mm_device_qcdm_cmd(FuMmDevice *self, const guint8 *cmd, gsize cmd_len, GError
 	/* command */
 	qcdm_req = g_bytes_new(cmd, cmd_len);
 	if (g_getenv("FWUPD_MODEM_MANAGER_VERBOSE") != NULL)
-		fu_common_dump_bytes(G_LOG_DOMAIN, "writing", qcdm_req);
+		fu_dump_bytes(G_LOG_DOMAIN, "writing", qcdm_req);
 	if (!fu_io_channel_write_bytes(self->io_channel,
 				       qcdm_req,
 				       1500,
@@ -604,7 +618,7 @@ fu_mm_device_qcdm_cmd(FuMmDevice *self, const guint8 *cmd, gsize cmd_len, GError
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_MODEM_MANAGER_VERBOSE") != NULL)
-		fu_common_dump_bytes(G_LOG_DOMAIN, "read", qcdm_res);
+		fu_dump_bytes(G_LOG_DOMAIN, "read", qcdm_res);
 
 	/* command == response */
 	if (g_bytes_compare(qcdm_res, qcdm_req) != 0) {
@@ -638,7 +652,7 @@ fu_mm_device_at_cmd_cb(FuDevice *device, gpointer user_data, GError **error)
 	/* command */
 	at_req = g_bytes_new(cmd_cr, strlen(cmd_cr));
 	if (g_getenv("FWUPD_MODEM_MANAGER_VERBOSE") != NULL)
-		fu_common_dump_bytes(G_LOG_DOMAIN, "writing", at_req);
+		fu_dump_bytes(G_LOG_DOMAIN, "writing", at_req);
 	if (!fu_io_channel_write_bytes(self->io_channel,
 				       at_req,
 				       1500,
@@ -665,7 +679,7 @@ fu_mm_device_at_cmd_cb(FuDevice *device, gpointer user_data, GError **error)
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_MODEM_MANAGER_VERBOSE") != NULL)
-		fu_common_dump_bytes(G_LOG_DOMAIN, "read", at_res);
+		fu_dump_bytes(G_LOG_DOMAIN, "read", at_res);
 	buf = g_bytes_get_data(at_res, &bufsz);
 	if (bufsz < 6) {
 		g_set_error(error,
@@ -710,6 +724,58 @@ fu_mm_device_at_cmd_cb(FuDevice *device, gpointer user_data, GError **error)
 		}
 	}
 
+	if (g_strcmp0(helper->cmd, "AT+QSECBOOT=\"status\"") == 0) {
+		/*
+		 * example AT+QSECBOOT="status" response:
+		 *
+		 * \r\n+QSECBOOT: "STATUS",1\r\n\r\nOK\r\n
+		 *
+		 * Secure boot status:
+		 * 1 - enabled
+		 * 0 - disabled
+		 */
+		g_auto(GStrv) parts = g_strsplit(buf, "\r\n", -1);
+
+		for (int j = 0; parts[j] != NULL; j++) {
+			if (g_strcmp0(parts[j], "+QSECBOOT: \"status\",1") == 0) {
+				fu_device_add_flag(FU_DEVICE(self),
+						   FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
+				break;
+			}
+			if (g_strcmp0(parts[j], "+QSECBOOT: \"status\",0") == 0) {
+				fu_device_add_flag(FU_DEVICE(self),
+						   FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+				break;
+			}
+		}
+	}
+
+	if (g_strcmp0(helper->cmd, "AT+QCFG=\"secbootstat\"") == 0) {
+		/*
+		 * example AT+QSECBOOT="status" response:
+		 *
+		 * \r\n+QSECBOOT: "STATUS",1\r\n\r\nOK\r\n
+		 *
+		 * Secure boot status:
+		 * 1 - enabled
+		 * 0 - disabled
+		 */
+		g_auto(GStrv) parts = g_strsplit(buf, "\r\n", -1);
+
+		for (int j = 0; parts[j] != NULL; j++) {
+			if (g_strcmp0(parts[j], "+QCFG: \"secbootstat\",1") == 0) {
+				fu_device_add_flag(FU_DEVICE(self),
+						   FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
+				break;
+			}
+			if (g_strcmp0(parts[j], "+QCFG: \"secbootstat\",0") == 0) {
+				fu_device_add_flag(FU_DEVICE(self),
+						   FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+				break;
+			}
+		}
+	}
+
 	/* success */
 	return TRUE;
 }
@@ -792,74 +858,6 @@ fu_mm_device_detach_fastboot(FuDevice *device, GError **error)
 	return TRUE;
 }
 
-#if MM_CHECK_VERSION(1, 17, 2)
-static gboolean
-fu_mm_device_find_edl_port(FuDevice *device, GError **error)
-{
-	FuMmDevice *self = FU_MM_DEVICE(device);
-
-	for (guint i = 0; i < 30; i++) {
-		if (fu_mm_utils_find_device_file(fu_device_get_physical_id(FU_DEVICE(self)),
-						 "wwan",
-						 &self->port_edl,
-						 NULL))
-			return TRUE;
-
-		g_usleep(250 * 1000);
-	}
-
-	g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_FAILED, "Couldn't find EDL port");
-	return FALSE;
-}
-
-static gboolean
-fu_mm_device_qcdm_switch_to_edl(FuDevice *device, GError **error)
-{
-	FuMmDevice *self = FU_MM_DEVICE(device);
-	static const guint8 emergency_download[] = {0x4b, 0x65, 0x01, 0x00, 0x54, 0x0f, 0x7e};
-
-	/* trigger emergency download mode, up to 30s retrying until the QCDM
-	 * port goes away; this takes us to the EDL (embedded downloader) execution
-	 * environment */
-
-	for (guint i = 0; i < 30; i++) {
-		g_autoptr(GError) error_local = NULL;
-		g_autoptr(FuDeviceLocker) locker = NULL;
-
-		if (i > 0)
-			g_usleep(G_USEC_PER_SEC);
-
-		locker = fu_device_locker_new_full(self,
-						   (FuDeviceLockerFunc)fu_mm_device_io_open_qcdm,
-						   (FuDeviceLockerFunc)fu_mm_device_io_close,
-						   &error_local);
-		if (locker == NULL) {
-			if (i > 0 &&
-			    g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE))
-				return fu_mm_device_find_edl_port(device, error);
-			g_debug("couldn't open QCDM port to switch to EDL mode: %s",
-				error_local->message);
-			break;
-		}
-
-		if (!fu_mm_device_qcdm_cmd(self,
-					   emergency_download,
-					   G_N_ELEMENTS(emergency_download),
-					   &error_local)) {
-			g_debug("couldn't send QCDM command to switch to EDL mode: %s",
-				error_local->message);
-			break;
-		}
-	}
-
-	g_set_error_literal(error,
-			    G_IO_ERROR,
-			    G_IO_ERROR_FAILED,
-			    "Couldn't switch device to embedded downloader execution environment");
-	return FALSE;
-}
-#endif /* MM_CHECK_VERSION(1,17,2) */
-
 static gboolean
 fu_mm_device_detach(FuDevice *device, FuProgress *progress, GError **error)
 {
@@ -1208,6 +1206,7 @@ fu_mm_device_write_firmware_mbim_qdu(FuDevice *device,
 	g_autofree gchar *version = NULL;
 	g_autoptr(FuArchive) archive = NULL;
 	g_autoptr(FuDeviceLocker) locker = NULL;
+	g_autoptr(GArray) digest = NULL;
 	g_autoptr(XbBuilder) builder = xb_builder_new();
 	g_autoptr(XbBuilderSource) source = xb_builder_source_new();
 	g_autoptr(XbSilo) silo = NULL;
@@ -1264,7 +1263,14 @@ fu_mm_device_write_firmware_mbim_qdu(FuDevice *device,
 		return FALSE;
 
 	fu_progress_set_status(progress, FWUPD_STATUS_DEVICE_WRITE);
-	fu_mbim_qdu_updater_write(self->mbim_qdu_updater, filename, data, device, progress, error);
+	digest = fu_mbim_qdu_updater_write(self->mbim_qdu_updater,
+					   filename,
+					   data,
+					   device,
+					   progress,
+					   error);
+	if (digest == NULL)
+		return FALSE;
 	if (!fu_device_locker_close(locker, error))
 		return FALSE;
 
@@ -1279,10 +1285,110 @@ fu_mm_device_write_firmware_mbim_qdu(FuDevice *device,
 #endif /* MM_CHECK_VERSION(1,17,1) && MBIM_CHECK_VERSION(1,25,3) */
 
 #if MM_CHECK_VERSION(1, 17, 2)
+static gboolean
+fu_mm_find_device_file(FuDevice *device, gpointer userdata, GError **error)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+	const gchar *subsystem = (const gchar *)userdata;
+
+	return fu_mm_utils_find_device_file(fu_device_get_physical_id(FU_DEVICE(self)),
+					    subsystem,
+					    &self->port_edl,
+					    error);
+}
+
+static gboolean
+fu_mm_device_find_edl_port(FuDevice *device, const gchar *subsystem, GError **error)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+
+	g_clear_pointer(&self->port_edl, g_free);
+
+	return fu_device_retry_full(device,
+				    fu_mm_find_device_file,
+				    30,
+				    250,
+				    (gpointer)subsystem,
+				    error);
+}
+
+static gboolean
+fu_mm_device_qcdm_switch_to_edl(FuDevice *device, gpointer userdata, GError **error)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+	g_autoptr(GError) error_local = NULL;
+	g_autoptr(FuDeviceLocker) locker = NULL;
+	static const guint8 emergency_download[] = {0x4b, 0x65, 0x01, 0x00, 0x54, 0x0f, 0x7e};
+
+	locker = fu_device_locker_new_full(self,
+					   (FuDeviceLockerFunc)fu_mm_device_io_open_qcdm,
+					   (FuDeviceLockerFunc)fu_mm_device_io_close,
+					   &error_local);
+
+	if (locker == NULL) {
+		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_INVALID_FILE)) {
+			return fu_mm_device_find_edl_port(device, "wwan", error);
+		}
+		g_propagate_error(error, g_steal_pointer(&error_local));
+		return FALSE;
+	}
+
+	if (!fu_mm_device_qcdm_cmd(self,
+				   emergency_download,
+				   G_N_ELEMENTS(emergency_download),
+				   error))
+		return FALSE;
+
+	g_set_error(error,
+		    FWUPD_ERROR,
+		    FWUPD_ERROR_NOT_FOUND,
+		    "Device haven't switched to EDL yet");
+	return FALSE;
+}
+
+#if MBIM_CHECK_VERSION(1, 27, 5)
+static void
+fu_mm_device_switch_to_edl_mbim_ready(MbimDevice *device, GAsyncResult *res, GMainLoop *loop)
+{
+	/* No need to check for a response since MBIM
+	 * port goes away without sending one */
+
+	g_main_loop_quit(loop);
+}
+
+static gboolean
+fu_mm_device_mbim_switch_to_edl(FuDevice *device, GError **error)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+	g_autoptr(FuDeviceLocker) locker = NULL;
+	g_autoptr(MbimMessage) message = NULL;
+	g_autoptr(GMainLoop) mainloop = g_main_loop_new(NULL, FALSE);
+
+	locker = fu_device_locker_new_full(device,
+					   (FuDeviceLockerFunc)fu_mm_device_mbim_open,
+					   (FuDeviceLockerFunc)fu_mm_device_mbim_close,
+					   error);
+	if (locker == NULL)
+		return FALSE;
+
+	message = mbim_message_qdu_quectel_reboot_set_new(MBIM_QDU_QUECTEL_REBOOT_TYPE_EDL, NULL);
+	mbim_device_command(fu_mbim_qdu_updater_get_mbim_device(self->mbim_qdu_updater),
+			    message,
+			    5,
+			    NULL,
+			    (GAsyncReadyCallback)fu_mm_device_switch_to_edl_mbim_ready,
+			    mainloop);
+
+	g_main_loop_run(mainloop);
+
+	return TRUE;
+}
+#endif // MBIM_CHECK_VERSION(1, 27, 5)
+
 static gboolean
 fu_mm_device_firehose_open(FuMmDevice *self, GError **error)
 {
-	self->firehose_updater = fu_firehose_updater_new(self->port_edl);
+	self->firehose_updater = fu_firehose_updater_new(self->port_edl, self->sahara_loader);
 	return fu_firehose_updater_open(self->firehose_updater, error);
 }
 
@@ -1316,6 +1422,24 @@ fu_mm_device_firehose_write(FuMmDevice *self,
 					 error);
 }
 
+#if MM_CHECK_VERSION(1, 19, 1) && MBIM_CHECK_VERSION(1, 25, 7)
+static gboolean
+fu_mm_device_sahara_open(FuMmDevice *self, GError **error)
+{
+	self->sahara_loader = fu_sahara_loader_new();
+	return fu_sahara_loader_open(self->sahara_loader, self->usb_device, error);
+}
+
+static gboolean
+fu_mm_device_sahara_close(FuMmDevice *self, GError **error)
+{
+	g_autoptr(FuSaharaLoader) loader = NULL;
+
+	loader = g_steal_pointer(&self->sahara_loader);
+	return fu_sahara_loader_close(loader, error);
+}
+#endif // MM_CHECK_VERSION(1, 19, 1) && MBIM_CHECK_VERSION(1, 25, 7)
+
 static gboolean
 fu_mm_setup_firmware_dir(FuMmDevice *self, GError **error)
 {
@@ -1323,7 +1447,7 @@ fu_mm_setup_firmware_dir(FuMmDevice *self, GError **error)
 	g_autofree gchar *mm_fw_dir = NULL;
 
 	/* create a directory to store firmware files for modem-manager plugin */
-	cachedir = fu_common_get_path(FU_PATH_KIND_CACHEDIR_PKG);
+	cachedir = fu_path_from_kind(FU_PATH_KIND_CACHEDIR_PKG);
 	mm_fw_dir = g_build_filename(cachedir, "modem-manager", "firmware", NULL);
 	if (g_mkdir_with_parents(mm_fw_dir, 0700) == -1) {
 		g_set_error(error,
@@ -1335,7 +1459,7 @@ fu_mm_setup_firmware_dir(FuMmDevice *self, GError **error)
 		return FALSE;
 	}
 
-	if (!fu_common_set_firmware_search_path(mm_fw_dir, error))
+	if (!fu_kernel_set_firmware_search_path(mm_fw_dir, error))
 		return FALSE;
 
 	self->firmware_path = g_steal_pointer(&mm_fw_dir);
@@ -1344,24 +1468,18 @@ fu_mm_setup_firmware_dir(FuMmDevice *self, GError **error)
 }
 
 static gboolean
-fu_mm_copy_firehose_prog(FuMmDevice *self, FuArchive *archive, GError **error)
+fu_mm_copy_firehose_prog(FuMmDevice *self, GBytes *prog, GError **error)
 {
 	g_autofree gchar *qcom_fw_dir = NULL;
 	g_autofree gchar *firehose_file_path = NULL;
-	g_autoptr(GBytes) firehose_prog = NULL;
-
-	/* lookup firehose-prog bootloader */
-	firehose_prog = fu_archive_lookup_by_fn(archive, "firehose-prog.mbn", error);
-	if (firehose_prog == NULL)
-		return FALSE;
 
 	qcom_fw_dir = g_build_filename(self->firmware_path, "qcom", NULL);
-	if (!fu_common_mkdir_parent(qcom_fw_dir, error))
+	if (!fu_path_mkdir_parent(qcom_fw_dir, error))
 		return FALSE;
 
 	firehose_file_path = g_build_filename(qcom_fw_dir, "prog_firehose_sdx24.mbn", NULL);
 
-	if (!fu_common_set_contents_bytes(firehose_file_path, firehose_prog, error))
+	if (!fu_bytes_set_contents(firehose_file_path, prog, error))
 		return FALSE;
 
 	return TRUE;
@@ -1370,7 +1488,7 @@ fu_mm_copy_firehose_prog(FuMmDevice *self, FuArchive *archive, GError **error)
 static gboolean
 fu_mm_prepare_firmware_search_path(FuMmDevice *self, GError **error)
 {
-	self->restore_firmware_path = fu_common_get_firmware_search_path(NULL);
+	self->restore_firmware_path = fu_kernel_get_firmware_search_path(NULL);
 
 	return fu_mm_setup_firmware_dir(self, error);
 }
@@ -1379,9 +1497,9 @@ static gboolean
 fu_mm_restore_firmware_search_path(FuMmDevice *self, GError **error)
 {
 	if (self->restore_firmware_path != NULL && strlen(self->restore_firmware_path) > 0)
-		return fu_common_set_firmware_search_path(self->restore_firmware_path, error);
+		return fu_kernel_set_firmware_search_path(self->restore_firmware_path, error);
 
-	return fu_common_reset_firmware_search_path(error);
+	return fu_kernel_reset_firmware_search_path(error);
 }
 
 static gboolean
@@ -1392,6 +1510,7 @@ fu_mm_device_write_firmware_firehose(FuDevice *device,
 {
 	FuMmDevice *self = FU_MM_DEVICE(device);
 	GBytes *firehose_rawprogram;
+	GBytes *firehose_prog;
 	g_autoptr(FuDeviceLocker) locker = NULL;
 	g_autoptr(FuArchive) archive = NULL;
 	g_autoptr(XbSilo) firehose_rawprogram_silo = NULL;
@@ -1400,32 +1519,14 @@ fu_mm_device_write_firmware_firehose(FuDevice *device,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 10);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 90);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 10, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 90, NULL);
 
 	/* decompress entire archive ahead of time */
 	archive = fu_archive_new(fw, FU_ARCHIVE_FLAG_IGNORE_PATH, error);
 	if (archive == NULL)
 		return FALSE;
-	fu_progress_step_done(progress);
-
-	/* modify firmware search path and restore it before function returns */
-	locker = fu_device_locker_new_full(self,
-					   (FuDeviceLockerFunc)fu_mm_prepare_firmware_search_path,
-					   (FuDeviceLockerFunc)fu_mm_restore_firmware_search_path,
-					   error);
-	if (locker == NULL)
-		return FALSE;
-
-	/* firehose modems that switch to the EDL mode over QCDM port require
-	 * firehose binary to be present in the firmware-loader search path. */
-	if (!fu_mm_copy_firehose_prog(self, archive, error))
-		return FALSE;
-
-	/* switch to embedded downloader (EDL) execution environment */
-	if (!fu_mm_device_qcdm_switch_to_edl(FU_DEVICE(self), error))
-		return FALSE;
 
 	/* lookup and validate firehose-rawprogram actions */
 	firehose_rawprogram = fu_archive_lookup_by_fn(archive, "firehose-rawprogram.xml", error);
@@ -1439,6 +1540,72 @@ fu_mm_device_write_firmware_firehose(FuDevice *device,
 		g_prefix_error(error, "Invalid firehose rawprogram manifest: ");
 		return FALSE;
 	}
+
+	/* lookup firehose-prog bootloader */
+	firehose_prog = fu_archive_lookup_by_fn(archive, "firehose-prog.mbn", error);
+	if (firehose_prog == NULL)
+		return FALSE;
+	fu_progress_step_done(progress);
+
+	/* Firehose program needs to be loaded to the modem before firehose update process can
+	 * start. Generally, modems use Sahara protocol to load the firehose binary.
+	 *
+	 * In case of MHI PCI modems, the mhi_wwan driver reads the firehose binary from the
+	 * firmware-loader and writes it to the modem.
+	 **/
+	if (g_strrstr(fu_device_get_physical_id(device), "pci") && self->port_qcdm != NULL) {
+		/* modify firmware search path and restore it before function returns */
+		locker = fu_device_locker_new_full(
+		    self,
+		    (FuDeviceLockerFunc)fu_mm_prepare_firmware_search_path,
+		    (FuDeviceLockerFunc)fu_mm_restore_firmware_search_path,
+		    error);
+		if (locker == NULL)
+			return FALSE;
+
+		/* firehose modems that use mhi_pci drivers require firehose binary
+		 * to be present in the firmware-loader search path. */
+		if (!fu_mm_copy_firehose_prog(self, firehose_prog, error))
+			return FALSE;
+		/* trigger emergency download mode, up to 30s retrying until the QCDM
+		 * port goes away; this takes us to the EDL (embedded downloader) execution
+		 * environment */
+		if (!fu_device_retry_full(FU_DEVICE(self),
+					  fu_mm_device_qcdm_switch_to_edl,
+					  30,
+					  1000,
+					  NULL,
+					  error))
+			return FALSE;
+
+		g_debug("found edl port: %s", self->port_edl);
+	}
+#if MM_CHECK_VERSION(1, 19, 1) && MBIM_CHECK_VERSION(1, 25, 7)
+	else if ((FU_MM_DEVICE(self)->update_methods & MM_MODEM_FIRMWARE_UPDATE_METHOD_SAHARA) &&
+		 self->port_mbim != NULL) {
+		/* switch to emergency download (EDL) execution environment */
+		if (!fu_mm_device_mbim_switch_to_edl(device, error))
+			return FALSE;
+
+		locker = fu_device_locker_new_full(self,
+						   (FuDeviceLockerFunc)fu_mm_device_sahara_open,
+						   (FuDeviceLockerFunc)fu_mm_device_sahara_close,
+						   error);
+		if (locker == NULL)
+			return FALSE;
+
+		/* use sahara port to load firehose binary */
+		if (!fu_sahara_loader_run(self->sahara_loader, firehose_prog, error))
+			return FALSE;
+	}
+#endif // MM_CHECK_VERSION(1, 19, 1) && MBIM_CHECK_VERSION(1, 25, 7)
+	else {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "suitable port not found");
+		return FALSE;
+	}
 	fu_progress_step_done(progress);
 
 	/* download all files in the firehose-rawprogram manifest via Firehose */
@@ -1594,6 +1761,19 @@ fu_mm_device_setup_branch_at(FuMmDevice *self, GError **error)
 {
 	g_autoptr(FuDeviceLocker) locker = NULL;
 
+	/* nothing to do if there is no AT port available or
+	 * ModemManagerBranchAtCommand quirk is not set */
+	if (self->port_at == NULL || self->branch_at == NULL)
+		return TRUE;
+
+	if (fu_device_has_flag(self, FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD)) {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "Firmware branches are not supported if the devices is signed");
+		return FALSE;
+	}
+
 	/* Create IO channel to send AT commands to the modem */
 	locker = fu_device_locker_new_full(self,
 					   (FuDeviceLockerFunc)fu_mm_device_io_open,
@@ -1602,44 +1782,125 @@ fu_mm_device_setup_branch_at(FuMmDevice *self, GError **error)
 	if (locker == NULL)
 		return FALSE;
 
-	/* firmware branch AT command may fail if not implemented,
-	 * clear error if not supported */
-	if (self->branch_at != NULL) {
-		g_autoptr(GError) error_branch = NULL;
-		if (!fu_mm_device_at_cmd(self, self->branch_at, TRUE, &error_branch))
-			g_debug("unable to get firmware branch: %s", error_branch->message);
-	}
+	if (!fu_mm_device_at_cmd(self, self->branch_at, TRUE, error))
+		return FALSE;
 
-	/* success */
-	return TRUE;
-}
-
-static gboolean
-fu_mm_device_setup(FuDevice *device, GError **error)
-{
-	FuMmDevice *self = FU_MM_DEVICE(device);
-
-	if (self->port_at != NULL) {
-		if (!fu_mm_device_setup_branch_at(self, error))
-			return FALSE;
-	}
-	if (fu_device_get_branch(device) != NULL)
-		g_debug("using firmware branch: %s", fu_device_get_branch(device));
+	if (fu_device_get_branch(self) != NULL)
+		g_debug("using firmware branch: %s", fu_device_get_branch(self));
 	else
 		g_debug("using firmware branch: default");
 
 	return TRUE;
 }
 
+static void
+fu_mm_device_setup_secboot_status_quectel(FuMmDevice *self)
+{
+	const gchar *version = fu_device_get_version(FU_DEVICE(self));
+	g_autofree gchar *name = NULL;
+
+	const gchar *at_cmd[] = {"AT+QSECBOOT=\"status\"", "AT+QCFG=\"secbootstat\"", NULL};
+
+	struct {
+		const gchar *name;
+		const gchar *version;
+	} secboot[] = {{"EM05GF", "EM05GFAR07A07M1G_01.005.01.005"},
+		       {"EM05CE", "EM05CEFCR08A16M1G_LNV"},
+		       {NULL, NULL}};
+
+	if (self->port_at != NULL) {
+		g_autoptr(FuDeviceLocker) locker = NULL;
+		g_autoptr(GError) error_local = NULL;
+
+		/* Create IO channel to send AT commands to the modem */
+		locker = fu_device_locker_new_full(self,
+						   (FuDeviceLockerFunc)fu_mm_device_io_open,
+						   (FuDeviceLockerFunc)fu_mm_device_io_close,
+						   &error_local);
+		if (locker == NULL) {
+			g_debug("failed to open AT port: %s", error_local->message);
+			return;
+		}
+
+		/* Try to query sec boot status with AT commands */
+		for (guint i = 0; at_cmd[i] != NULL; i++) {
+			if (!fu_mm_device_at_cmd(self, at_cmd[i], TRUE, &error_local))
+				g_debug("AT command failed (%s): %s",
+					at_cmd[i],
+					error_local->message);
+			else
+				return;
+		}
+	}
+
+	/* find model name and compare with table from Quectel */
+	if (version == NULL)
+		return;
+	name = g_strndup(version, 6);
+	for (guint i = 0; secboot[i].name != NULL; i++) {
+		if (g_strcmp0(name, secboot[i].name) == 0) {
+			if (fu_version_compare(version,
+					       secboot[i].version,
+					       FWUPD_VERSION_FORMAT_PLAIN) >= 0) {
+				fu_device_add_flag(FU_DEVICE(self),
+						   FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
+			} else {
+				fu_device_add_flag(FU_DEVICE(self),
+						   FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+			}
+			return;
+		}
+	}
+}
+
+static void
+fu_mm_device_setup_secboot_status(FuDevice *device)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+
+	if (fu_device_has_vendor_id(device, "USB:0x2C7C") ||
+	    fu_device_has_vendor_id(device, "PCI:0x1EAC"))
+		fu_mm_device_setup_secboot_status_quectel(self);
+}
+
+static gboolean
+fu_mm_device_setup(FuDevice *device, GError **error)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+	g_autoptr(GError) error_local = NULL;
+
+	fu_mm_device_setup_secboot_status(device);
+
+	if (!fu_mm_device_setup_branch_at(self, &error_local))
+		g_warning("Failed to set firmware branch: %s", error_local->message);
+
+	return TRUE;
+}
+
+static void
+fu_mm_device_incorporate(FuDevice *device, FuDevice *donor_device)
+{
+	FuMmDevice *self = FU_MM_DEVICE(device);
+	FuMmDevice *donor = FU_MM_DEVICE(donor_device);
+
+	self->update_methods = fu_mm_device_get_update_methods(donor);
+	self->detach_fastboot_at = g_strdup(fu_mm_device_get_detach_fastboot_at(donor));
+	self->inhibition_uid = g_strdup(fu_mm_device_get_inhibition_uid(donor));
+	self->port_at_ifnum = fu_mm_device_get_port_at_ifnum(donor);
+	self->port_qmi_ifnum = fu_mm_device_get_port_qmi_ifnum(donor);
+	self->port_mbim_ifnum = fu_mm_device_get_port_mbim_ifnum(donor);
+	g_set_object(&self->manager, donor->manager);
+}
+
 static void
 fu_mm_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
@@ -1668,7 +1929,8 @@ fu_mm_device_finalize(GObject *object)
 		g_source_remove(self->attach_idle);
 	if (self->qmi_pdc_active_id)
 		g_array_unref(self->qmi_pdc_active_id);
-	g_object_unref(self->manager);
+	if (self->manager != NULL)
+		g_object_unref(self->manager);
 	if (self->omodem != NULL)
 		g_object_unref(self->omodem);
 	g_free(self->detach_fastboot_at);
@@ -1698,6 +1960,7 @@ fu_mm_device_class_init(FuMmDeviceClass *klass)
 	klass_device->write_firmware = fu_mm_device_write_firmware;
 	klass_device->attach = fu_mm_device_attach;
 	klass_device->set_progress = fu_mm_device_set_progress;
+	klass_device->incorporate = fu_mm_device_incorporate;
 
 	/**
 	 * FuMmDevice::attach-finished:
@@ -1728,39 +1991,16 @@ fu_mm_device_new(FuContext *ctx, MMManager *manager, MMObject *omodem)
 	return self;
 }
 
-FuPluginMmInhibitedDeviceInfo *
-fu_plugin_mm_inhibited_device_info_new(FuMmDevice *device)
+FuMmDevice *
+fu_mm_shadow_device_new(FuMmDevice *device)
 {
-	FuPluginMmInhibitedDeviceInfo *info;
-
-	info = g_new0(FuPluginMmInhibitedDeviceInfo, 1);
-	info->physical_id = g_strdup(fu_device_get_physical_id(FU_DEVICE(device)));
-	info->vendor = g_strdup(fu_device_get_vendor(FU_DEVICE(device)));
-	info->name = g_strdup(fu_device_get_name(FU_DEVICE(device)));
-	info->version = g_strdup(fu_device_get_version(FU_DEVICE(device)));
-	info->guids = fu_device_get_guids(FU_DEVICE(device));
-	info->update_methods = fu_mm_device_get_update_methods(device);
-	info->detach_fastboot_at = g_strdup(fu_mm_device_get_detach_fastboot_at(device));
-	info->port_at_ifnum = fu_mm_device_get_port_at_ifnum(device);
-	info->port_qmi_ifnum = fu_mm_device_get_port_qmi_ifnum(device);
-	info->port_mbim_ifnum = fu_mm_device_get_port_mbim_ifnum(device);
-	info->inhibited_uid = g_strdup(fu_mm_device_get_inhibition_uid(device));
-
-	return info;
-}
-
-void
-fu_plugin_mm_inhibited_device_info_free(FuPluginMmInhibitedDeviceInfo *info)
-{
-	g_free(info->inhibited_uid);
-	g_free(info->physical_id);
-	g_free(info->vendor);
-	g_free(info->name);
-	g_free(info->version);
-	if (info->guids)
-		g_ptr_array_unref(info->guids);
-	g_free(info->detach_fastboot_at);
-	g_free(info);
+	FuMmDevice *shadow_device = NULL;
+	shadow_device = g_object_new(FU_TYPE_MM_DEVICE,
+				     "context",
+				     fu_device_get_context(FU_DEVICE(device)),
+				     NULL);
+	fu_device_incorporate(FU_DEVICE(shadow_device), FU_DEVICE(device));
+	return shadow_device;
 }
 
 FuUsbDevice *
@@ -1779,23 +2019,12 @@ fu_mm_device_set_usb_device(FuMmDevice *self, FuUsbDevice *usb_device)
 }
 
 FuMmDevice *
-fu_mm_device_udev_new(FuContext *ctx, MMManager *manager, FuPluginMmInhibitedDeviceInfo *info)
+fu_mm_device_udev_new(FuContext *ctx, MMManager *manager, FuMmDevice *shadow_device)
 {
 	FuMmDevice *self = g_object_new(FU_TYPE_MM_DEVICE, "context", ctx, NULL);
-	g_debug("creating udev-based mm device at %s", info->physical_id);
-	self->manager = g_object_ref(manager);
-	fu_device_set_physical_id(FU_DEVICE(self), info->physical_id);
-	fu_device_set_vendor(FU_DEVICE(self), info->vendor);
-	fu_device_set_name(FU_DEVICE(self), info->name);
-	fu_device_set_version(FU_DEVICE(self), info->version);
-	self->update_methods = info->update_methods;
-	self->detach_fastboot_at = g_strdup(info->detach_fastboot_at);
-	self->port_at_ifnum = info->port_at_ifnum;
-	self->port_qmi_ifnum = info->port_qmi_ifnum;
-
-	for (guint i = 0; i < info->guids->len; i++)
-		fu_device_add_guid(FU_DEVICE(self), g_ptr_array_index(info->guids, i));
-
+	g_debug("creating udev-based mm device at %s",
+		fu_device_get_physical_id(FU_DEVICE(shadow_device)));
+	fu_device_incorporate(FU_DEVICE(self), FU_DEVICE(shadow_device));
 	return self;
 }
 
