@@ -17,6 +17,10 @@ G_DECLARE_FINAL_TYPE(FuMmDevice, fu_mm_device, FU, MM_DEVICE, FuDevice)
 
 FuMmDevice *
 fu_mm_device_new(FuContext *ctx, MMManager *manager, MMObject *omodem);
+FuUsbDevice *
+fu_mm_device_get_usb_device(FuMmDevice *self);
+void
+fu_mm_device_set_usb_device(FuMmDevice *self, FuUsbDevice *usb_device);
 const gchar *
 fu_mm_device_get_inhibition_uid(FuMmDevice *device);
 const gchar *
@@ -30,30 +34,10 @@ fu_mm_device_get_port_mbim_ifnum(FuMmDevice *device);
 MMModemFirmwareUpdateMethod
 fu_mm_device_get_update_methods(FuMmDevice *device);
 
-/* support for udev-based devices */
-typedef struct {
-	gchar *inhibited_uid;
-	gchar *physical_id;
-	gchar *vendor;
-	gchar *name;
-	gchar *version;
-	GPtrArray *guids;
-	MMModemFirmwareUpdateMethod update_methods;
-	gchar *detach_fastboot_at;
-	gint port_at_ifnum;
-	gint port_qmi_ifnum;
-	gint port_mbim_ifnum;
-} FuPluginMmInhibitedDeviceInfo;
-
-FuPluginMmInhibitedDeviceInfo *
-fu_plugin_mm_inhibited_device_info_new(FuMmDevice *device);
-void
-fu_plugin_mm_inhibited_device_info_free(FuPluginMmInhibitedDeviceInfo *info);
-G_DEFINE_AUTOPTR_CLEANUP_FUNC(FuPluginMmInhibitedDeviceInfo,
-			      fu_plugin_mm_inhibited_device_info_free);
-
 FuMmDevice *
-fu_mm_device_udev_new(FuContext *ctx, MMManager *manager, FuPluginMmInhibitedDeviceInfo *info);
+fu_mm_shadow_device_new(FuMmDevice *device);
+FuMmDevice *
+fu_mm_device_udev_new(FuContext *ctx, MMManager *manager, FuMmDevice *shadow_device);
 void
 fu_mm_device_udev_add_port(FuMmDevice *device,
 			   const gchar *subsystem,
