@@ -31,11 +31,11 @@ fu_redfish_device_to_string(FuDevice *device, guint idt, GString *str)
 	FuRedfishDevice *self = FU_REDFISH_DEVICE(device);
 	FuRedfishDevicePrivate *priv = GET_PRIVATE(self);
 	if (priv->milestone > 0x0)
-		fu_common_string_append_kx(str, idt, "Milestone", priv->milestone);
+		fu_string_append_kx(str, idt, "Milestone", priv->milestone);
 	if (priv->build != NULL)
-		fu_common_string_append_kv(str, idt, "Build", priv->build);
-	fu_common_string_append_ku(str, idt, "ResetPretDelay", priv->reset_pre_delay);
-	fu_common_string_append_ku(str, idt, "ResetPostDelay", priv->reset_post_delay);
+		fu_string_append(str, idt, "Build", priv->build);
+	fu_string_append_ku(str, idt, "ResetPretDelay", priv->reset_pre_delay);
+	fu_string_append_ku(str, idt, "ResetPostDelay", priv->reset_post_delay);
 }
 
 static void
@@ -62,7 +62,6 @@ fu_redfish_device_set_device_class(FuRedfishDevice *self, const gchar *tmp)
 		return;
 	}
 	g_debug("no icon mapping for %s", tmp);
-	fu_device_add_icon(FU_DEVICE(self), "audio-card");
 }
 
 static gboolean
@@ -70,7 +69,6 @@ fu_redfish_device_probe_related_pcie_item(FuRedfishDevice *self, const gchar *ur
 {
 	FuRedfishDevicePrivate *priv = GET_PRIVATE(self);
 	JsonObject *json_obj;
-	const gchar *subsystem = "PCI";
 	guint64 vendor_id = 0x0;
 	guint64 model_id = 0x0;
 	guint64 subsystem_vendor_id = 0x0;
@@ -95,36 +93,28 @@ fu_redfish_device_probe_related_pcie_item(FuRedfishDevice *self, const gchar *ur
 	if (json_object_has_member(json_obj, "VendorId")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "VendorId");
 		if (tmp != NULL && tmp[0] != '\0') {
-			if (!fu_common_strtoull_full(tmp, &vendor_id, 0, G_MAXUINT16, error))
+			if (!fu_strtoull(tmp, &vendor_id, 0, G_MAXUINT16, error))
 				return FALSE;
 		}
 	}
 	if (json_object_has_member(json_obj, "DeviceId")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "DeviceId");
 		if (tmp != NULL && tmp[0] != '\0') {
-			if (!fu_common_strtoull_full(tmp, &model_id, 0, G_MAXUINT16, error))
+			if (!fu_strtoull(tmp, &model_id, 0, G_MAXUINT16, error))
 				return FALSE;
 		}
 	}
 	if (json_object_has_member(json_obj, "SubsystemVendorId")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "SubsystemVendorId");
 		if (tmp != NULL && tmp[0] != '\0') {
-			if (!fu_common_strtoull_full(tmp,
-						     &subsystem_vendor_id,
-						     0,
-						     G_MAXUINT16,
-						     error))
+			if (!fu_strtoull(tmp, &subsystem_vendor_id, 0, G_MAXUINT16, error))
 				return FALSE;
 		}
 	}
 	if (json_object_has_member(json_obj, "SubsystemId")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "SubsystemId");
 		if (tmp != NULL && tmp[0] != '\0') {
-			if (!fu_common_strtoull_full(tmp,
-						     &subsystem_model_id,
-						     0,
-						     G_MAXUINT16,
-						     error))
+			if (!fu_strtoull(tmp, &subsystem_model_id, 0, G_MAXUINT16, error))
 				return FALSE;
 		}
 	}
@@ -137,25 +127,19 @@ fu_redfish_device_probe_related_pcie_item(FuRedfishDevice *self, const gchar *ur
 	}
 
 	/* add more instance IDs if possible */
-	if (vendor_id != 0x0 && model_id != 0x0) {
-		g_autofree gchar *devid1 = NULL;
-		devid1 = g_strdup_printf("%s\\VEN_%04X&DEV_%04X",
-					 subsystem,
-					 (guint)vendor_id,
-					 (guint)model_id);
-		fu_device_add_instance_id(FU_DEVICE(self), devid1);
-	}
-	if (vendor_id != 0x0 && model_id != 0x0 && subsystem_vendor_id != 0x0 &&
-	    subsystem_model_id != 0x0) {
-		g_autofree gchar *devid2 = NULL;
-		devid2 = g_strdup_printf("%s\\VEN_%04X&DEV_%04X&SUBSYS_%04X%04X",
-					 subsystem,
-					 (guint)vendor_id,
-					 (guint)model_id,
+	if (vendor_id != 0x0)
+		fu_device_add_instance_u16(FU_DEVICE(self), "VEN", vendor_id);
+	if (model_id != 0x0)
+		fu_device_add_instance_u16(FU_DEVICE(self), "DEV", model_id);
+	if (subsystem_vendor_id != 0x0 && subsystem_model_id != 0x0) {
+		g_autofree gchar *subsys = NULL;
+		subsys = g_strdup_printf("%04X%04X",
 					 (guint)subsystem_vendor_id,
 					 (guint)subsystem_model_id);
-		fu_device_add_instance_id(FU_DEVICE(self), devid2);
+		fu_device_add_instance_str(FU_DEVICE(self), "SUBSYS", subsys);
 	}
+	fu_device_build_instance_id(FU_DEVICE(self), NULL, "PCI", "VEN", "DEV", NULL);
+	fu_device_build_instance_id(FU_DEVICE(self), NULL, "PCI", "VEN", "DEV", "SUBSYS", NULL);
 
 	/* success */
 	return TRUE;
@@ -278,7 +262,7 @@ fu_redfish_device_set_version_lenovo(FuRedfishDevice *self, const gchar *version
 	}
 	priv->build = g_strndup(out_build + 2, 1);
 	fu_device_set_version(FU_DEVICE(self), out_version);
-	fu_device_set_version_format(FU_DEVICE(self), fu_common_version_guess_format(out_version));
+	fu_device_set_version_format(FU_DEVICE(self), fu_version_guess_format(out_version));
 	return TRUE;
 }
 
@@ -298,8 +282,7 @@ fu_redfish_device_set_version(FuRedfishDevice *self, const gchar *tmp)
 		g_autofree gchar *ver = fu_redfish_common_fix_version(tmp);
 		if (ver != NULL) {
 			fu_device_set_version(FU_DEVICE(self), ver);
-			fu_device_set_version_format(FU_DEVICE(self),
-						     fu_common_version_guess_format(ver));
+			fu_device_set_version_format(FU_DEVICE(self), fu_version_guess_format(ver));
 		}
 	}
 }
@@ -453,31 +436,31 @@ fu_redfish_device_probe(FuDevice *dev, GError **error)
 		}
 	}
 
+	/* add IDs */
+	fu_device_add_instance_strsafe(dev, "VENDOR", fu_device_get_vendor(dev));
+	fu_device_add_instance_str(dev, "SOFTWAREID", guid);
+	fu_device_add_instance_str(dev, "ID", fu_device_get_backend_id(dev));
+
 	/* some vendors use a GUID, others use an ID like BMC-AFBT-10 */
 	guid_lower = g_ascii_strdown(guid, -1);
 	if (fwupd_guid_is_valid(guid_lower)) {
 		fu_device_add_guid(dev, guid_lower);
-	} else if (fu_device_get_vendor(dev) != NULL) {
-		const gchar *instance_id_suffix = "";
-		g_autofree gchar *instance_id = NULL;
+	} else {
 		if (fu_device_has_private_flag(dev, FU_REDFISH_DEVICE_FLAG_UNSIGNED_BUILD))
-			instance_id_suffix = "&TYPE_UNSIGNED";
-		instance_id = g_strdup_printf("REDFISH\\VENDOR_%s&SOFTWAREID_%s%s",
-					      fu_device_get_vendor(dev),
-					      guid,
-					      instance_id_suffix);
-		g_strdelimit(instance_id, " ", '_');
-		fu_device_add_instance_id(dev, instance_id);
+			fu_device_add_instance_str(dev, "TYPE", "UNSIGNED");
+
+		fu_device_build_instance_id(dev,
+					    NULL,
+					    "REDFISH",
+					    "VENDOR",
+					    "SOFTWAREID",
+					    "TYPE",
+					    NULL);
+		fu_device_build_instance_id(dev, NULL, "REDFISH", "VENDOR", "SOFTWAREID", NULL);
 	}
 
 	/* used for quirking and parenting */
-	if (fu_device_get_vendor(dev) != NULL && fu_device_get_backend_id(dev) != NULL) {
-		g_autofree gchar *instance_id = NULL;
-		instance_id = g_strdup_printf("REDFISH\\VENDOR_%s&ID_%s",
-					      fu_device_get_vendor(dev),
-					      fu_device_get_backend_id(dev));
-		fu_device_add_instance_id(dev, instance_id);
-	}
+	fu_device_build_instance_id(dev, NULL, "REDFISH", "VENDOR", "ID", NULL);
 
 	if (json_object_has_member(member, "Name")) {
 		const gchar *tmp = json_object_get_string_member(member, "Name");
@@ -786,13 +769,13 @@ fu_redfish_device_set_quirk_kv(FuDevice *device,
 	guint64 tmp = 0;
 
 	if (g_strcmp0(key, "RedfishResetPreDelay") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT, error))
 			return FALSE;
 		priv->reset_pre_delay = tmp;
 		return TRUE;
 	}
 	if (g_strcmp0(key, "RedfishResetPostDelay") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT, error))
 			return FALSE;
 		priv->reset_post_delay = tmp;
 		return TRUE;
