@@ -14,9 +14,13 @@
 static void
 fu_plugin_rts54hid_init(FuPlugin *plugin)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_RTS54HID_DEVICE);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_RTS54HID_MODULE);
+}
+
+static void
+fu_plugin_rts54hid_load(FuContext *ctx)
+{
 	fu_context_add_quirk_key(ctx, "Rts54TargetAddr");
 	fu_context_add_quirk_key(ctx, "Rts54I2cSpeed");
 	fu_context_add_quirk_key(ctx, "Rts54RegisterAddrLen");
@@ -26,5 +30,6 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_rts54hid_load;
 	vfuncs->init = fu_plugin_rts54hid_init;
 }
