@@ -25,8 +25,8 @@ static void
 fu_rts54hid_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuRts54HidDevice *self = FU_RTS54HID_DEVICE(device);
-	fu_common_string_append_kb(str, idt, "FwAuth", self->fw_auth);
-	fu_common_string_append_kb(str, idt, "DualBank", self->dual_bank);
+	fu_string_append_kb(str, idt, "FwAuth", self->fw_auth);
+	fu_string_append_kb(str, idt, "DualBank", self->dual_bank);
 }
 
 static gboolean
@@ -295,10 +295,10 @@ fu_rts54hid_device_write_firmware(FuDevice *device,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 46);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 52);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1); /* reset */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 46, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 52, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, "reset");
 
 	/* get default image */
 	fw = fu_firmware_get_bytes(firmware, error);
@@ -355,10 +355,10 @@ fu_rts54hid_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0);	 /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 62);	 /* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 38); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0);	 /* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 62, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 38, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0, "reload");
 }
 
 static void
