@@ -33,9 +33,9 @@ fu_rts54hub_rtd21xx_device_to_string(FuDevice *module, guint idt, GString *str)
 {
 	FuRts54hubRtd21xxDevice *self = FU_RTS54HUB_RTD21XX_DEVICE(module);
 	FuRts54hubRtd21xxDevicePrivate *priv = GET_PRIVATE(self);
-	fu_common_string_append_kx(str, idt, "TargetAddr", priv->target_addr);
-	fu_common_string_append_kx(str, idt, "I2cSpeed", priv->i2c_speed);
-	fu_common_string_append_kx(str, idt, "RegisterAddrLen", priv->register_addr_len);
+	fu_string_append_kx(str, idt, "TargetAddr", priv->target_addr);
+	fu_string_append_kx(str, idt, "I2cSpeed", priv->i2c_speed);
+	fu_string_append_kx(str, idt, "RegisterAddrLen", priv->register_addr_len);
 }
 
 static FuRts54HubDevice *
@@ -61,7 +61,7 @@ fu_rts54hub_rtd21xx_device_set_quirk_kv(FuDevice *device,
 
 	/* load target address from quirks */
 	if (g_strcmp0(key, "Rts54TargetAddr") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		priv->target_addr = tmp;
 		return TRUE;
@@ -69,7 +69,7 @@ fu_rts54hub_rtd21xx_device_set_quirk_kv(FuDevice *device,
 
 	/* load i2c speed from quirks */
 	if (g_strcmp0(key, "Rts54I2cSpeed") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, FU_RTS54HUB_I2C_SPEED_LAST - 1, error))
+		if (!fu_strtoull(value, &tmp, 0, FU_RTS54HUB_I2C_SPEED_LAST - 1, error))
 			return FALSE;
 		priv->i2c_speed = tmp;
 		return TRUE;
@@ -77,7 +77,7 @@ fu_rts54hub_rtd21xx_device_set_quirk_kv(FuDevice *device,
 
 	/* load register address length from quirks */
 	if (g_strcmp0(key, "Rts54RegisterAddrLen") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		priv->register_addr_len = tmp;
 		return TRUE;
