@@ -96,7 +96,7 @@ fu_synaptics_cape_device_set_report(FuSynapticsCapeDevice *self,
 	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
 
 	if (g_getenv("FWUPD_SYNAPTICS_CAPE_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "SetReport", (guint8 *)data, sizeof(*data));
+		fu_dump_raw(G_LOG_DOMAIN, "SetReport", (guint8 *)data, sizeof(*data));
 
 	return fu_hid_device_set_report(FU_HID_DEVICE(self),
 					FU_SYNAPTICS_CAPE_DEVICE_GOLEM_REPORT_ID,
@@ -127,7 +127,7 @@ fu_synaptics_cape_device_get_report(FuSynapticsCapeDevice *self,
 		return FALSE;
 
 	if (g_getenv("FWUPD_SYNAPTICS_CAPE_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "GetReport", (guint8 *)data, sizeof(*data));
+		fu_dump_raw(G_LOG_DOMAIN, "GetReport", (guint8 *)data, sizeof(*data));
 
 	/* success */
 	return TRUE;
@@ -157,7 +157,7 @@ fu_synaptics_cape_device_get_report_intr(FuSynapticsCapeDevice *self,
 	}
 
 	if (g_getenv("FWUPD_SYNAPTICS_CAPE_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "GetReport", (guint8 *)data, sizeof(*data));
+		fu_dump_raw(G_LOG_DOMAIN, "GetReport", (guint8 *)data, sizeof(*data));
 
 	/* success */
 	return TRUE;
@@ -327,8 +327,7 @@ fu_synaptics_cape_device_sendcmd_ex(FuSynapticsCapeDevice *self,
 
 	/* copies returned data if it is GET command */
 	if (is_get) {
-		req->data_len =
-		    (gint16)fu_common_read_uint16((guint8 *)&report.cmd, G_LITTLE_ENDIAN);
+		req->data_len = (gint16)fu_memread_uint16((guint8 *)&report.cmd, G_LITTLE_ENDIAN);
 
 		for (int i = 0; i < FU_SYNAPTICS_CAPE_CMD_MAX_DATA_LEN; i++)
 			req->data[i] = GUINT32_FROM_LE(report.cmd.data[i]);
@@ -377,7 +376,7 @@ fu_synaptics_cape_device_to_string(FuDevice *device, guint idt, GString *str)
 
 	g_return_if_fail(FU_IS_SYNAPTICS_CAPE_DEVICE(self));
 
-	fu_common_string_append_ku(str, idt, "ActivePartition", self->active_partition);
+	fu_string_append_ku(str, idt, "ActivePartition", self->active_partition);
 }
 
 /* resets device */
@@ -475,7 +474,7 @@ fu_synaptics_cape_device_setup_version(FuSynapticsCapeDevice *self, GError **err
 	    (GUINT32_FROM_LE(cmd.data[0]) << 24) | ((GUINT32_FROM_LE(cmd.data[1]) & 0xFF) << 16) |
 	    ((GUINT32_FROM_LE(cmd.data[2]) & 0xFF) << 8) | (GUINT32_FROM_LE(cmd.data[3]) & 0xFF);
 
-	version_str = fu_common_version_from_uint32(version_raw, FWUPD_VERSION_FORMAT_QUAD);
+	version_str = fu_version_from_uint32(version_raw, FWUPD_VERSION_FORMAT_QUAD);
 	fu_device_set_version(FU_DEVICE(self), version_str);
 	fu_device_set_version_raw(FU_DEVICE(self), version_raw);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
@@ -554,8 +553,9 @@ fu_synaptics_cape_device_prepare_firmware(FuDevice *device,
 	if (self->active_partition == 1)
 		offset = bufsz / 2;
 
-	new_fw = g_bytes_new_from_bytes(fw, offset, bufsz / 2);
-
+	new_fw = fu_bytes_new_offset(fw, offset, bufsz / 2, error);
+	if (new_fw == NULL)
+		return NULL;
 	if (!fu_firmware_parse(firmware, new_fw, flags, error))
 		return NULL;
 
@@ -703,10 +703,10 @@ fu_synaptics_cape_device_write_firmware(FuDevice *device,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 2); /* header */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 69);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 0);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 29);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 2, "device-write-hdr");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 69, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 29, NULL);
 
 	fw_header = fu_firmware_get_image_by_id_bytes(firmware, FU_FIRMWARE_ID_HEADER, error);
 	if (fw_header == NULL)
@@ -757,10 +757,10 @@ static void
 fu_synaptics_cape_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
