@@ -14,9 +14,13 @@
 static void
 fu_plugin_synaptics_cxaudio_init(FuPlugin *plugin)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_SYNAPTICS_CXAUDIO_DEVICE);
 	fu_plugin_add_firmware_gtype(plugin, NULL, FU_TYPE_SYNAPTICS_CXAUDIO_FIRMWARE);
+}
+
+static void
+fu_plugin_synaptics_cxaudio_load(FuContext *ctx)
+{
 	fu_context_add_quirk_key(ctx, "CxaudioChipIdBase");
 	fu_context_add_quirk_key(ctx, "CxaudioPatch1ValidAddr");
 	fu_context_add_quirk_key(ctx, "CxaudioPatch2ValidAddr");
@@ -27,5 +31,6 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_synaptics_cxaudio_load;
 	vfuncs->init = fu_plugin_synaptics_cxaudio_init;
 }
