@@ -78,16 +78,16 @@ fu_synaprom_device_cmd_send(FuSynapromDevice *device,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_NO_PROFILE);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 25);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 75);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 25, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 75, NULL);
 
 	if (g_getenv("FWUPD_SYNAPROM_VERBOSE") != NULL) {
-		fu_common_dump_full(G_LOG_DOMAIN,
-				    "REQST",
-				    request->data,
-				    request->len,
-				    16,
-				    FU_DUMP_FLAGS_SHOW_ADDRESSES);
+		fu_dump_full(G_LOG_DOMAIN,
+			     "REQST",
+			     request->data,
+			     request->len,
+			     16,
+			     FU_DUMP_FLAGS_SHOW_ADDRESSES);
 	}
 	ret = g_usb_device_bulk_transfer(usb_device,
 					 FU_SYNAPROM_USB_REQUEST_EP,
@@ -125,12 +125,12 @@ fu_synaprom_device_cmd_send(FuSynapromDevice *device,
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_SYNAPROM_VERBOSE") != NULL) {
-		fu_common_dump_full(G_LOG_DOMAIN,
-				    "REPLY",
-				    reply->data,
-				    actual_len,
-				    16,
-				    FU_DUMP_FLAGS_SHOW_ADDRESSES);
+		fu_dump_full(G_LOG_DOMAIN,
+			     "REPLY",
+			     reply->data,
+			     actual_len,
+			     16,
+			     FU_DUMP_FLAGS_SHOW_ADDRESSES);
 	}
 	fu_progress_step_done(progress);
 
@@ -332,8 +332,8 @@ fu_synaprom_device_write_fw(FuSynapromDevice *self,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 99);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 99, NULL);
 
 	/* collect chunks */
 	buf = g_bytes_get_data(fw, &bufsz);
@@ -344,12 +344,7 @@ fu_synaprom_device_write_fw(FuSynapromDevice *self,
 		g_autoptr(GByteArray) chunk = g_byte_array_new();
 
 		/* get chunk size */
-		if (!fu_common_read_uint32_safe(buf,
-						bufsz,
-						offset,
-						&chunksz,
-						G_LITTLE_ENDIAN,
-						error))
+		if (!fu_memread_uint32_safe(buf, bufsz, offset, &chunksz, G_LITTLE_ENDIAN, error))
 			return FALSE;
 		offset += sizeof(guint32);
 
@@ -496,11 +491,10 @@ static void
 fu_synaprom_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 96, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0, "reload");
 }
 
 static void
