@@ -6,9 +6,9 @@
 
 #include "config.h"
 
+#include <fwupdplugin.h>
+
 #include <fcntl.h>
-#include <fwupd.h>
-#include <glib.h>
 #include <glib/gprintf.h>
 #include <glib/gstdio.h>
 #include <gudev/gudev.h>
@@ -889,7 +889,7 @@ fu_thunderbolt_gudev_uevent_cb(GUdevClient *gudev_client,
 		g_autoptr(FuUdevDevice) device = NULL;
 		g_autoptr(GError) error_local = NULL;
 
-		device = fu_udev_device_new_with_context(tt->ctx, udev_device);
+		device = fu_udev_device_new(tt->ctx, udev_device);
 		if (!fu_device_probe(FU_DEVICE(device), &error_local)) {
 			g_warning("failed to probe: %s", error_local->message);
 			return;
@@ -921,6 +921,7 @@ test_set_up(ThunderboltTest *tt, gconstpointer params)
 	g_autofree gchar *pluginfn = NULL;
 	g_autofree gchar *sysfs = NULL;
 	g_autoptr(GError) error = NULL;
+	g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 	const gchar *udev_subsystems[] = {"thunderbolt", NULL};
 
 	tt->ctx = fu_context_new();
@@ -946,7 +947,7 @@ test_set_up(ThunderboltTest *tt, gconstpointer params)
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
-	ret = fu_plugin_runner_startup(tt->plugin, &error);
+	ret = fu_plugin_runner_startup(tt->plugin, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -1142,8 +1143,10 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull(ctl_data);
 
 	/* parse controller image */
-	ret =
-	    fu_firmware_parse(FU_FIRMWARE(firmware_ctl), ctl_data, FWUPD_INSTALL_FLAG_NONE, &error);
+	ret = fu_firmware_parse(FU_FIRMWARE(firmware_ctl),
+				ctl_data,
+				FWUPD_INSTALL_FLAG_NO_SEARCH,
+				&error);
 	g_assert_true(ret);
 	g_assert_no_error(error);
 
@@ -1157,8 +1160,10 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull(fwi_data);
 
 	/* parse */
-	ret =
-	    fu_firmware_parse(FU_FIRMWARE(firmware_fwi), fwi_data, FWUPD_INSTALL_FLAG_NONE, &error);
+	ret = fu_firmware_parse(FU_FIRMWARE(firmware_fwi),
+				fwi_data,
+				FWUPD_INSTALL_FLAG_NO_SEARCH,
+				&error);
 	g_assert_true(ret);
 	g_assert_no_error(error);
 
@@ -1172,8 +1177,10 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull(bad_data);
 
 	/* parse; should fail, bad image */
-	ret =
-	    fu_firmware_parse(FU_FIRMWARE(firmware_bad), bad_data, FWUPD_INSTALL_FLAG_NONE, &error);
+	ret = fu_firmware_parse(FU_FIRMWARE(firmware_bad),
+				bad_data,
+				FWUPD_INSTALL_FLAG_NO_SEARCH,
+				&error);
 	g_assert_false(ret);
 	g_assert_error(error, FWUPD_ERROR, FWUPD_ERROR_READ);
 	g_debug("expected image validation error [ctl]: %s", error->message);
@@ -1233,8 +1240,12 @@ test_update_working(ThunderboltTest *tt, gconstpointer user_data)
 	 * after the time in the last parameter (given in ms) */
 	up_ctx = mock_tree_prepare_for_update(tree, plugin, "42.23", fw_data, 1000);
 	g_assert_nonnull(up_ctx);
-	ret =
-	    fu_plugin_runner_write_firmware(plugin, tree->fu_device, fw_data, progress, 0, &error);
+	ret = fu_plugin_runner_write_firmware(plugin,
+					      tree->fu_device,
+					      fw_data,
+					      progress,
+					      FWUPD_INSTALL_FLAG_NO_SEARCH,
+					      &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -1283,8 +1294,12 @@ test_update_wd19(ThunderboltTest *tt, gconstpointer user_data)
 	fu_device_add_flag(tree->fu_device, FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE);
 	version_before = fu_device_get_version(tree->fu_device);
 
-	ret =
-	    fu_plugin_runner_write_firmware(plugin, tree->fu_device, fw_data, progress, 0, &error);
+	ret = fu_plugin_runner_write_firmware(plugin,
+					      tree->fu_device,
+					      fw_data,
+					      progress,
+					      FWUPD_INSTALL_FLAG_NO_SEARCH,
+					      &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -1317,8 +1332,12 @@ test_update_fail(ThunderboltTest *tt, gconstpointer user_data)
 	up_ctx = mock_tree_prepare_for_update(tree, plugin, "42.23", fw_data, 1000);
 	up_ctx->result = UPDATE_FAIL_DEVICE_INTERNAL;
 
-	ret =
-	    fu_plugin_runner_write_firmware(plugin, tree->fu_device, fw_data, progress, 0, &error);
+	ret = fu_plugin_runner_write_firmware(plugin,
+					      tree->fu_device,
+					      fw_data,
+					      progress,
+					      FWUPD_INSTALL_FLAG_NO_SEARCH,
+					      &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -1366,8 +1385,12 @@ test_update_fail_nowshow(ThunderboltTest *tt, gconstpointer user_data)
 	up_ctx = mock_tree_prepare_for_update(tree, plugin, "42.23", fw_data, 1000);
 	up_ctx->result = UPDATE_FAIL_DEVICE_NOSHOW;
 
-	ret =
-	    fu_plugin_runner_write_firmware(plugin, tree->fu_device, fw_data, progress, 0, &error);
+	ret = fu_plugin_runner_write_firmware(plugin,
+					      tree->fu_device,
+					      fw_data,
+					      progress,
+					      FWUPD_INSTALL_FLAG_NO_SEARCH,
+					      &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 
@@ -1380,11 +1403,13 @@ test_update_fail_nowshow(ThunderboltTest *tt, gconstpointer user_data)
 int
 main(int argc, char **argv)
 {
-	g_autofree gchar *quirkdatadir = NULL;
-
+	g_autofree gchar *testdatadir = NULL;
 	g_test_init(&argc, &argv, NULL);
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
+	testdatadir = g_test_build_filename(G_TEST_DIST, "tests", NULL);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", testdatadir, TRUE);
+
 	g_test_add("/thunderbolt/basic",
 		   ThunderboltTest,
 		   NULL,
