@@ -72,13 +72,10 @@ fu_thunderbolt_controller_to_string(FuDevice *device, guint idt, GString *str)
 	/* FuThunderboltDevice->to_string */
 	FU_DEVICE_CLASS(fu_thunderbolt_controller_parent_class)->to_string(device, idt, str);
 
-	fu_common_string_append_kv(str,
-				   idt,
-				   "Device Type",
-				   fu_thunderbolt_controller_kind_to_string(self));
-	fu_common_string_append_kb(str, idt, "Safe Mode", self->safe_mode);
-	fu_common_string_append_kb(str, idt, "Native mode", self->is_native);
-	fu_common_string_append_ku(str, idt, "Generation", self->gen);
+	fu_string_append(str, idt, "Device Type", fu_thunderbolt_controller_kind_to_string(self));
+	fu_string_append_kb(str, idt, "Safe Mode", self->safe_mode);
+	fu_string_append_kb(str, idt, "Native mode", self->is_native);
+	fu_string_append_ku(str, idt, "Generation", self->gen);
 }
 
 static gboolean
@@ -127,7 +124,7 @@ fu_thunderbolt_controller_read_status_block(FuThunderboltController *self, GErro
 		return FALSE;
 	if (!fu_firmware_parse(FU_FIRMWARE(firmware),
 			       controller_fw,
-			       FWUPD_INSTALL_FLAG_NONE,
+			       FWUPD_INSTALL_FLAG_NO_SEARCH,
 			       error))
 		return FALSE;
 	self->is_native = fu_thunderbolt_firmware_is_native(firmware);
@@ -174,6 +171,19 @@ fu_thunderbolt_controller_setup_usb4(FuThunderboltController *self, GError **err
 	return TRUE;
 }
 
+static void
+fu_thunderbolt_controller_set_signed(FuDevice *device)
+{
+	FuThunderboltController *self = FU_THUNDERBOLT_CONTROLLER(device);
+	GUdevDevice *udev_device = fu_udev_device_get_dev(FU_UDEV_DEVICE(device));
+	const gchar *tmp;
+
+	/* if it's a USB4 type not of host and generation 3; it's Intel */
+	tmp = g_udev_device_get_property(udev_device, "USB4_TYPE");
+	if (g_strcmp0(tmp, "host") != 0 && self->gen == 3)
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
+}
+
 static gboolean
 fu_thunderbolt_controller_setup(FuDevice *device, GError **error)
 {
@@ -290,12 +300,17 @@ fu_thunderbolt_controller_setup(FuDevice *device, GError **error)
 	} else {
 		fu_device_add_internal_flag(device, FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
 	}
-	if (self->controller_kind == FU_THUNDERBOLT_CONTROLLER_KIND_HOST) {
+	if (self->controller_kind == FU_THUNDERBOLT_CONTROLLER_KIND_HOST &&
+	    fu_device_has_private_flag(FU_DEVICE(self),
+				       FU_THUNDERBOLT_DEVICE_FLAG_FORCE_ENUMERATION)) {
 		g_autoptr(GError) error_local = NULL;
 		if (!fu_thunderbolt_controller_setup_usb4(self, &error_local))
 			g_warning("failed to setup host: %s", error_local->message);
 	}
 
+	/* set up signed payload attribute */
+	fu_thunderbolt_controller_set_signed(device);
+
 	/* success */
 	return TRUE;
 }
