@@ -23,31 +23,148 @@ struct FuPluginData {
 	FuUefiBgrt *bgrt;
 	FuVolume *esp;
 	FuBackend *backend;
+	GFile *fwupd_efi_file;
+	GFileMonitor *fwupd_efi_monitor;
 };
 
+static void
+fu_plugin_uefi_capsule_to_string(FuPlugin *plugin, guint idt, GString *str)
+{
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	fu_backend_add_string(priv->backend, idt, str);
+	if (priv->bgrt != NULL) {
+		fu_string_append_kb(str,
+				    idt,
+				    "BgrtSupported",
+				    fu_uefi_bgrt_get_supported(priv->bgrt));
+	}
+}
+
+static gboolean
+fu_plugin_uefi_capsule_fwupd_efi_parse(FuPlugin *plugin, GError **error)
+{
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	FuContext *ctx = fu_plugin_get_context(plugin);
+	const guint8 needle[] = "f\0w\0u\0p\0d\0-\0e\0f\0i\0 \0v\0e\0r\0s\0i\0o\0n\0 ";
+	gsize bufsz = 0;
+	gsize offset = 0;
+	guint16 version_tmp[16] = {0x0};
+	g_autofree gchar *buf = NULL;
+	g_autofree gchar *version = NULL;
+
+	/* find the UTF-16 version string */
+	if (!g_file_load_contents(priv->fwupd_efi_file, NULL, &buf, &bufsz, NULL, error))
+		return FALSE;
+	if (!fu_memmem_safe((const guint8 *)buf, bufsz, needle, sizeof(needle), &offset, error)) {
+		g_autofree gchar *fn = g_file_get_path(priv->fwupd_efi_file);
+		g_prefix_error(error, "searching %s: ", fn);
+		return FALSE;
+	}
+
+	/* align */
+	if (!fu_memcpy_safe((guint8 *)version_tmp,
+			    sizeof(version_tmp),
+			    0x0, /* dst */
+			    (const guint8 *)buf,
+			    bufsz,
+			    offset + sizeof(needle),
+			    sizeof(version_tmp) - sizeof(guint16),
+			    error))
+		return FALSE;
+
+	/* convert to UTF-8 */
+	version = g_utf16_to_utf8(version_tmp, -1, NULL, NULL, error);
+	if (version == NULL) {
+		g_autofree gchar *fn = g_file_get_path(priv->fwupd_efi_file);
+		g_prefix_error(error, "converting %s: ", fn);
+		return FALSE;
+	}
+
+	/* success */
+	fu_context_add_runtime_version(ctx, "org.freedesktop.fwupd-efi", version);
+	return TRUE;
+}
+
+static void
+fu_plugin_uefi_capsule_fwupd_efi_changed_cb(GFileMonitor *monitor,
+					    GFile *file,
+					    GFile *other_file,
+					    GFileMonitorEvent event_type,
+					    gpointer user_data)
+{
+	FuPlugin *plugin = FU_PLUGIN(user_data);
+	FuContext *ctx = fu_plugin_get_context(plugin);
+	g_autoptr(GError) error_local = NULL;
+
+	if (!fu_plugin_uefi_capsule_fwupd_efi_parse(plugin, &error_local)) {
+		fu_context_add_runtime_version(ctx, "org.freedesktop.fwupd-efi", "1.0");
+		g_warning("failed to get new fwupd efi runtime version: %s", error_local->message);
+		return;
+	}
+}
+
+static gboolean
+fu_plugin_uefi_capsule_fwupd_efi_probe(FuPlugin *plugin, GError **error)
+{
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	FuContext *ctx = fu_plugin_get_context(plugin);
+	g_autofree gchar *fn = NULL;
+
+	/* find the app binary */
+	fn = fu_uefi_get_built_app_path(error);
+	if (fn == NULL)
+		return FALSE;
+	priv->fwupd_efi_file = g_file_new_for_path(fn);
+	priv->fwupd_efi_monitor =
+	    g_file_monitor_file(priv->fwupd_efi_file, G_FILE_MONITOR_NONE, NULL, error);
+	if (priv->fwupd_efi_monitor == NULL)
+		return FALSE;
+	g_signal_connect(G_FILE_MONITOR(priv->fwupd_efi_monitor),
+			 "changed",
+			 G_CALLBACK(fu_plugin_uefi_capsule_fwupd_efi_changed_cb),
+			 plugin);
+	if (!fu_plugin_uefi_capsule_fwupd_efi_parse(plugin, error)) {
+		fu_context_add_runtime_version(ctx, "org.freedesktop.fwupd-efi", "1.0");
+		return FALSE;
+	}
+	return TRUE;
+}
+
 static void
 fu_plugin_uefi_capsule_init(FuPlugin *plugin)
 {
 	FuContext *ctx = fu_plugin_get_context(plugin);
-	FuPluginData *data = fu_plugin_alloc_data(plugin, sizeof(FuPluginData));
-	data->backend = fu_uefi_backend_new(ctx);
-	data->bgrt = fu_uefi_bgrt_new();
+	FuPluginData *priv = fu_plugin_alloc_data(plugin, sizeof(FuPluginData));
+	g_autoptr(GError) error_local = NULL;
+
+	priv->backend = fu_uefi_backend_new(ctx);
+	priv->bgrt = fu_uefi_bgrt_new();
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_RUN_AFTER, "upower");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "tpm");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "dell");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "linux_lockdown");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "acpi_phat");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_CONFLICTS, "uefi"); /* old name */
+
+	/* add a requirement on the fwupd-efi version -- which can change  */
+	if (!fu_plugin_uefi_capsule_fwupd_efi_probe(plugin, &error_local))
+		g_debug("failed to get fwupd-efi runtime version: %s", error_local->message);
 }
 
 static void
 fu_plugin_uefi_capsule_destroy(FuPlugin *plugin)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
-	if (data->esp != NULL)
-		g_object_unref(data->esp);
-	g_object_unref(data->backend);
-	g_object_unref(data->bgrt);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
+	if (priv->esp != NULL)
+		g_object_unref(priv->esp);
+	if (priv->fwupd_efi_file != NULL)
+		g_object_unref(priv->fwupd_efi_file);
+	if (priv->fwupd_efi_monitor != NULL) {
+		g_file_monitor_cancel(priv->fwupd_efi_monitor);
+		g_object_unref(priv->fwupd_efi_monitor);
+	}
+	g_object_unref(priv->backend);
+	g_object_unref(priv->bgrt);
 }
 
 static gboolean
@@ -60,22 +177,22 @@ fu_plugin_uefi_capsule_clear_results(FuPlugin *plugin, FuDevice *device, GError
 static void
 fu_plugin_uefi_capsule_add_security_attrs(FuPlugin *plugin, FuSecurityAttrs *attrs)
 {
-#ifdef HAVE_HSI
 	g_autoptr(FwupdSecurityAttr) attr = NULL;
 	g_autoptr(GError) error = NULL;
 
 	/* create attr */
-	attr = fwupd_security_attr_new(FWUPD_SECURITY_ATTR_ID_UEFI_SECUREBOOT);
-	fwupd_security_attr_set_plugin(attr, fu_plugin_get_name(plugin));
+	attr = fu_plugin_security_attr_new(plugin, FWUPD_SECURITY_ATTR_ID_UEFI_SECUREBOOT);
 	fu_security_attrs_append(attrs, attr);
 
 	/* SB not available or disabled */
-	if (!fu_efivar_secure_boot_enabled_full(&error)) {
+	if (!fu_efivar_secure_boot_enabled(&error)) {
 		if (g_error_matches(error, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
 			fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_NOT_FOUND);
 			return;
 		}
+		fu_security_attr_add_bios_target_value(attr, "SecureBoot", "enable");
 		fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ISSUE);
+		fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW);
 		fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED);
 		return;
 	}
@@ -83,7 +200,6 @@ fu_plugin_uefi_capsule_add_security_attrs(FuPlugin *plugin, FuSecurityAttrs *att
 	/* success */
 	fwupd_security_attr_add_flag(attr, FWUPD_SECURITY_ATTR_FLAG_SUCCESS);
 	fwupd_security_attr_set_result(attr, FWUPD_SECURITY_ATTR_RESULT_ENABLED);
-#endif
 }
 
 static GBytes *
@@ -97,9 +213,9 @@ fu_plugin_uefi_capsule_get_splash_data(guint width, guint height, GError **error
 	g_autoptr(GBytes) blob_archive = NULL;
 
 	/* load archive */
-	datadir_pkg = fu_common_get_path(FU_PATH_KIND_DATADIR_PKG);
+	datadir_pkg = fu_path_from_kind(FU_PATH_KIND_DATADIR_PKG);
 	filename_archive = g_build_filename(datadir_pkg, "uefi-capsule-ux.tar.xz", NULL);
-	blob_archive = fu_common_get_contents_bytes(filename_archive, error);
+	blob_archive = fu_bytes_get_contents(filename_archive, error);
 	if (blob_archive == NULL)
 		return NULL;
 	archive = fu_archive_new(blob_archive, FU_ARCHIVE_FLAG_NONE, error);
@@ -138,7 +254,7 @@ fu_plugin_uefi_capsule_write_splash_data(FuPlugin *plugin,
 					 GBytes *blob,
 					 GError **error)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	guint32 screen_x, screen_y;
 	gsize buf_size = g_bytes_get_size(blob);
 	gssize size;
@@ -170,11 +286,11 @@ fu_plugin_uefi_capsule_write_splash_data(FuPlugin *plugin,
 	}
 
 	/* save to a predicatable filename */
-	esp_path = fu_volume_get_mount_point(data->esp);
+	esp_path = fu_volume_get_mount_point(priv->esp);
 	directory = fu_uefi_get_esp_path_for_os(device, esp_path);
 	basename = g_strdup_printf("fwupd-%s.cap", FU_EFIVAR_GUID_UX_CAPSULE);
 	fn = g_build_filename(directory, "fw", basename, NULL);
-	if (!fu_common_mkdir_parent(fn, error))
+	if (!fu_path_mkdir_parent(fn, error))
 		return FALSE;
 	ofile = g_file_new_for_path(fn);
 	ostream =
@@ -194,17 +310,17 @@ fu_plugin_uefi_capsule_write_splash_data(FuPlugin *plugin,
 	header.image_type = 0;
 	header.reserved = 0;
 	header.x_offset = (screen_x / 2) - (width / 2);
-	if (screen_y == fu_uefi_bgrt_get_height(data->bgrt)) {
+	if (screen_y == fu_uefi_bgrt_get_height(priv->bgrt)) {
 		header.y_offset = (gdouble)screen_y * 0.8f;
 	} else {
 		header.y_offset =
-		    fu_uefi_bgrt_get_yoffset(data->bgrt) + fu_uefi_bgrt_get_height(data->bgrt);
+		    fu_uefi_bgrt_get_yoffset(priv->bgrt) + fu_uefi_bgrt_get_height(priv->bgrt);
 	};
 
 	/* header, payload and image has to add to zero */
-	csum += fu_common_sum8((guint8 *)&capsule_header, sizeof(capsule_header));
-	csum += fu_common_sum8((guint8 *)&header, sizeof(header));
-	csum += fu_common_sum8_bytes(blob);
+	csum += fu_sum8((guint8 *)&capsule_header, sizeof(capsule_header));
+	csum += fu_sum8((guint8 *)&header, sizeof(header));
+	csum += fu_sum8_bytes(blob);
 	header.checksum = 0x100 - csum;
 
 	/* write capsule file */
@@ -233,7 +349,7 @@ fu_plugin_uefi_capsule_write_splash_data(FuPlugin *plugin,
 static gboolean
 fu_plugin_uefi_capsule_update_splash(FuPlugin *plugin, FuDevice *device, GError **error)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	guint best_idx = G_MAXUINT;
 	guint32 lowest_border_pixels = G_MAXUINT;
 	guint32 screen_height = 768;
@@ -260,7 +376,7 @@ fu_plugin_uefi_capsule_update_splash(FuPlugin *plugin, FuDevice *device, GError
 	}
 
 	/* get the boot graphics resource table data */
-	if (!fu_uefi_bgrt_get_supported(data->bgrt)) {
+	if (!fu_uefi_bgrt_get_supported(priv->bgrt)) {
 		g_set_error_literal(error,
 				    FWUPD_ERROR,
 				    FWUPD_ERROR_NOT_SUPPORTED,
@@ -361,11 +477,15 @@ fu_plugin_uefi_capsule_load_config(FuPlugin *plugin, FuDevice *device)
 	gboolean fallback_removable_path;
 	guint64 sz_reqd = FU_UEFI_COMMON_REQUIRED_ESP_FREE_SPACE;
 	g_autofree gchar *require_esp_free_space = NULL;
+	g_autoptr(GError) error_local = NULL;
 
 	/* parse free space needed for ESP */
 	require_esp_free_space = fu_plugin_get_config_value(plugin, "RequireESPFreeSpace");
-	if (require_esp_free_space != NULL)
-		sz_reqd = fu_common_strtoull(require_esp_free_space);
+	if (require_esp_free_space != NULL) {
+		if (!fu_strtoull(require_esp_free_space, &sz_reqd, 0, G_MAXUINT64, &error_local)) {
+			g_warning("invalid ESP free space specified: %s", error_local->message);
+		}
+	}
 	fu_device_set_metadata_integer(device, "RequireESPFreeSpace", sz_reqd);
 
 	/* shim used for SB or not? */
@@ -383,19 +503,19 @@ fu_plugin_uefi_capsule_load_config(FuPlugin *plugin, FuDevice *device)
 static void
 fu_plugin_uefi_capsule_register_proxy_device(FuPlugin *plugin, FuDevice *device)
 {
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	g_autoptr(FuUefiDevice) dev = NULL;
 	g_autoptr(GError) error_local = NULL;
 
 	/* load all configuration variables */
-	dev = fu_uefi_backend_device_new_from_dev(FU_UEFI_BACKEND(data->backend), device);
+	dev = fu_uefi_backend_device_new_from_dev(FU_UEFI_BACKEND(priv->backend), device);
 	fu_plugin_uefi_capsule_load_config(plugin, FU_DEVICE(dev));
-	if (data->esp == NULL)
-		data->esp = fu_common_get_esp_default(&error_local);
-	if (data->esp == NULL) {
+	if (priv->esp == NULL)
+		priv->esp = fu_volume_new_esp_default(&error_local);
+	if (priv->esp == NULL) {
 		fu_device_inhibit(device, "no-esp", error_local->message);
 	} else {
-		fu_uefi_device_set_esp(dev, data->esp);
+		fu_uefi_device_set_esp(dev, priv->esp);
 		fu_device_uninhibit(device, "no-esp");
 	}
 	fu_plugin_device_add(plugin, FU_DEVICE(dev));
@@ -506,16 +626,16 @@ static void
 fu_plugin_uefi_capsule_test_secure_boot(FuPlugin *plugin)
 {
 	const gchar *result_str = "Disabled";
-	if (fu_efivar_secure_boot_enabled())
+	if (fu_efivar_secure_boot_enabled(NULL))
 		result_str = "Enabled";
 	fu_plugin_add_report_metadata(plugin, "SecureBoot", result_str);
 }
 
 static gboolean
-fu_plugin_uefi_capsule_startup(FuPlugin *plugin, GError **error)
+fu_plugin_uefi_capsule_startup(FuPlugin *plugin, FuProgress *progress, GError **error)
 {
 	FuContext *ctx = fu_plugin_get_context(plugin);
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	guint64 nvram_total;
 	g_autofree gchar *esp_path = NULL;
 	g_autofree gchar *nvram_total_str = NULL;
@@ -535,12 +655,12 @@ fu_plugin_uefi_capsule_startup(FuPlugin *plugin, GError **error)
 
 	/* use GRUB to load updates */
 	if (fu_plugin_get_config_value_boolean(plugin, "EnableGrubChainLoad")) {
-		fu_uefi_backend_set_device_gtype(FU_UEFI_BACKEND(data->backend),
+		fu_uefi_backend_set_device_gtype(FU_UEFI_BACKEND(priv->backend),
 						 FU_TYPE_UEFI_GRUB_DEVICE);
 	}
 
 	/* check we can use this backend */
-	if (!fu_backend_setup(data->backend, &error_local)) {
+	if (!fu_backend_setup(priv->backend, progress, &error_local)) {
 		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_WRITE)) {
 			fu_plugin_add_flag(plugin, FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED);
 			fu_plugin_add_flag(plugin, FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE);
@@ -562,8 +682,8 @@ fu_plugin_uefi_capsule_startup(FuPlugin *plugin, GError **error)
 	/* override the default ESP path */
 	esp_path = fu_plugin_get_config_value(plugin, "OverrideESPMountPoint");
 	if (esp_path != NULL) {
-		data->esp = fu_common_get_esp_for_path(esp_path, error);
-		if (data->esp == NULL) {
+		priv->esp = fu_volume_new_esp_for_path(esp_path, error);
+		if (priv->esp == NULL) {
 			g_prefix_error(error,
 				       "invalid OverrideESPMountPoint=%s "
 				       "specified in config: ",
@@ -692,7 +812,7 @@ fu_plugin_uefi_capsule_check_cod_support(FuPlugin *plugin, GError **error)
 		g_prefix_error(error, "failed to read EFI variable: ");
 		return FALSE;
 	}
-	if (!fu_common_read_uint64_safe(buf, bufsz, 0x0, &value, G_LITTLE_ENDIAN, error))
+	if (!fu_memread_uint64_safe(buf, bufsz, 0x0, &value, G_LITTLE_ENDIAN, error))
 		return FALSE;
 	if ((value & EFI_OS_INDICATIONS_FILE_CAPSULE_DELIVERY_SUPPORTED) == 0) {
 		g_set_error_literal(error,
@@ -720,10 +840,9 @@ fu_plugin_uefi_capsule_check_cod_support(FuPlugin *plugin, GError **error)
 }
 
 static gboolean
-fu_plugin_uefi_capsule_coldplug(FuPlugin *plugin, GError **error)
+fu_plugin_uefi_capsule_coldplug(FuPlugin *plugin, FuProgress *progress, GError **error)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
-	FuPluginData *data = fu_plugin_get_data(plugin);
+	FuPluginData *priv = fu_plugin_get_data(plugin);
 	const gchar *str;
 	gboolean has_fde = FALSE;
 	g_autoptr(GError) error_udisks2 = NULL;
@@ -731,15 +850,25 @@ fu_plugin_uefi_capsule_coldplug(FuPlugin *plugin, GError **error)
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GPtrArray) devices = NULL;
 
-	if (data->esp == NULL) {
-		data->esp = fu_common_get_esp_default(&error_udisks2);
-		if (data->esp == NULL) {
+	/* progress */
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 63, "find-esp");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 1, "check-cod");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 8, "check-bitlocker");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 1, "coldplug");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 26, "add-devices");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 1, "setup-bgrt");
+
+	if (priv->esp == NULL) {
+		priv->esp = fu_volume_new_esp_default(&error_udisks2);
+		if (priv->esp == NULL) {
 			fu_plugin_add_flag(plugin, FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND);
 			fu_plugin_add_flag(plugin, FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE);
 			fu_plugin_add_flag(plugin, FWUPD_PLUGIN_FLAG_USER_WARNING);
 			g_warning("cannot find default ESP: %s", error_udisks2->message);
 		}
 	}
+	fu_progress_step_done(progress);
 
 	/* firmware may lie */
 	if (!fu_plugin_get_config_value_boolean(plugin, "DisableCapsuleUpdateOnDisk")) {
@@ -747,28 +876,30 @@ fu_plugin_uefi_capsule_coldplug(FuPlugin *plugin, GError **error)
 		if (!fu_plugin_uefi_capsule_check_cod_support(plugin, &error_cod)) {
 			g_debug("not using CapsuleOnDisk support: %s", error_cod->message);
 		} else {
-			fu_uefi_backend_set_device_gtype(FU_UEFI_BACKEND(data->backend),
+			fu_uefi_backend_set_device_gtype(FU_UEFI_BACKEND(priv->backend),
 							 FU_TYPE_UEFI_COD_DEVICE);
 		}
 	}
+	fu_progress_step_done(progress);
 
 	/*  warn the user that BitLocker might ask for recovery key after fw update */
 	if (!fu_common_check_full_disk_encryption(&error_fde)) {
 		g_debug("FDE in use, set flag: %s", error_fde->message);
 		has_fde = TRUE;
 	}
+	fu_progress_step_done(progress);
 
 	/* add each device */
-	if (!fu_backend_coldplug(data->backend, error))
+	if (!fu_backend_coldplug(priv->backend, fu_progress_get_child(progress), error))
 		return FALSE;
-	devices = fu_backend_get_devices(data->backend);
+	fu_progress_step_done(progress);
+	devices = fu_backend_get_devices(priv->backend);
 	for (guint i = 0; i < devices->len; i++) {
 		FuUefiDevice *dev = g_ptr_array_index(devices, i);
 		g_autoptr(GError) error_device = NULL;
 
-		fu_device_set_context(FU_DEVICE(dev), ctx);
-		if (data->esp != NULL)
-			fu_uefi_device_set_esp(dev, data->esp);
+		if (priv->esp != NULL)
+			fu_uefi_device_set_esp(dev, priv->esp);
 		if (!fu_plugin_uefi_capsule_coldplug_device(plugin, dev, &error_device)) {
 			if (g_error_matches(error_device, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED)) {
 				g_warning("skipping device that failed coldplug: %s",
@@ -796,14 +927,16 @@ fu_plugin_uefi_capsule_coldplug(FuPlugin *plugin, GError **error)
 
 		fu_plugin_device_add(plugin, FU_DEVICE(dev));
 	}
+	fu_progress_step_done(progress);
 
 	/* for debugging problems later */
 	fu_plugin_uefi_capsule_test_secure_boot(plugin);
-	if (!fu_uefi_bgrt_setup(data->bgrt, &error_local))
+	if (!fu_uefi_bgrt_setup(priv->bgrt, &error_local))
 		g_debug("BGRT setup failed: %s", error_local->message);
-	str = fu_uefi_bgrt_get_supported(data->bgrt) ? "Enabled" : "Disabled";
+	str = fu_uefi_bgrt_get_supported(priv->bgrt) ? "Enabled" : "Disabled";
 	g_debug("UX Capsule support : %s", str);
 	fu_plugin_add_report_metadata(plugin, "UEFIUXCapsule", str);
+	fu_progress_step_done(progress);
 
 	return TRUE;
 }
@@ -814,6 +947,7 @@ fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 	vfuncs->build_hash = FU_BUILD_HASH;
 	vfuncs->init = fu_plugin_uefi_capsule_init;
 	vfuncs->destroy = fu_plugin_uefi_capsule_destroy;
+	vfuncs->to_string = fu_plugin_uefi_capsule_to_string;
 	vfuncs->clear_results = fu_plugin_uefi_capsule_clear_results;
 	vfuncs->add_security_attrs = fu_plugin_uefi_capsule_add_security_attrs;
 	vfuncs->device_registered = fu_plugin_uefi_capsule_device_registered;
