@@ -15,7 +15,6 @@
 #include <unistd.h>
 
 #include "fu-context-private.h"
-#include "fu-ucs2.h"
 #include "fu-uefi-backend.h"
 #include "fu-uefi-cod-device.h"
 #include "fu-uefi-common.h"
@@ -81,7 +80,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &verbose,
 	     /* TRANSLATORS: command line option */
-	     _("Show extra debugging information"),
+	     N_("Show extra debugging information"),
 	     NULL},
 	    {"version",
 	     '\0',
@@ -89,7 +88,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_version,
 	     /* TRANSLATORS: command line option */
-	     _("Display version"),
+	     N_("Display version"),
 	     NULL},
 	    {"log",
 	     'L',
@@ -97,7 +96,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_log,
 	     /* TRANSLATORS: command line option */
-	     _("Show the debug log from the last attempted update"),
+	     N_("Show the debug log from the last attempted update"),
 	     NULL},
 	    {"list",
 	     'l',
@@ -105,7 +104,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_list,
 	     /* TRANSLATORS: command line option */
-	     _("List supported firmware updates"),
+	     N_("List supported firmware updates"),
 	     NULL},
 	    {"supported",
 	     's',
@@ -113,7 +112,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_supported,
 	     /* TRANSLATORS: command line option */
-	     _("Query for firmware update support"),
+	     N_("Query for firmware update support"),
 	     NULL},
 	    {"info",
 	     'i',
@@ -121,7 +120,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_info,
 	     /* TRANSLATORS: command line option */
-	     _("Show the information of firmware update status"),
+	     N_("Show the information of firmware update status"),
 	     NULL},
 	    {"enable",
 	     'e',
@@ -129,7 +128,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_enable,
 	     /* TRANSLATORS: command line option */
-	     _("Enable firmware update support on supported systems"),
+	     N_("Enable firmware update support on supported systems"),
 	     NULL},
 	    {"esp-path",
 	     'p',
@@ -137,16 +136,16 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_STRING,
 	     &esp_path,
 	     /* TRANSLATORS: command line option */
-	     _("Override the default ESP path"),
+	     N_("Override the default ESP path"),
 	     /* TRANSLATORS: command argument: uppercase, spaces->dashes */
-	     _("PATH")},
+	     N_("PATH")},
 	    {"set-debug",
 	     'd',
 	     G_OPTION_FLAG_NONE,
 	     G_OPTION_ARG_NONE,
 	     &action_set_debug,
 	     /* TRANSLATORS: command line option */
-	     _("Set the debugging flag during update"),
+	     N_("Set the debugging flag during update"),
 	     NULL},
 	    {"unset-debug",
 	     'D',
@@ -154,7 +153,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_NONE,
 	     &action_unset_debug,
 	     /* TRANSLATORS: command line option */
-	     _("Unset the debugging flag during update"),
+	     N_("Unset the debugging flag during update"),
 	     NULL},
 	    {"apply",
 	     'a',
@@ -162,16 +161,16 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_STRING,
 	     &apply,
 	     /* TRANSLATORS: command line option */
-	     _("Apply firmware updates"),
+	     N_("Apply firmware updates"),
 	     /* TRANSLATORS: command argument: uppercase, spaces->dashes */
-	     C_("A single GUID", "GUID")},
+	     NC_("A single GUID", "GUID")},
 	    {"method",
 	     'm',
 	     G_OPTION_FLAG_NONE,
 	     G_OPTION_ARG_STRING,
 	     &type,
 	     /* TRANSLATORS: command line option */
-	     _("Device update method"),
+	     N_("Device update method"),
 	     "nvram|cod|grub"},
 	    {"flags",
 	     'f',
@@ -179,7 +178,7 @@ main(int argc, char *argv[])
 	     G_OPTION_ARG_STRING,
 	     &flags,
 	     /* TRANSLATORS: command line option */
-	     _("Use quirk flags when installing firmware"),
+	     N_("Use quirk flags when installing firmware"),
 	     NULL},
 	    {NULL}};
 
@@ -215,7 +214,7 @@ main(int argc, char *argv[])
 
 	/* set verbose? */
 	if (verbose) {
-		g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
+		(void)g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
 	} else {
 		g_log_set_handler(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, fu_util_ignore_cb, NULL);
 	}
@@ -235,14 +234,14 @@ main(int argc, char *argv[])
 
 	/* override the default ESP path */
 	if (esp_path != NULL) {
-		esp = fu_common_get_esp_for_path(esp_path, &error);
+		esp = fu_volume_new_esp_for_path(esp_path, &error);
 		if (esp == NULL) {
 			/* TRANSLATORS: ESP is EFI System Partition */
 			g_print("%s: %s\n", _("ESP specified was not valid"), error->message);
 			return EXIT_FAILURE;
 		}
 	} else {
-		esp = fu_common_get_esp_default(&error);
+		esp = fu_volume_new_esp_default(&error);
 		if (esp == NULL) {
 			g_printerr("failed: %s\n", error->message);
 			return EXIT_FAILURE;
@@ -267,13 +266,18 @@ main(int argc, char *argv[])
 		}
 		buf_ucs2 = g_new0(guint16, (sz / 2) + 1);
 		memcpy(buf_ucs2, buf, sz);
-		str = fu_ucs2_to_uft8(buf_ucs2, sz / 2);
+		str = g_utf16_to_utf8(buf_ucs2, sz / 2, NULL, NULL, &error_local);
+		if (str == NULL) {
+			g_printerr("failed: %s\n", error_local->message);
+			return EXIT_FAILURE;
+		}
 		g_print("%s", str);
 	}
 
 	if (action_list || action_supported || action_info) {
 		g_autoptr(FuContext) ctx = fu_context_new();
 		g_autoptr(FuBackend) backend = fu_uefi_backend_new(ctx);
+		g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 		g_autoptr(GError) error_local = NULL;
 
 		/* load SMBIOS */
@@ -283,7 +287,7 @@ main(int argc, char *argv[])
 		}
 
 		/* add each device */
-		if (!fu_backend_coldplug(backend, &error_local)) {
+		if (!fu_backend_coldplug(backend, progress, &error_local)) {
 			g_printerr("failed: %s\n", error_local->message);
 			return EXIT_FAILURE;
 		}
@@ -398,6 +402,13 @@ main(int argc, char *argv[])
 		g_autoptr(GError) error_local = NULL;
 		g_autoptr(GBytes) fw = NULL;
 
+		/* progress */
+		fu_progress_set_id(progress, G_STRLOC);
+		fu_progress_add_flag(progress, FU_PROGRESS_FLAG_NO_PROFILE);
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, "prepare");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98, NULL);
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, "cleanup");
+
 		/* load SMBIOS */
 		if (!fu_context_load_hwinfo(ctx, &error_local)) {
 			g_printerr("failed: %s\n", error_local->message);
@@ -425,7 +436,7 @@ main(int argc, char *argv[])
 			g_printerr("capsule filename required\n");
 			return EXIT_FAILURE;
 		}
-		fw = fu_common_get_contents_bytes(argv[1], &error_local);
+		fw = fu_bytes_get_contents(argv[1], &error_local);
 		if (fw == NULL) {
 			g_printerr("failed: %s\n", error_local->message);
 			return EXIT_FAILURE;
@@ -434,22 +445,31 @@ main(int argc, char *argv[])
 		fu_uefi_device_set_esp(dev, esp);
 		if (flags != NULL)
 			fu_device_set_custom_flags(FU_DEVICE(dev), flags);
-		if (!fu_device_prepare(FU_DEVICE(dev), FWUPD_INSTALL_FLAG_NONE, &error_local)) {
+		if (!fu_device_prepare(FU_DEVICE(dev),
+				       fu_progress_get_child(progress),
+				       FWUPD_INSTALL_FLAG_NONE,
+				       &error_local)) {
 			g_printerr("failed: %s\n", error_local->message);
 			return EXIT_FAILURE;
 		}
+		fu_progress_step_done(progress);
 		if (!fu_device_write_firmware(FU_DEVICE(dev),
 					      fw,
-					      progress,
+					      fu_progress_get_child(progress),
 					      FWUPD_INSTALL_FLAG_NONE,
 					      &error_local)) {
 			g_printerr("failed: %s\n", error_local->message);
 			return EXIT_FAILURE;
 		}
-		if (!fu_device_cleanup(FU_DEVICE(dev), FWUPD_INSTALL_FLAG_NONE, &error_local)) {
+		fu_progress_step_done(progress);
+		if (!fu_device_cleanup(FU_DEVICE(dev),
+				       fu_progress_get_child(progress),
+				       FWUPD_INSTALL_FLAG_NONE,
+				       &error_local)) {
 			g_printerr("failed: %s\n", error_local->message);
 			return EXIT_FAILURE;
 		}
+		fu_progress_step_done(progress);
 	}
 
 	/* success */
