@@ -97,7 +97,6 @@ fu_uefi_dbx_prepare_firmware(FuDevice *device, GBytes *fw, FwupdInstallFlags fla
 static gboolean
 fu_uefi_dbx_device_probe(FuDevice *device, GError **error)
 {
-	g_autofree gchar *arch_up = NULL;
 	g_autoptr(FuFirmware) kek = fu_efi_signature_list_new();
 	g_autoptr(GBytes) kek_blob = NULL;
 	g_autoptr(GPtrArray) sigs = NULL;
@@ -106,25 +105,21 @@ fu_uefi_dbx_device_probe(FuDevice *device, GError **error)
 	kek_blob = fu_efivar_get_data_bytes(FU_EFIVAR_GUID_EFI_GLOBAL, "KEK", NULL, error);
 	if (kek_blob == NULL)
 		return FALSE;
-	if (!fu_firmware_parse(kek, kek_blob, FWUPD_INSTALL_FLAG_NO_SEARCH, error))
+	if (!fu_firmware_parse(kek, kek_blob, FWUPD_INSTALL_FLAG_NONE, error))
 		return FALSE;
-	arch_up = g_utf8_strup(EFI_MACHINE_TYPE_NAME, -1);
+	fu_device_add_instance_strup(device, "ARCH", EFI_MACHINE_TYPE_NAME);
+
 	sigs = fu_firmware_get_images(kek);
 	for (guint j = 0; j < sigs->len; j++) {
 		FuEfiSignature *sig = g_ptr_array_index(sigs, j);
 		g_autofree gchar *checksum = NULL;
-		g_autofree gchar *checksum_up = NULL;
-		g_autofree gchar *devid1 = NULL;
-		g_autofree gchar *devid2 = NULL;
 
 		checksum = fu_firmware_get_checksum(FU_FIRMWARE(sig), G_CHECKSUM_SHA256, error);
 		if (checksum == NULL)
 			return FALSE;
-		checksum_up = g_utf8_strup(checksum, -1);
-		devid1 = g_strdup_printf("UEFI\\CRT_%s", checksum_up);
-		fu_device_add_instance_id(device, devid1);
-		devid2 = g_strdup_printf("UEFI\\CRT_%s&ARCH_%s", checksum_up, arch_up);
-		fu_device_add_instance_id(device, devid2);
+		fu_device_add_instance_strup(device, "CRT", checksum);
+		fu_device_build_instance_id(device, NULL, "UEFI", "CRT", NULL);
+		fu_device_build_instance_id(device, NULL, "UEFI", "CRT", "ARCH", NULL);
 	}
 	return fu_uefi_dbx_device_set_version_number(device, error);
 }
@@ -134,10 +129,10 @@ fu_uefi_dbx_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 98, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
