@@ -194,7 +194,6 @@ fu_usi_dock_mcu_device_enumerate_children(FuUsiDockMcuDevice *self, GError **err
 	for (guint i = 0; components[i].name != NULL; i++) {
 		const guint8 *val = outbuf + components[i].offset;
 		g_autofree gchar *version = NULL;
-		g_autofree gchar *instance_id = NULL;
 		g_autoptr(FuDevice) child = NULL;
 
 		child = fu_usi_dock_child_new(fu_device_get_context(FU_DEVICE(self)));
@@ -361,11 +360,15 @@ fu_usi_dock_mcu_device_enumerate_children(FuUsiDockMcuDevice *self, GError **err
 		}
 
 		/* add virtual device */
-		instance_id = g_strdup_printf("USB\\VID_%04X&PID_%04X&CID_%s",
-					      fu_usb_device_get_vid(FU_USB_DEVICE(self)),
-					      fu_usb_device_get_pid(FU_USB_DEVICE(self)),
-					      components[i].name);
-		fu_device_add_instance_id(child, instance_id);
+		fu_device_add_instance_u16(child,
+					   "VID",
+					   fu_usb_device_get_vid(FU_USB_DEVICE(self)));
+		fu_device_add_instance_u16(child,
+					   "PID",
+					   fu_usb_device_get_pid(FU_USB_DEVICE(self)));
+		fu_device_add_instance_str(child, "CID", components[i].name);
+		if (!fu_device_build_instance_id(child, error, "USB", "VID", "PID", "CID", NULL))
+			return FALSE;
 		if (fu_device_get_name(child) == NULL)
 			fu_device_set_name(child, components[i].name);
 		fu_device_set_logical_id(child, components[i].name);
@@ -553,11 +556,11 @@ fu_usi_dock_mcu_device_write_firmware_with_idx(FuUsiDockMcuDevice *self,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 6);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 40);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 13);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 42);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 6, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 40, "write-external");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 13, "wait-for-checksum");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 42, "internal-flash");
 
 	/* initial external flash */
 	cmd = USBUID_ISP_DEVICE_CMD_FWBUFER_INITIAL;
@@ -686,7 +689,7 @@ fu_usi_dock_mcu_device_write_firmware(FuDevice *device,
 static gboolean
 fu_usi_dock_mcu_device_attach(FuDevice *device, FuProgress *progress, GError **error)
 {
-	fu_device_set_remove_delay(device, 500000);
+	fu_device_set_remove_delay(device, 900000);
 	fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
 
 	/* success */
@@ -698,10 +701,10 @@ fu_usi_dock_mcu_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 2);	/* erase */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 90);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 6); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 90, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 6, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
