@@ -217,6 +217,8 @@ fu_vli_device_spi_read(FuVliDevice *self,
 
 	/* get data from hardware */
 	chunks = fu_chunk_array_mutable_new(buf, bufsz, address, 0x0, FU_VLI_DEVICE_TXSIZE);
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_set_steps(progress, chunks->len);
 	for (guint i = 0; i < chunks->len; i++) {
 		FuChunk *chk = g_ptr_array_index(chunks, i);
 		if (!fu_vli_device_spi_read_block(self,
@@ -229,7 +231,7 @@ fu_vli_device_spi_read(FuVliDevice *self,
 				       fu_chunk_get_address(chk));
 			return NULL;
 		}
-		fu_progress_set_percentage_full(progress, (gsize)i + 1, (gsize)chunks->len);
+		fu_progress_step_done(progress);
 	}
 	return g_bytes_new_take(g_steal_pointer(&buf), bufsz);
 }
@@ -272,7 +274,7 @@ fu_vli_device_spi_write_block(FuVliDevice *self,
 		g_prefix_error(error, "SPI data read failed: ");
 		return FALSE;
 	}
-	return fu_common_bytes_compare_raw(buf, bufsz, buf_tmp, bufsz, error);
+	return fu_memcmp_safe(buf, bufsz, buf_tmp, bufsz, error);
 }
 
 gboolean
@@ -288,8 +290,8 @@ fu_vli_device_spi_write(FuVliDevice *self,
 
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 99);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 1); /* chk0 */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 99, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 1, "device-write-chk0");
 
 	/* write SPI data, then CRC bytes last */
 	g_debug("writing 0x%x bytes @0x%x", (guint)bufsz, address);
@@ -336,8 +338,8 @@ fu_vli_device_spi_erase_all(FuVliDevice *self, FuProgress *progress, GError **er
 {
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 99);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 1);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 99, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 1, NULL);
 
 	if (!fu_vli_device_spi_write_enable(self, error))
 		return FALSE;
@@ -384,6 +386,8 @@ fu_vli_device_spi_erase(FuVliDevice *self,
 {
 	g_autoptr(GPtrArray) chunks = fu_chunk_array_new(NULL, sz, addr, 0x0, 0x1000);
 	g_debug("erasing 0x%x bytes @0x%x", (guint)sz, addr);
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_set_steps(progress, chunks->len);
 	for (guint i = 0; i < chunks->len; i++) {
 		FuChunk *chk = g_ptr_array_index(chunks, i);
 		if (g_getenv("FWUPD_VLI_USBHUB_VERBOSE") != NULL)
@@ -396,7 +400,7 @@ fu_vli_device_spi_erase(FuVliDevice *self,
 				       fu_chunk_get_address(chk));
 			return FALSE;
 		}
-		fu_progress_set_percentage_full(progress, (gsize)i + 1, (gsize)chunks->len);
+		fu_progress_step_done(progress);
 	}
 	return TRUE;
 }
@@ -426,21 +430,64 @@ fu_vli_device_set_kind(FuVliDevice *self, FuVliDeviceKind device_kind)
 		g_object_notify(G_OBJECT(self), "kind");
 	}
 
+	/* newer chips use SHA-256 and ECDSA-256 */
+	switch (device_kind) {
+	case FU_VLI_DEVICE_KIND_MSP430:
+	case FU_VLI_DEVICE_KIND_PS186:
+	case FU_VLI_DEVICE_KIND_RTD21XX:
+	case FU_VLI_DEVICE_KIND_VL100:
+	case FU_VLI_DEVICE_KIND_VL101:
+	case FU_VLI_DEVICE_KIND_VL102:
+	case FU_VLI_DEVICE_KIND_VL103:
+	case FU_VLI_DEVICE_KIND_VL104:
+	case FU_VLI_DEVICE_KIND_VL105:
+	case FU_VLI_DEVICE_KIND_VL120:
+	case FU_VLI_DEVICE_KIND_VL210:
+	case FU_VLI_DEVICE_KIND_VL211:
+	case FU_VLI_DEVICE_KIND_VL212:
+	case FU_VLI_DEVICE_KIND_VL810:
+	case FU_VLI_DEVICE_KIND_VL811:
+	case FU_VLI_DEVICE_KIND_VL811PB0:
+	case FU_VLI_DEVICE_KIND_VL811PB3:
+	case FU_VLI_DEVICE_KIND_VL812B0:
+	case FU_VLI_DEVICE_KIND_VL812B3:
+	case FU_VLI_DEVICE_KIND_VL812Q4S:
+	case FU_VLI_DEVICE_KIND_VL813:
+	case FU_VLI_DEVICE_KIND_VL815:
+	case FU_VLI_DEVICE_KIND_VL817:
+	case FU_VLI_DEVICE_KIND_VL819Q7:
+	case FU_VLI_DEVICE_KIND_VL819Q8:
+	case FU_VLI_DEVICE_KIND_VL820Q7:
+	case FU_VLI_DEVICE_KIND_VL820Q8:
+	case FU_VLI_DEVICE_KIND_VL821Q7:
+	case FU_VLI_DEVICE_KIND_VL821Q8:
+	case FU_VLI_DEVICE_KIND_VL822Q5:
+	case FU_VLI_DEVICE_KIND_VL822Q7:
+	case FU_VLI_DEVICE_KIND_VL822Q8:
+		fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+		break;
+	case FU_VLI_DEVICE_KIND_VL107:
+	case FU_VLI_DEVICE_KIND_VL650:
+	case FU_VLI_DEVICE_KIND_VL830:
+		fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
+		break;
+	default:
+		g_warning("device kind %s [0x%02x] does not indicate unsigned/signed payload",
+			  fu_vli_common_device_kind_to_string(device_kind),
+			  device_kind);
+		break;
+	}
+
 	/* set maximum firmware size */
 	sz = fu_vli_common_device_kind_get_size(device_kind);
 	if (sz > 0x0)
 		fu_device_set_firmware_size_max(FU_DEVICE(self), sz);
 
 	/* add extra DEV GUID too */
-	if (priv->kind != FU_VLI_DEVICE_KIND_UNKNOWN) {
-		GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
-		g_autofree gchar *devid1 = NULL;
-		devid1 = g_strdup_printf("USB\\VID_%04X&PID_%04X&DEV_%s",
-					 g_usb_device_get_vid(usb_device),
-					 g_usb_device_get_pid(usb_device),
-					 fu_vli_common_device_kind_to_string(priv->kind));
-		fu_device_add_instance_id(FU_DEVICE(self), devid1);
-	}
+	fu_device_add_instance_str(FU_DEVICE(self),
+				   "DEV",
+				   fu_vli_common_device_kind_to_string(priv->kind));
+	fu_device_build_instance_id(FU_DEVICE(self), NULL, "USB", "VID", "PID", "DEV", NULL);
 }
 
 void
@@ -474,15 +521,15 @@ fu_vli_device_to_string(FuDevice *device, guint idt, GString *str)
 	FU_DEVICE_CLASS(fu_vli_device_parent_class)->to_string(device, idt, str);
 
 	if (priv->kind != FU_VLI_DEVICE_KIND_UNKNOWN) {
-		fu_common_string_append_kv(str,
-					   idt,
-					   "DeviceKind",
-					   fu_vli_common_device_kind_to_string(priv->kind));
+		fu_string_append(str,
+				 idt,
+				 "DeviceKind",
+				 fu_vli_common_device_kind_to_string(priv->kind));
 	}
-	fu_common_string_append_kb(str, idt, "SpiAutoDetect", priv->spi_auto_detect);
+	fu_string_append_kb(str, idt, "SpiAutoDetect", priv->spi_auto_detect);
 	if (priv->flash_id != 0x0) {
 		g_autofree gchar *tmp = fu_vli_device_get_flash_id_str(self);
-		fu_common_string_append_kv(str, idt, "FlashId", tmp);
+		fu_string_append(str, idt, "FlashId", tmp);
 	}
 	fu_device_add_string(FU_DEVICE(priv->cfi_device), idt + 1, str);
 }
@@ -514,23 +561,23 @@ fu_vli_device_spi_read_flash_id(FuVliDevice *self, GError **error)
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_VLI_USBHUB_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "SpiCmdReadId", buf, sizeof(buf));
+		fu_dump_raw(G_LOG_DOMAIN, "SpiCmdReadId", buf, sizeof(buf));
 	if (priv->spi_cmd_read_id_sz == 4) {
-		if (!fu_common_read_uint32_safe(buf,
-						sizeof(buf),
-						0x0,
-						&priv->flash_id,
-						G_BIG_ENDIAN,
-						error))
+		if (!fu_memread_uint32_safe(buf,
+					    sizeof(buf),
+					    0x0,
+					    &priv->flash_id,
+					    G_BIG_ENDIAN,
+					    error))
 			return FALSE;
 	} else if (priv->spi_cmd_read_id_sz == 2) {
 		guint16 tmp = 0;
-		if (!fu_common_read_uint16_safe(buf, sizeof(buf), 0x0, &tmp, G_BIG_ENDIAN, error))
+		if (!fu_memread_uint16_safe(buf, sizeof(buf), 0x0, &tmp, G_BIG_ENDIAN, error))
 			return FALSE;
 		priv->flash_id = tmp;
 	} else if (priv->spi_cmd_read_id_sz == 1) {
 		guint8 tmp = 0;
-		if (!fu_common_read_uint8_safe(buf, sizeof(buf), 0x0, &tmp, error))
+		if (!fu_memread_uint8_safe(buf, sizeof(buf), 0x0, &tmp, error))
 			return FALSE;
 		priv->flash_id = tmp;
 	}
@@ -549,33 +596,36 @@ fu_vli_device_setup(FuDevice *device, GError **error)
 
 	/* get the flash chip attached */
 	if (priv->spi_auto_detect) {
-		GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
 		if (!fu_vli_device_spi_read_flash_id(self, error)) {
 			g_prefix_error(error, "failed to read SPI chip ID: ");
 			return FALSE;
 		}
 		if (priv->flash_id != 0x0) {
-			g_autofree gchar *devid1 = NULL;
-			g_autofree gchar *devid2 = NULL;
 			g_autofree gchar *flash_id = fu_vli_device_get_flash_id_str(self);
 
 			/* use the correct flash device */
 			fu_cfi_device_set_flash_id(priv->cfi_device, flash_id);
-			if (!fu_device_probe(FU_DEVICE(priv->cfi_device), error))
+			if (!fu_device_setup(FU_DEVICE(priv->cfi_device), error))
 				return FALSE;
 
 			/* add extra instance IDs to include the SPI variant */
-			devid2 = g_strdup_printf("USB\\VID_%04X&PID_%04X&SPI_%s&REV_%04X",
-						 g_usb_device_get_vid(usb_device),
-						 g_usb_device_get_pid(usb_device),
-						 flash_id,
-						 g_usb_device_get_release(usb_device));
-			fu_device_add_instance_id(device, devid2);
-			devid1 = g_strdup_printf("USB\\VID_%04X&PID_%04X&SPI_%s",
-						 g_usb_device_get_vid(usb_device),
-						 g_usb_device_get_pid(usb_device),
-						 flash_id);
-			fu_device_add_instance_id(device, devid1);
+			fu_device_add_instance_str(device, "SPI", flash_id);
+			if (!fu_device_build_instance_id(device,
+							 error,
+							 "USB",
+							 "VID",
+							 "PID",
+							 "SPI",
+							 NULL))
+				return FALSE;
+			fu_device_build_instance_id(device,
+						    NULL,
+						    "USB",
+						    "VID",
+						    "PID",
+						    "SPI",
+						    "REV",
+						    NULL);
 		}
 	}
 
@@ -591,13 +641,13 @@ fu_vli_device_set_quirk_kv(FuDevice *device, const gchar *key, const gchar *valu
 	guint64 tmp = 0;
 
 	if (g_strcmp0(key, "CfiDeviceCmdReadIdSz") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		priv->spi_cmd_read_id_sz = tmp;
 		return TRUE;
 	}
 	if (g_strcmp0(key, "VliSpiAutoDetect") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		priv->spi_auto_detect = tmp > 0;
 		return TRUE;
@@ -674,6 +724,7 @@ fu_vli_device_init(FuVliDevice *self)
 	priv->spi_cmd_read_id_sz = 2;
 	priv->spi_auto_detect = TRUE;
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_NO_SERIAL_NUMBER);
 }
 
 static void
