@@ -59,7 +59,7 @@ fu_vli_usbhub_device_i2c_read(FuVliUsbhubDevice *self,
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_VLI_USBHUB_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "I2cReadData", buf, bufsz);
+		fu_dump_raw(G_LOG_DOMAIN, "I2cReadData", buf, bufsz);
 	return TRUE;
 }
 
@@ -87,7 +87,7 @@ fu_vli_usbhub_device_i2c_write_data(FuVliUsbhubDevice *self,
 	GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
 	guint16 value = (((guint16)disable_start_bit) << 8) | disable_end_bit;
 	if (g_getenv("FWUPD_VLI_USBHUB_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "I2cWriteData", buf, bufsz);
+		fu_dump_raw(G_LOG_DOMAIN, "I2cWriteData", buf, bufsz);
 	if (!g_usb_device_control_transfer(usb_device,
 					   G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
 					   G_USB_DEVICE_REQUEST_TYPE_VENDOR,
@@ -226,7 +226,9 @@ fu_vli_usbhub_msp430_device_write_firmware(FuDevice *device,
 		return FALSE;
 
 	/* transfer by I²C write, and check status by I²C read */
+	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_set_status(progress, FWUPD_STATUS_DEVICE_WRITE);
+	fu_progress_set_steps(progress, records->len);
 	for (guint j = 0; j < records->len; j++) {
 		FuIhexFirmwareRecord *rcd = g_ptr_array_index(records, j);
 		FuVliUsbhubDeviceRequest req = {0x0};
@@ -277,7 +279,7 @@ fu_vli_usbhub_msp430_device_write_firmware(FuDevice *device,
 				     &req,
 				     error))
 			return FALSE;
-		fu_progress_set_percentage_full(progress, (gsize)j + 1, (gsize)records->len);
+		fu_progress_step_done(progress);
 	}
 
 	/* the device automatically reboots */
@@ -292,37 +294,32 @@ fu_vli_usbhub_msp430_device_probe(FuDevice *device, GError **error)
 {
 	FuVliDeviceKind device_kind = FU_VLI_DEVICE_KIND_MSP430;
 	FuVliUsbhubDevice *parent = FU_VLI_USBHUB_DEVICE(fu_device_get_parent(device));
-	g_autofree gchar *instance_id = NULL;
 
 	fu_device_set_name(device, fu_vli_common_device_kind_to_string(device_kind));
 	fu_device_set_physical_id(device, fu_device_get_physical_id(FU_DEVICE(parent)));
 
 	/* add instance ID */
-	instance_id = g_strdup_printf("USB\\VID_%04X&PID_%04X&I2C_%s",
-				      fu_usb_device_get_vid(FU_USB_DEVICE(parent)),
-				      fu_usb_device_get_pid(FU_USB_DEVICE(parent)),
-				      fu_vli_common_device_kind_to_string(device_kind));
-	fu_device_add_instance_id(device, instance_id);
-
-	return TRUE;
+	fu_device_add_instance_str(device, "I2C", fu_vli_common_device_kind_to_string(device_kind));
+	return fu_device_build_instance_id(device, error, "USB", "VID", "PID", NULL);
 }
 
 static void
 fu_vli_usbhub_msp430_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 13);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 85); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0);	 /* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 13, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 85, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0, "reload");
 }
 
 static void
 fu_vli_usbhub_msp430_device_init(FuVliUsbhubMsp430Device *self)
 {
-	fu_device_add_icon(FU_DEVICE(self), "audio-card");
+	fu_device_add_icon(FU_DEVICE(self), "usb-hub");
 	fu_device_add_protocol(FU_DEVICE(self), "com.vli.i2c");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PAIR);
 	fu_device_set_logical_id(FU_DEVICE(self), "I2C");
 	fu_device_set_summary(FU_DEVICE(self), "I²C dock management device");
