@@ -15,10 +15,14 @@
 static void
 fu_plugin_wacom_raw_init(FuPlugin *plugin)
 {
-	FuContext *ctx = fu_plugin_get_context(plugin);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_WACOM_AES_DEVICE);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_WACOM_EMR_DEVICE);
 	fu_plugin_add_udev_subsystem(plugin, "hidraw");
+}
+
+static void
+fu_plugin_wacom_raw_load(FuContext *ctx)
+{
 	fu_context_add_quirk_key(ctx, "WacomI2cFlashBlockSize");
 	fu_context_add_quirk_key(ctx, "WacomI2cFlashBaseAddr");
 	fu_context_add_quirk_key(ctx, "WacomI2cFlashSize");
@@ -28,5 +32,6 @@ void
 fu_plugin_init_vfuncs(FuPluginVfuncs *vfuncs)
 {
 	vfuncs->build_hash = FU_BUILD_HASH;
+	vfuncs->load = fu_plugin_wacom_raw_load;
 	vfuncs->init = fu_plugin_wacom_raw_init;
 }
