@@ -8,8 +8,6 @@
 
 #include <fwupdplugin.h>
 
-#include <gio/gio.h>
-
 #include "fu-wacom-aes-device.h"
 #include "fu-wacom-common.h"
 
@@ -41,8 +39,6 @@ fu_wacom_aes_add_recovery_hwid(FuDevice *device, GError **error)
 	FuWacomRawVerifyResponse rsp = {.report_id = FU_WACOM_RAW_BL_REPORT_ID_GET,
 					.size8 = 0x00,
 					.data = {0x00}};
-	g_autofree gchar *devid1 = NULL;
-	g_autofree gchar *devid2 = NULL;
 	guint16 pid;
 
 	if (!fu_wacom_device_set_feature(FU_WACOM_DEVICE(device),
@@ -77,12 +73,13 @@ fu_wacom_aes_add_recovery_hwid(FuDevice *device, GError **error)
 		return FALSE;
 	}
 
-	devid1 = g_strdup_printf("HIDRAW\\VEN_2D1F&DEV_%04X", pid);
-	devid2 = g_strdup_printf("HIDRAW\\VEN_056A&DEV_%04X", pid);
-	fu_device_add_instance_id(device, devid1);
-	fu_device_add_instance_id(device, devid2);
-
-	return TRUE;
+	/* add recovery IDs */
+	fu_device_add_instance_u16(device, "VEN", 0x2D1F);
+	fu_device_add_instance_u16(device, "DEV", pid);
+	if (!fu_device_build_instance_id(device, error, "HIDRAW", "VID", "PID", NULL))
+		return FALSE;
+	fu_device_add_instance_u16(device, "VEN", 0x056A);
+	return fu_device_build_instance_id(device, error, "HIDRAW", "VID", "PID", NULL);
 }
 
 static gboolean
@@ -137,12 +134,12 @@ fu_wacom_aes_device_setup(FuDevice *device, GError **error)
 
 		if (!fu_wacom_device_get_feature(FU_WACOM_DEVICE(self), data, sizeof(data), error))
 			return FALSE;
-		if (!fu_common_read_uint16_safe(data,
-						sizeof(data),
-						11,
-						&fw_ver,
-						G_LITTLE_ENDIAN,
-						error))
+		if (!fu_memread_uint16_safe(data,
+					    sizeof(data),
+					    11,
+					    &fw_ver,
+					    G_LITTLE_ENDIAN,
+					    error))
 			return FALSE;
 		version = g_strdup_printf("%04x.%02x", fw_ver, data[13]);
 		fu_device_set_version(device, version);
@@ -234,8 +231,8 @@ fu_wacom_aes_device_write_firmware(FuDevice *device,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 20);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 80);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 20, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 80, NULL);
 
 	/* erase */
 	if (!fu_wacom_aes_device_erase_all(self, progress, error))
