@@ -8,11 +8,8 @@
 
 #include "config.h"
 
-#include <glib-object.h>
 #include <string.h>
 
-#include "fwupd-error.h"
-
 #include "fu-device-list.h"
 #include "fu-device-private.h"
 #include "fu-mutex.h"
@@ -216,6 +213,10 @@ fu_device_list_get_active(FuDeviceList *self)
 	g_rw_lock_reader_lock(&self->devices_mutex);
 	for (guint i = 0; i < self->devices->len; i++) {
 		FuDeviceItem *item = g_ptr_array_index(self->devices, i);
+		if (fu_device_has_inhibit(item->device, "unconnected"))
+			continue;
+		if (fu_device_has_inhibit(item->device, "hidden"))
+			continue;
 		g_ptr_array_add(devices, g_object_ref(item->device));
 	}
 	g_rw_lock_reader_unlock(&self->devices_mutex);
@@ -444,6 +445,17 @@ fu_device_list_remove_with_delay(FuDeviceItem *item)
 					item);
 }
 
+static gboolean
+fu_device_list_should_remove_with_delay(FuDevice *device)
+{
+	if (fu_device_get_remove_delay(device) == 0)
+		return FALSE;
+	if (fu_device_has_internal_flag(device, FU_DEVICE_INTERNAL_FLAG_ONLY_WAIT_FOR_REPLUG) &&
+	    !fu_device_has_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG))
+		return FALSE;
+	return TRUE;
+}
+
 /**
  * fu_device_list_remove:
  * @self: a device list
@@ -485,7 +497,7 @@ fu_device_list_remove(FuDeviceList *self, FuDevice *device)
 	}
 
 	/* delay the removal and check for replug */
-	if (fu_device_get_remove_delay(item->device) > 0) {
+	if (fu_device_list_should_remove_with_delay(item->device)) {
 		fu_device_list_remove_with_delay(item);
 		return;
 	}
@@ -919,7 +931,7 @@ fu_device_list_wait_for_replug(FuDeviceList *self, GError **error)
 			fu_device_remove_flag(device_tmp, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
 			g_ptr_array_add(device_ids, g_strdup(fu_device_get_id(device_tmp)));
 		}
-		device_ids_str = fu_common_strjoin_array(",", device_ids);
+		device_ids_str = fu_strjoin(",", device_ids);
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_NOT_FOUND,
