@@ -6,19 +6,15 @@
 
 #pragma once
 
-#include <glib-object.h>
+#include <fwupdplugin.h>
+
 #include <jcat.h>
-#include <xmlb.h>
 
 #include "fwupd-device.h"
 #include "fwupd-enums.h"
 
-#include "fu-common.h"
-#include "fu-context.h"
-#include "fu-engine-request.h"
-#include "fu-install-task.h"
-#include "fu-plugin.h"
-#include "fu-security-attrs.h"
+#include "fu-config.h"
+#include "fu-release.h"
 
 #define FU_TYPE_ENGINE (fu_engine_get_type())
 G_DECLARE_FINAL_TYPE(FuEngine, fu_engine, FU, ENGINE, GObject)
@@ -41,38 +37,37 @@ typedef enum {
 	FU_ENGINE_LOAD_FLAG_REMOTES = 1 << 2,
 	FU_ENGINE_LOAD_FLAG_HWINFO = 1 << 3,
 	FU_ENGINE_LOAD_FLAG_NO_CACHE = 1 << 4,
+	FU_ENGINE_LOAD_FLAG_NO_IDLE_SOURCES = 1 << 5,
 	/*< private >*/
 	FU_ENGINE_LOAD_FLAG_LAST
 } FuEngineLoadFlags;
 
 FuEngine *
-fu_engine_new(FuAppFlags app_flags);
-void
-fu_engine_add_app_flag(FuEngine *self, FuAppFlags app_flags);
+fu_engine_new(void);
 void
 fu_engine_add_plugin_filter(FuEngine *self, const gchar *plugin_glob);
 void
 fu_engine_idle_reset(FuEngine *self);
 gboolean
-fu_engine_load(FuEngine *self, FuEngineLoadFlags flags, GError **error);
-gboolean
-fu_engine_load_plugins(FuEngine *self, GError **error);
+fu_engine_load(FuEngine *self, FuEngineLoadFlags flags, FuProgress *progress, GError **error);
 gboolean
 fu_engine_get_tainted(FuEngine *self);
 const gchar *
+fu_engine_get_host_vendor(FuEngine *self);
+const gchar *
 fu_engine_get_host_product(FuEngine *self);
 const gchar *
 fu_engine_get_host_machine_id(FuEngine *self);
 const gchar *
 fu_engine_get_host_bkc(FuEngine *self);
+gboolean
+fu_engine_is_uid_trusted(FuEngine *self, guint64 calling_uid);
 const gchar *
 fu_engine_get_host_security_id(FuEngine *self);
-FwupdStatus
-fu_engine_get_status(FuEngine *self);
 XbSilo *
 fu_engine_get_silo_from_blob(FuEngine *self, GBytes *blob_cab, GError **error);
-guint64
-fu_engine_get_archive_size_max(FuEngine *self);
+FuConfig *
+fu_engine_get_config(FuEngine *self);
 GPtrArray *
 fu_engine_get_plugins(FuEngine *self);
 GPtrArray *
@@ -141,6 +136,12 @@ fu_engine_firmware_dump(FuEngine *self,
 			FuProgress *progress,
 			FwupdInstallFlags flags,
 			GError **error);
+FuFirmware *
+fu_engine_firmware_read(FuEngine *self,
+			FuDevice *device,
+			FuProgress *progress,
+			FwupdInstallFlags flags,
+			GError **error);
 gboolean
 fu_engine_modify_remote(FuEngine *self,
 			const gchar *remote_id,
@@ -158,13 +159,12 @@ fu_engine_composite_prepare(FuEngine *self, GPtrArray *devices, GError **error);
 gboolean
 fu_engine_composite_cleanup(FuEngine *self, GPtrArray *devices, GError **error);
 gboolean
-fu_engine_install(FuEngine *self,
-		  FuInstallTask *task,
-		  GBytes *blob_cab,
-		  FuProgress *progress,
-		  FwupdInstallFlags flags,
-		  FwupdFeatureFlags feature_flags,
-		  GError **error);
+fu_engine_install_release(FuEngine *self,
+			  FuRelease *task,
+			  GBytes *blob_cab,
+			  FuProgress *progress,
+			  FwupdInstallFlags flags,
+			  GError **error);
 gboolean
 fu_engine_install_blob(FuEngine *self,
 		       FuDevice *device,
@@ -174,13 +174,13 @@ fu_engine_install_blob(FuEngine *self,
 		       FwupdFeatureFlags feature_flags,
 		       GError **error);
 gboolean
-fu_engine_install_tasks(FuEngine *self,
-			FuEngineRequest *request,
-			GPtrArray *install_tasks,
-			GBytes *blob_cab,
-			FuProgress *progress,
-			FwupdInstallFlags flags,
-			GError **error);
+fu_engine_install_releases(FuEngine *self,
+			   FuEngineRequest *request,
+			   GPtrArray *releases,
+			   GBytes *blob_cab,
+			   FuProgress *progress,
+			   FwupdInstallFlags flags,
+			   GError **error);
 GPtrArray *
 fu_engine_get_details(FuEngine *self, FuEngineRequest *request, gint fd, GError **error);
 gboolean
@@ -218,12 +218,16 @@ void
 fu_engine_add_plugin(FuEngine *self, FuPlugin *plugin);
 void
 fu_engine_add_runtime_version(FuEngine *self, const gchar *component_id, const gchar *version);
+GPtrArray *
+fu_engine_get_details_for_bytes(FuEngine *self,
+				FuEngineRequest *request,
+				GBytes *blob,
+				GError **error);
 gboolean
-fu_engine_check_trust(FuEngine *self, FuInstallTask *task, GError **error);
+fu_engine_check_trust(FuEngine *self, FuRelease *task, GError **error);
 gboolean
 fu_engine_check_requirements(FuEngine *self,
-			     FuEngineRequest *request,
-			     FuInstallTask *task,
+			     FuRelease *release,
 			     FwupdInstallFlags flags,
 			     GError **error);
 void
@@ -237,3 +241,10 @@ fu_engine_schedule_update(FuEngine *self,
 			  GBytes *blob_cab,
 			  FwupdInstallFlags flags,
 			  GError **error);
+GError *
+fu_engine_error_array_get_best(GPtrArray *errors);
+gboolean
+fu_engine_modify_bios_settings(FuEngine *self,
+			       GHashTable *settings,
+			       gboolean force_ro,
+			       GError **error);
