@@ -8,9 +8,6 @@
 
 #include "config.h"
 
-#include <fwupd.h>
-#include <gio/gio.h>
-#include <glib-object.h>
 #include <glib/gstdio.h>
 #include <json-glib/json-glib.h>
 #ifdef HAVE_SQLITE
@@ -20,13 +17,12 @@
 
 #include "fwupd-security-attr-private.h"
 
-#include "fu-common.h"
 #include "fu-device-private.h"
 #include "fu-history.h"
 #include "fu-mutex.h"
-#include "fu-security-attr.h"
+#include "fu-security-attr-common.h"
 
-#define FU_HISTORY_CURRENT_SCHEMA_VERSION 7
+#define FU_HISTORY_CURRENT_SCHEMA_VERSION 8
 
 static void
 fu_history_finalize(GObject *object);
@@ -55,7 +51,7 @@ fu_history_device_from_stmt(sqlite3_stmt *stmt)
 	FwupdRelease *release;
 
 	/* create new result */
-	device = fu_device_new();
+	device = fu_device_new(NULL);
 	release = fu_device_get_release_default(device);
 
 	/* device_id */
@@ -135,6 +131,11 @@ fu_history_device_from_stmt(sqlite3_stmt *stmt)
 	tmp = (const gchar *)sqlite3_column_text(stmt, 15);
 	if (tmp != NULL)
 		fwupd_release_set_protocol(release, tmp);
+
+	/* release_id */
+	tmp = (const gchar *)sqlite3_column_text(stmt, 16);
+	if (tmp != NULL)
+		fwupd_release_set_id(release, tmp);
 	return device;
 }
 
@@ -187,7 +188,8 @@ fu_history_create_database(FuHistory *self, GError **error)
 			  "version_old TEXT,"
 			  "version_new TEXT,"
 			  "checksum_device TEXT DEFAULT NULL,"
-			  "protocol TEXT DEFAULT NULL);"
+			  "protocol TEXT DEFAULT NULL,"
+			  "release_id TEXT DEFAULT NULL);"
 			  "CREATE TABLE IF NOT EXISTS approved_firmware ("
 			  "checksum TEXT);"
 			  "CREATE TABLE IF NOT EXISTS blocked_firmware ("
@@ -234,7 +236,7 @@ fu_history_migrate_database_v1(FuHistory *self, GError **error)
 			  "device_id, update_state, update_error, filename, "
 			  "display_name, plugin, device_created, device_modified, "
 			  "checksum, flags, metadata, guid_default, version_old, "
-			  "version_new, NULL, NULL FROM history_old;"
+			  "version_new, NULL, NULL, NULL FROM history_old;"
 			  "DROP TABLE history_old;",
 			  NULL,
 			  NULL,
@@ -343,6 +345,20 @@ fu_history_migrate_database_v6(FuHistory *self, GError **error)
 	return TRUE;
 }
 
+static gboolean
+fu_history_migrate_database_v7(FuHistory *self, GError **error)
+{
+	gint rc;
+	rc = sqlite3_exec(self->db,
+			  "ALTER TABLE history ADD COLUMN release_id TEXT DEFAULT NULL;",
+			  NULL,
+			  NULL,
+			  NULL);
+	if (rc != SQLITE_OK)
+		g_debug("ignoring database error: %s", sqlite3_errmsg(self->db));
+	return TRUE;
+}
+
 /* returns 0 if database is not initialized */
 static guint
 fu_history_get_schema_version(FuHistory *self)
@@ -403,6 +419,10 @@ fu_history_create_or_migrate(FuHistory *self, guint schema_ver, GError **error)
 	case 6:
 		if (!fu_history_migrate_database_v6(self, error))
 			return FALSE;
+	/* fall through */
+	case 7:
+		if (!fu_history_migrate_database_v7(self, error))
+			return FALSE;
 		break;
 	default:
 		/* this is probably okay, but return an error if we ever delete
@@ -465,7 +485,7 @@ fu_history_load(FuHistory *self, GError **error)
 	g_return_val_if_fail(locker != NULL, FALSE);
 
 	/* create directory */
-	dirname = fu_common_get_path(FU_PATH_KIND_LOCALSTATEDIR_PKG);
+	dirname = fu_path_from_kind(FU_PATH_KIND_LOCALSTATEDIR_PKG);
 	file = g_file_new_for_path(dirname);
 	if (!g_file_query_exists(file, NULL)) {
 		if (!g_file_make_directory_with_parents(file, NULL, error))
@@ -997,7 +1017,8 @@ fu_history_get_devices(FuHistory *self, GError **error)
 				"version_new, "
 				"version_old, "
 				"checksum_device, "
-				"protocol FROM history "
+				"protocol, "
+				"release_id FROM history "
 				"ORDER BY device_modified ASC;",
 				-1,
 				&stmt,
