@@ -8,10 +8,8 @@
 
 #include "config.h"
 
-#include <glib.h>
 #include <glib/gi18n.h>
 
-#include "fu-common.h"
 #include "fu-progressbar.h"
 
 static void
@@ -103,6 +101,22 @@ fu_progressbar_erase_line(FuProgressbar *self)
 	g_print("\033[G");
 }
 
+static gboolean
+_fu_status_is_predictable(FwupdStatus status)
+{
+	if (status == FWUPD_STATUS_DEVICE_ERASE)
+		return TRUE;
+	if (status == FWUPD_STATUS_DEVICE_VERIFY)
+		return TRUE;
+	if (status == FWUPD_STATUS_DEVICE_READ)
+		return TRUE;
+	if (status == FWUPD_STATUS_DEVICE_WRITE)
+		return TRUE;
+	if (status == FWUPD_STATUS_DOWNLOADING)
+		return TRUE;
+	return FALSE;
+}
+
 static gboolean
 fu_progressbar_estimate_ready(FuProgressbar *self, guint percentage)
 {
@@ -116,6 +130,10 @@ fu_progressbar_estimate_ready(FuProgressbar *self, guint percentage)
 		return FALSE;
 	}
 
+	/* allow-list things that make sense... */
+	if (!_fu_status_is_predictable(self->status))
+		return FALSE;
+
 	old = self->last_estimate;
 	elapsed = g_timer_elapsed(self->time_elapsed, NULL);
 	self->last_estimate = elapsed / percentage * (100 - percentage);
@@ -151,22 +169,21 @@ fu_progressbar_refresh(FuProgressbar *self, FwupdStatus status, guint percentage
 	gboolean is_idle_newline = FALSE;
 	g_autoptr(GString) str = g_string_new(NULL);
 
+	g_return_if_fail(percentage <= 100);
+
 	/* erase previous line */
 	fu_progressbar_erase_line(self);
 
 	/* add status */
-	if (status == FWUPD_STATUS_IDLE) {
-		percentage = 100;
+	if (status == FWUPD_STATUS_IDLE || status == FWUPD_STATUS_UNKNOWN) {
 		status = self->status;
 		is_idle_newline = TRUE;
-	} else if (status == FWUPD_STATUS_WAITING_FOR_AUTH) {
-		is_idle_newline = TRUE;
 	}
 	if (percentage == 100)
 		is_idle_newline = TRUE;
 	title = fu_progressbar_status_to_string(status);
 	g_string_append(str, title);
-	for (i = fu_common_strwidth(str->str); i < self->length_status; i++)
+	for (i = fu_strwidth(str->str); i < self->length_status; i++)
 		g_string_append_c(str, ' ');
 
 	/* add progressbar */
@@ -262,7 +279,7 @@ fu_progressbar_spin_cb(gpointer user_data)
 	FuProgressbar *self = FU_PROGRESSBAR(user_data);
 
 	/* ignore */
-	if (self->status == FWUPD_STATUS_IDLE || self->status == FWUPD_STATUS_WAITING_FOR_AUTH)
+	if (self->status == FWUPD_STATUS_IDLE || self->status == FWUPD_STATUS_UNKNOWN)
 		return G_SOURCE_CONTINUE;
 
 	/* move the spinner index up to down */
@@ -315,16 +332,16 @@ fu_progressbar_update(FuProgressbar *self, FwupdStatus status, guint percentage)
 {
 	g_return_if_fail(FU_IS_PROGRESSBAR(self));
 
+	/* not useful */
+	if (status == FWUPD_STATUS_UNKNOWN)
+		return;
+
 	/* ignore initial client connection */
 	if (self->status == FWUPD_STATUS_UNKNOWN && status == FWUPD_STATUS_IDLE) {
 		self->status = status;
 		return;
 	}
 
-	/* use cached value */
-	if (status == FWUPD_STATUS_UNKNOWN)
-		status = self->status;
-
 	if (!self->interactive) {
 		g_print("%s: %u%%\n", fu_progressbar_status_to_string(status), percentage);
 		self->status = status;
@@ -335,7 +352,7 @@ fu_progressbar_update(FuProgressbar *self, FwupdStatus status, guint percentage)
 	/* if the main loop isn't spinning and we've not had a chance to
 	 * execute the callback just do the refresh now manually */
 	if (percentage == 0 && status != FWUPD_STATUS_IDLE &&
-	    status != FWUPD_STATUS_WAITING_FOR_AUTH && self->status != FWUPD_STATUS_UNKNOWN) {
+	    self->status != FWUPD_STATUS_UNKNOWN) {
 		if ((g_get_monotonic_time() - self->last_animated) / 1000 > 40) {
 			fu_progressbar_spin_inc(self);
 			fu_progressbar_refresh(self, status, percentage);
