@@ -53,7 +53,7 @@ fu_usb_backend_device_added_cb(GUsbContext *ctx, GUsbDevice *usb_device, FuBacke
 	g_autoptr(FuUsbDevice) device = NULL;
 
 	/* success */
-	device = fu_usb_device_new_with_context(fu_backend_get_context(backend), usb_device);
+	device = fu_usb_device_new(fu_backend_get_context(backend), usb_device);
 	fu_backend_device_added(backend, FU_DEVICE(device));
 }
 
@@ -77,7 +77,7 @@ fu_usb_backend_context_finalized_cb(gpointer data, GObject *where_the_object_was
 }
 
 static gboolean
-fu_usb_backend_setup(FuBackend *backend, GError **error)
+fu_usb_backend_setup(FuBackend *backend, FuProgress *progress, GError **error)
 {
 	FuUsbBackend *self = FU_USB_BACKEND(backend);
 
@@ -87,6 +87,56 @@ fu_usb_backend_setup(FuBackend *backend, GError **error)
 		return FALSE;
 	}
 	g_object_weak_ref(G_OBJECT(self->usb_ctx), fu_usb_backend_context_finalized_cb, self);
+	return TRUE;
+}
+
+static void
+fu_usb_backend_coldplug_device(FuUsbBackend *self, GUsbDevice *usb_device, FuProgress *progress)
+{
+	g_autoptr(FuUsbDevice) device = NULL;
+	g_autofree gchar *name = NULL;
+
+	name = g_strdup_printf("%04X:%04X",
+			       g_usb_device_get_vid(usb_device),
+			       g_usb_device_get_pid(usb_device));
+	fu_progress_set_name(progress, name);
+	device = fu_usb_device_new(fu_backend_get_context(FU_BACKEND(self)), usb_device);
+	fu_backend_device_added(FU_BACKEND(self), FU_DEVICE(device));
+}
+
+static void
+fu_usb_backend_coldplug_devices(FuUsbBackend *self, GPtrArray *usb_devices, FuProgress *progress)
+{
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_set_steps(progress, usb_devices->len);
+	for (guint i = 0; i < usb_devices->len; i++) {
+		GUsbDevice *usb_device = g_ptr_array_index(usb_devices, i);
+		fu_usb_backend_coldplug_device(self, usb_device, fu_progress_get_child(progress));
+		fu_progress_step_done(progress);
+	}
+}
+
+static gboolean
+fu_usb_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **error)
+{
+	FuUsbBackend *self = FU_USB_BACKEND(backend);
+	g_autoptr(GPtrArray) usb_devices = NULL;
+
+	/* progress */
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 1, "enumerate");
+	fu_progress_add_step(progress, FWUPD_STATUS_LOADING, 99, "add-devices");
+
+	/* no insight */
+	g_usb_context_enumerate(self->usb_ctx);
+	fu_progress_step_done(progress);
+
+	/* add each device */
+	usb_devices = g_usb_context_get_devices(self->usb_ctx);
+	fu_usb_backend_coldplug_devices(self, usb_devices, fu_progress_get_child(progress));
+	fu_progress_step_done(progress);
+
+	/* watch for future changes */
 	g_signal_connect(G_USB_CONTEXT(self->usb_ctx),
 			 "device-added",
 			 G_CALLBACK(fu_usb_backend_device_added_cb),
@@ -95,15 +145,6 @@ fu_usb_backend_setup(FuBackend *backend, GError **error)
 			 "device-removed",
 			 G_CALLBACK(fu_usb_backend_device_removed_cb),
 			 self);
-
-	return TRUE;
-}
-
-static gboolean
-fu_usb_backend_coldplug(FuBackend *backend, GError **error)
-{
-	FuUsbBackend *self = FU_USB_BACKEND(backend);
-	g_usb_context_enumerate(self->usb_ctx);
 	return TRUE;
 }
 
