@@ -6,14 +6,15 @@
 
 #define G_LOG_DOMAIN "FuMain"
 
-#include <config.h>
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <stdio.h>
 #include <unistd.h>
 #ifdef HAVE_GUSB
 #include <gusb.h>
 #endif
-#include <fwupd.h>
+
 #include <xmlb.h>
 #ifdef HAVE_LIBCURL
 #include <curl/curl.h>
@@ -24,11 +25,8 @@
 #include <windows.h>
 #endif
 
-#include "fu-common.h"
 #include "fu-device-private.h"
-#include "fu-device.h"
-#include "fu-security-attr.h"
-#include "fu-security-attrs.h"
+#include "fu-security-attr-common.h"
 #include "fu-util-common.h"
 
 #ifdef HAVE_SYSTEMD
@@ -49,6 +47,8 @@ fu_util_get_systemd_unit(void)
 gchar *
 fu_util_term_format(const gchar *text, FuUtilTermColor fg_color)
 {
+	if (g_getenv("NO_COLOR") != NULL)
+		return g_strdup(text);
 	return g_strdup_printf("\033[%um\033[1m%s\033[0m", fg_color, text);
 }
 
@@ -105,7 +105,7 @@ fu_util_print_data(const gchar *title, const gchar *msg)
 	g_print("%s:", title);
 
 	/* pad */
-	title_len = fu_common_strwidth(title) + 1;
+	title_len = fu_strwidth(title) + 1;
 	lines = g_strsplit(msg, "\n", -1);
 	for (guint j = 0; lines[j] != NULL; j++) {
 		for (gsize i = title_len; i < 25; i++)
@@ -166,6 +166,7 @@ fu_util_prompt_for_boolean(gboolean def)
 static gboolean
 fu_util_traverse_tree(GNode *n, gpointer data)
 {
+	FwupdClient *client = FWUPD_CLIENT(data);
 	guint idx = g_node_depth(n) - 1;
 	g_autofree gchar *tmp = NULL;
 	g_auto(GStrv) split = NULL;
@@ -173,7 +174,7 @@ fu_util_traverse_tree(GNode *n, gpointer data)
 	/* get split lines */
 	if (FWUPD_IS_DEVICE(n->data)) {
 		FwupdDevice *dev = FWUPD_DEVICE(n->data);
-		tmp = fu_util_device_to_string(dev, idx);
+		tmp = fu_util_device_to_string(client, dev, idx);
 	} else if (FWUPD_IS_REMOTE(n->data)) {
 		FwupdRemote *remote = FWUPD_REMOTE(n->data);
 		tmp = fu_util_remote_to_string(remote, idx);
@@ -185,8 +186,10 @@ fu_util_traverse_tree(GNode *n, gpointer data)
 
 	/* root node */
 	if (n->data == NULL && g_getenv("FWUPD_VERBOSE") == NULL) {
-		const gchar *str = data;
-		g_print("%s\n│\n", str != NULL ? str : "○");
+		g_autofree gchar *str = g_strdup_printf("%s %s",
+							fwupd_client_get_host_vendor(client),
+							fwupd_client_get_host_product(client));
+		g_print("%s\n│\n", str);
 		return FALSE;
 	}
 
@@ -237,9 +240,9 @@ fu_util_traverse_tree(GNode *n, gpointer data)
 }
 
 void
-fu_util_print_tree(GNode *n, gpointer data)
+fu_util_print_tree(FwupdClient *client, GNode *n)
 {
-	g_node_traverse(n, G_PRE_ORDER, G_TRAVERSE_ALL, -1, fu_util_traverse_tree, data);
+	g_node_traverse(n, G_PRE_ORDER, G_TRAVERSE_ALL, -1, fu_util_traverse_tree, client);
 }
 
 static gboolean
@@ -427,9 +430,9 @@ fu_util_prompt_warning(FwupdDevice *device,
 	g_autoptr(GString) str = g_string_new(NULL);
 
 	/* up, down, or re-install */
-	vercmp = fu_common_vercmp_full(fwupd_release_get_version(release),
-				       fu_device_get_version(device),
-				       fwupd_device_get_version_format(device));
+	vercmp = fu_version_compare(fwupd_release_get_version(release),
+				    fu_device_get_version(device),
+				    fwupd_device_get_version_format(device));
 	if (vercmp < 0) {
 		g_string_append_printf(
 		    title,
@@ -653,11 +656,11 @@ fu_util_cmd_array_to_string(GPtrArray *array)
 		FuUtilCmd *item = g_ptr_array_index(array, i);
 		g_string_append(string, "  ");
 		g_string_append(string, item->name);
-		len = fu_common_strwidth(item->name) + 2;
+		len = fu_strwidth(item->name) + 2;
 		if (item->arguments != NULL) {
 			g_string_append(string, " ");
 			g_string_append(string, item->arguments);
-			len += fu_common_strwidth(item->arguments) + 1;
+			len += fu_strwidth(item->arguments) + 1;
 		}
 		if (len < max_len) {
 			for (gsize j = len; j < max_len + 1; j++)
@@ -794,6 +797,24 @@ fu_util_release_get_name(FwupdRelease *release)
 			 * is the device that updates all the other firmware on the system */
 			return g_strdup_printf(_("%s BMC Update"), name);
 		}
+		if (g_strcmp0(cat, "X-UsbReceiver") == 0) {
+			/* TRANSLATORS: Receiver refers to a radio device, e.g. a tiny Bluetooth
+			 * device that stays in the USB port so the wireless peripheral works */
+			return g_strdup_printf(_("%s USB Receiver Update"), name);
+		}
+		if (g_strcmp0(cat, "X-Drive") == 0) {
+			/* TRANSLATORS: drive refers to a storage device, e.g. SATA disk */
+			return g_strdup_printf(_("%s Drive Update"), name);
+		}
+		if (g_strcmp0(cat, "X-FlashDrive") == 0) {
+			/* TRANSLATORS: flash refers to solid state storage, e.g. UFS or eMMC */
+			return g_strdup_printf(_("%s Flash Drive Update"), name);
+		}
+		if (g_strcmp0(cat, "X-SolidStateDrive") == 0) {
+			/* TRANSLATORS: SSD refers to a Solid State Drive, e.g. non-rotating
+			 * SATA or NVMe disk */
+			return g_strdup_printf(_("%s SSD Update"), name);
+		}
 	}
 
 	/* TRANSLATORS: this is the fallback where we don't know if the release
@@ -806,7 +827,7 @@ static GPtrArray *
 fu_util_strsplit_words(const gchar *text, guint line_len)
 {
 	g_auto(GStrv) tokens = NULL;
-	g_autoptr(GPtrArray) lines = g_ptr_array_new();
+	g_autoptr(GPtrArray) lines = g_ptr_array_new_with_free_func(g_free);
 	g_autoptr(GString) curline = g_string_new(NULL);
 
 	/* sanity check */
@@ -819,7 +840,7 @@ fu_util_strsplit_words(const gchar *text, guint line_len)
 	tokens = g_strsplit(text, " ", -1);
 	for (guint i = 0; tokens[i] != NULL; i++) {
 		/* current line plus new token is okay */
-		if (curline->len + fu_common_strwidth(tokens[i]) < line_len) {
+		if (curline->len + fu_strwidth(tokens[i]) < line_len) {
 			g_string_append_printf(curline, "%s ", tokens[i]);
 			continue;
 		}
@@ -849,15 +870,15 @@ fu_util_warning_box_line(const gchar *start,
 {
 	guint offset = 0;
 	if (start != NULL) {
-		offset += fu_common_strwidth(start);
+		offset += fu_strwidth(start);
 		g_print("%s", start);
 	}
 	if (text != NULL) {
-		offset += fu_common_strwidth(text);
+		offset += fu_strwidth(text);
 		g_print("%s", text);
 	}
 	if (end != NULL)
-		offset += fu_common_strwidth(end);
+		offset += fu_strwidth(end);
 	for (guint i = offset; i < width; i++)
 		g_print("%s", padding);
 	if (end != NULL)
@@ -1067,7 +1088,7 @@ fu_util_convert_description(const gchar *xml, GError **error)
 			     &helper);
 
 	/* success */
-	return fu_common_strstrip(str->str);
+	return fu_strstrip(str->str);
 }
 
 /**
@@ -1301,8 +1322,61 @@ fu_util_update_state_to_string(FwupdUpdateState update_state)
 	return NULL;
 }
 
+static gchar *
+fu_util_device_problem_to_string(FwupdClient *client, FwupdDevice *dev, FwupdDeviceProblem problem)
+{
+	if (problem == FWUPD_DEVICE_PROBLEM_NONE)
+		return NULL;
+	if (problem == FWUPD_DEVICE_PROBLEM_UNKNOWN)
+		return NULL;
+	if (problem == FWUPD_DEVICE_PROBLEM_SYSTEM_POWER_TOO_LOW) {
+		if (fwupd_client_get_battery_level(client) == FWUPD_BATTERY_LEVEL_INVALID ||
+		    fwupd_client_get_battery_threshold(client) == FWUPD_BATTERY_LEVEL_INVALID) {
+			/* TRANSLATORS: as in laptop battery power */
+			return g_strdup(_("System power is too low to perform the update"));
+		}
+		return g_strdup_printf(
+		    /* TRANSLATORS: as in laptop battery power */
+		    _("System power is too low to perform the update (%u%%, requires %u%%)"),
+		    fwupd_client_get_battery_level(client),
+		    fwupd_client_get_battery_threshold(client));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_UNREACHABLE) {
+		/* TRANSLATORS: for example, a Bluetooth mouse that is in powersave mode */
+		return g_strdup(_("Device is unreachable, or out of wireless range"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW) {
+		if (fwupd_device_get_battery_level(dev) == FWUPD_BATTERY_LEVEL_INVALID ||
+		    fwupd_device_get_battery_threshold(dev) == FWUPD_BATTERY_LEVEL_INVALID) {
+			/* TRANSLATORS: for example the batteries *inside* the Bluetooth mouse */
+			return g_strdup_printf(_("Device battery power is too low"));
+		}
+		/* TRANSLATORS: for example the batteries *inside* the Bluetooth mouse */
+		return g_strdup_printf(_("Device battery power is too low (%u%%, requires %u%%)"),
+				       fwupd_device_get_battery_level(dev),
+				       fwupd_device_get_battery_threshold(dev));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_UPDATE_PENDING) {
+		/* TRANSLATORS: usually this is when we're waiting for a reboot */
+		return g_strdup(_("Device is waiting for the update to be applied"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER) {
+		/* TRANSLATORS: as in, wired mains power for a laptop */
+		return g_strdup(_("Device requires AC power to be connected"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED) {
+		/* TRANSLATORS: lid means "laptop top cover" */
+		return g_strdup(_("Device cannot be used while the lid is closed"));
+	}
+	if (problem == FWUPD_DEVICE_PROBLEM_IS_EMULATED) {
+		/* TRANSLATORS: emulated means we are pretending to be a different model */
+		return g_strdup(_("Device is emulated"));
+	}
+	return NULL;
+}
+
 gchar *
-fu_util_device_to_string(FwupdDevice *dev, guint idt)
+fu_util_device_to_string(FwupdClient *client, FwupdDevice *dev, guint idt)
 {
 	FwupdUpdateState state;
 	GPtrArray *guids = fwupd_device_get_guids(dev);
@@ -1329,19 +1403,19 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 		/* TRANSLATORS: Name of hardware */
 		tmp = _("Unknown Device");
 	}
-	fu_common_string_append_kv(str, idt, tmp, NULL);
+	fu_string_append(str, idt, tmp, NULL);
 
 	tmp = fwupd_device_get_id(dev);
 	if (tmp != NULL) {
 		/* TRANSLATORS: ID for hardware, typically a SHA1 sum */
-		fu_common_string_append_kv(str, idt + 1, _("Device ID"), tmp);
+		fu_string_append(str, idt + 1, _("Device ID"), tmp);
 	}
 
 	/* summary */
 	tmp = fwupd_device_get_summary(dev);
 	if (tmp != NULL) {
 		/* TRANSLATORS: one line summary of device */
-		fu_common_string_append_kv(str, idt + 1, _("Summary"), tmp);
+		fu_string_append(str, idt + 1, _("Summary"), tmp);
 	}
 
 	/* description */
@@ -1352,7 +1426,7 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 		if (desc == NULL)
 			desc = g_strdup(tmp);
 		/* TRANSLATORS: multiline description of device */
-		fu_common_string_append_kv(str, idt + 1, _("Description"), desc);
+		fu_string_append(str, idt + 1, _("Description"), desc);
 	}
 
 	/* versions */
@@ -1366,47 +1440,46 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 			g_string_append_printf(verstr, " [%s]", datestr);
 		}
 		if (flags & FWUPD_DEVICE_FLAG_HISTORICAL) {
-			fu_common_string_append_kv(
-			    str,
-			    idt + 1,
-			    /* TRANSLATORS: version number of previous firmware */
-			    _("Previous version"),
-			    verstr->str);
+			fu_string_append(str,
+					 idt + 1,
+					 /* TRANSLATORS: version number of previous firmware */
+					 _("Previous version"),
+					 verstr->str);
 		} else {
 			/* TRANSLATORS: version number of current firmware */
-			fu_common_string_append_kv(str, idt + 1, _("Current version"), verstr->str);
+			fu_string_append(str, idt + 1, _("Current version"), verstr->str);
 		}
 	}
 	tmp = fwupd_device_get_version_lowest(dev);
 	if (tmp != NULL) {
 		/* TRANSLATORS: smallest version number installable on device */
-		fu_common_string_append_kv(str, idt + 1, _("Minimum Version"), tmp);
+		fu_string_append(str, idt + 1, _("Minimum Version"), tmp);
 	}
 	tmp = fwupd_device_get_version_bootloader(dev);
 	if (tmp != NULL) {
 		/* TRANSLATORS: firmware version of bootloader */
-		fu_common_string_append_kv(str, idt + 1, _("Bootloader Version"), tmp);
+		fu_string_append(str, idt + 1, _("Bootloader Version"), tmp);
 	}
 
 	/* vendor */
 	tmp = fwupd_device_get_vendor(dev);
 	if (tmp != NULL && vendor_ids->len > 0) {
-		g_autofree gchar *strv = fu_common_strjoin_array(", ", vendor_ids);
+		g_autofree gchar *strv = fu_strjoin(", ", vendor_ids);
 		g_autofree gchar *both = g_strdup_printf("%s (%s)", tmp, strv);
 		/* TRANSLATORS: manufacturer of hardware */
-		fu_common_string_append_kv(str, idt + 1, _("Vendor"), both);
+		fu_string_append(str, idt + 1, _("Vendor"), both);
 	} else if (tmp != NULL) {
 		/* TRANSLATORS: manufacturer of hardware */
-		fu_common_string_append_kv(str, idt + 1, _("Vendor"), tmp);
+		fu_string_append(str, idt + 1, _("Vendor"), tmp);
 	} else if (vendor_ids->len > 0) {
-		g_autofree gchar *strv = fu_common_strjoin_array("|", vendor_ids);
+		g_autofree gchar *strv = fu_strjoin("|", vendor_ids);
 		/* TRANSLATORS: manufacturer of hardware */
-		fu_common_string_append_kv(str, idt + 1, _("Vendor"), strv);
+		fu_string_append(str, idt + 1, _("Vendor"), strv);
 	}
 
 	/* branch */
 	if (fwupd_device_get_branch(dev) != NULL) {
-		fu_common_string_append_kv(
+		fu_string_append(
 		    str,
 		    idt + 1,
 		    /* TRANSLATORS: the stream of firmware, e.g. nonfree or open-source */
@@ -1419,31 +1492,31 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 		g_autofree gchar *time =
 		    fu_util_time_to_str(fwupd_device_get_install_duration(dev));
 		/* TRANSLATORS: length of time the update takes to apply */
-		fu_common_string_append_kv(str, idt + 1, _("Install Duration"), time);
+		fu_string_append(str, idt + 1, _("Install Duration"), time);
 	}
 
 	/* serial # */
 	tmp = fwupd_device_get_serial(dev);
 	if (tmp != NULL) {
 		/* TRANSLATORS: serial number of hardware */
-		fu_common_string_append_kv(str, idt + 1, _("Serial Number"), tmp);
+		fu_string_append(str, idt + 1, _("Serial Number"), tmp);
 	}
 
 	/* update state */
 	state = fwupd_device_get_update_state(dev);
 	if (state != FWUPD_UPDATE_STATE_UNKNOWN) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: hardware state, e.g. "pending" */
-					   _("Update State"),
-					   fu_util_update_state_to_string(state));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: hardware state, e.g. "pending" */
+				 _("Update State"),
+				 fu_util_update_state_to_string(state));
 
 		if (state == FWUPD_UPDATE_STATE_SUCCESS) {
 			tmp = fwupd_device_get_update_message(dev);
 			if (tmp != NULL) {
 				g_autofree gchar *color =
 				    fu_util_term_format(tmp, FU_UTIL_TERM_COLOR_BLUE);
-				fu_common_string_append_kv(
+				fu_string_append(
 				    str,
 				    idt + 1,
 				    /* TRANSLATORS: helpful messages from last update */
@@ -1452,11 +1525,54 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 			}
 		}
 	}
-	tmp = fwupd_device_get_update_error(dev);
-	if (tmp != NULL) {
-		g_autofree gchar *color = fu_util_term_format(tmp, FU_UTIL_TERM_COLOR_RED);
-		/* TRANSLATORS: error message from last update attempt */
-		fu_common_string_append_kv(str, idt + 1, _("Update Error"), color);
+
+	/* battery, but only if we're not about to show the same info as an inhibit */
+	if (!fwupd_device_has_problem(dev, FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW)) {
+		if (fwupd_device_get_battery_level(dev) != FWUPD_BATTERY_LEVEL_INVALID &&
+		    fwupd_device_get_battery_threshold(dev) != FWUPD_BATTERY_LEVEL_INVALID) {
+			g_autofree gchar *val = NULL;
+			/* TRANSLATORS: first percentage is current value, 2nd percentage is the
+			 * lowest limit the firmware update is allowed for the update to happen */
+			val = g_strdup_printf(_("%u%% (threshold %u%%)"),
+					      fwupd_device_get_battery_level(dev),
+					      fwupd_device_get_battery_threshold(dev));
+			/* TRANSLATORS: refers to the battery inside the peripheral device */
+			fu_string_append(str, idt + 1, _("Battery"), val);
+		} else if (fwupd_device_get_battery_level(dev) != FWUPD_BATTERY_LEVEL_INVALID) {
+			g_autofree gchar *val = NULL;
+			val = g_strdup_printf("%u%%", fwupd_device_get_battery_level(dev));
+			/* TRANSLATORS: refers to the battery inside the peripheral device */
+			fu_string_append(str, idt + 1, _("Battery"), val);
+		}
+	}
+
+	/* either show enumerated [translated] problems or the synthesized update error */
+	if (fwupd_device_get_problems(dev) == FWUPD_DEVICE_PROBLEM_NONE) {
+		tmp = fwupd_device_get_update_error(dev);
+		if (tmp != NULL) {
+			g_autofree gchar *color = fu_util_term_format(tmp, FU_UTIL_TERM_COLOR_RED);
+			/* TRANSLATORS: error message from last update attempt */
+			fu_string_append(str, idt + 1, _("Update Error"), color);
+		}
+	} else {
+		/* TRANSLATORS: reasons the device is not updatable */
+		tmp = _("Problems");
+		for (guint i = 0; i < 64; i++) {
+			FwupdDeviceProblem problem = (guint64)1 << i;
+			g_autofree gchar *bullet = NULL;
+			g_autofree gchar *desc = NULL;
+			g_autofree gchar *color = NULL;
+
+			if (!fwupd_device_has_problem(dev, problem))
+				continue;
+			desc = fu_util_device_problem_to_string(client, dev, problem);
+			if (desc == NULL)
+				continue;
+			bullet = g_strdup_printf("• %s", desc);
+			color = fu_util_term_format(bullet, FU_UTIL_TERM_COLOR_RED);
+			fu_string_append(str, idt + 1, tmp, color);
+			tmp = NULL;
+		}
 	}
 
 	/* modified date: for history devices */
@@ -1466,7 +1582,7 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 		date = g_date_time_new_from_unix_utc(modified);
 		time_str = g_date_time_format(date, "%F %R");
 		/* TRANSLATORS: the original time/date the device was modified */
-		fu_common_string_append_kv(str, idt + 1, _("Last modified"), time_str);
+		fu_string_append(str, idt + 1, _("Last modified"), time_str);
 	}
 
 	/* all GUIDs for this hardware, with IDs if available */
@@ -1489,14 +1605,13 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 			guid_src = g_strdup_printf("%s ← %s", guid, instance_id);
 		}
 		if (i == 0) {
-			fu_common_string_append_kv(
-			    str,
-			    idt + 1,
-			    /* TRANSLATORS: global ID common to all similar hardware */
-			    ngettext("GUID", "GUIDs", guids->len),
-			    guid_src);
+			fu_string_append(str,
+					 idt + 1,
+					 /* TRANSLATORS: global ID common to all similar hardware */
+					 ngettext("GUID", "GUIDs", guids->len),
+					 guid_src);
 		} else {
-			fu_common_string_append_kv(str, idt + 1, "", guid_src);
+			fu_string_append(str, idt + 1, "", guid_src);
 		}
 	}
 
@@ -1512,21 +1627,21 @@ fu_util_device_to_string(FwupdDevice *dev, guint idt)
 		if (tmp != NULL) {
 			g_autofree gchar *bullet = NULL;
 			bullet = g_strdup_printf("• %s", tmp2);
-			fu_common_string_append_kv(str, idt + 1, tmp, bullet);
+			fu_string_append(str, idt + 1, tmp, bullet);
 			tmp = NULL;
 		} else {
 			g_autofree gchar *bullet = NULL;
 			bullet = g_strdup_printf("• %s", tmp2);
-			fu_common_string_append_kv(str, idt + 1, "", bullet);
+			fu_string_append(str, idt + 1, "", bullet);
 		}
 	}
 	for (guint i = 0; i < issues->len; i++) {
 		const gchar *issue = g_ptr_array_index(issues, i);
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: issue fixed with the release, e.g. CVE */
-					   i == 0 ? ngettext("Issue", "Issues", issues->len) : "",
-					   issue);
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: issue fixed with the release, e.g. CVE */
+				 i == 0 ? ngettext("Issue", "Issues", issues->len) : "",
+				 issue);
 	}
 
 	return g_string_free(g_steal_pointer(&str), FALSE);
@@ -1632,14 +1747,14 @@ fu_util_plugin_to_string(FwupdPlugin *plugin, guint idt)
 	const gchar *hdr;
 	guint64 flags = fwupd_plugin_get_flags(plugin);
 
-	fu_common_string_append_kv(str, idt, fwupd_plugin_get_name(plugin), NULL);
+	fu_string_append(str, idt, fwupd_plugin_get_name(plugin), NULL);
 
 	/* TRANSLATORS: description of plugin state, e.g. disabled */
 	hdr = _("Flags");
 	if (flags == 0x0) {
 		g_autofree gchar *tmp = fu_util_plugin_flag_to_cli_text(flags);
 		g_autofree gchar *li = g_strdup_printf("• %s", tmp);
-		fu_common_string_append_kv(str, idt + 1, hdr, li);
+		fu_string_append(str, idt + 1, hdr, li);
 	} else {
 		for (guint i = 0; i < 64; i++) {
 			g_autofree gchar *li = NULL;
@@ -1650,7 +1765,7 @@ fu_util_plugin_to_string(FwupdPlugin *plugin, guint idt)
 			if (tmp == NULL)
 				continue;
 			li = g_strdup_printf("• %s", tmp);
-			fu_common_string_append_kv(str, idt + 1, hdr, li);
+			fu_string_append(str, idt + 1, hdr, li);
 
 			/* clear header */
 			hdr = "";
@@ -1753,27 +1868,27 @@ fu_util_release_to_string(FwupdRelease *rel, guint idt)
 
 	g_return_val_if_fail(FWUPD_IS_RELEASE(rel), NULL);
 
-	fu_common_string_append_kv(str, idt, fwupd_release_get_name(rel), NULL);
+	fu_string_append(str, idt, fwupd_release_get_name(rel), NULL);
 
 	/* TRANSLATORS: version number of new firmware */
-	fu_common_string_append_kv(str, idt + 1, _("New version"), fwupd_release_get_version(rel));
+	fu_string_append(str, idt + 1, _("New version"), fwupd_release_get_version(rel));
 
 	if (fwupd_release_get_remote_id(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: the server the file is coming from */
-					   _("Remote ID"),
-					   fwupd_release_get_remote_id(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: the server the file is coming from */
+				 _("Remote ID"),
+				 fwupd_release_get_remote_id(rel));
 	}
 	if (fwupd_release_get_id(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: the exact component on the server */
-					   _("Release ID"),
-					   fwupd_release_get_id(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: the exact component on the server */
+				 _("Release ID"),
+				 fwupd_release_get_id(rel));
 	}
 	if (fwupd_release_get_branch(rel) != NULL) {
-		fu_common_string_append_kv(
+		fu_string_append(
 		    str,
 		    idt + 1,
 		    /* TRANSLATORS: the stream of firmware, e.g. nonfree or open-source */
@@ -1781,79 +1896,86 @@ fu_util_release_to_string(FwupdRelease *rel, guint idt)
 		    fwupd_release_get_branch(rel));
 	}
 	if (fwupd_release_get_summary(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: one line summary of device */
-					   _("Summary"),
-					   fwupd_release_get_summary(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: one line summary of device */
+				 _("Summary"),
+				 fwupd_release_get_summary(rel));
 	}
 	if (fwupd_release_get_name_variant_suffix(rel) != NULL) {
-		fu_common_string_append_kv(
+		fu_string_append(
 		    str,
 		    idt + 1,
 		    /* TRANSLATORS: one line variant of release (e.g. 'Prerelease' or 'China') */
 		    _("Variant"),
 		    fwupd_release_get_name_variant_suffix(rel));
 	}
-	fu_common_string_append_kv(str,
-				   idt + 1,
-				   /* TRANSLATORS: e.g. GPLv2+, Proprietary etc */
-				   _("License"),
-				   fu_util_license_to_string(fwupd_release_get_license(rel)));
+	fu_string_append(str,
+			 idt + 1,
+			 /* TRANSLATORS: e.g. GPLv2+, Proprietary etc */
+			 _("License"),
+			 fu_util_license_to_string(fwupd_release_get_license(rel)));
 	if (fwupd_release_get_size(rel) != 0) {
 		g_autofree gchar *tmp = NULL;
 		tmp = g_format_size(fwupd_release_get_size(rel));
 		/* TRANSLATORS: file size of the download */
-		fu_common_string_append_kv(str, idt + 1, _("Size"), tmp);
+		fu_string_append(str, idt + 1, _("Size"), tmp);
 	}
 	if (fwupd_release_get_created(rel) != 0) {
 		gint64 value = (gint64)fwupd_release_get_created(rel);
 		g_autoptr(GDateTime) date = g_date_time_new_from_unix_utc(value);
 		g_autofree gchar *tmp = g_date_time_format(date, "%F");
 		/* TRANSLATORS: when the update was built */
-		fu_common_string_append_kv(str, idt + 1, _("Created"), tmp);
+		fu_string_append(str, idt + 1, _("Created"), tmp);
 	}
 	if (fwupd_release_get_urgency(rel) != FWUPD_RELEASE_URGENCY_UNKNOWN) {
 		FwupdReleaseUrgency tmp = fwupd_release_get_urgency(rel);
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: how important the release is */
-					   _("Urgency"),
-					   fu_util_release_urgency_to_string(tmp));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: how important the release is */
+				 _("Urgency"),
+				 fu_util_release_urgency_to_string(tmp));
 	}
 	if (fwupd_release_get_details_url(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: more details about the update link */
-					   _("Details"),
-					   fwupd_release_get_details_url(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: more details about the update link */
+				 _("Details"),
+				 fwupd_release_get_details_url(rel));
 	}
 	if (fwupd_release_get_source_url(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: source (as in code) link */
-					   _("Source"),
-					   fwupd_release_get_source_url(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: source (as in code) link */
+				 _("Source"),
+				 fwupd_release_get_source_url(rel));
 	}
 	if (fwupd_release_get_vendor(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: manufacturer of hardware */
-					   _("Vendor"),
-					   fwupd_release_get_vendor(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: manufacturer of hardware */
+				 _("Vendor"),
+				 fwupd_release_get_vendor(rel));
 	}
 	if (fwupd_release_get_install_duration(rel) != 0) {
 		g_autofree gchar *tmp =
 		    fu_util_time_to_str(fwupd_release_get_install_duration(rel));
 		/* TRANSLATORS: length of time the update takes to apply */
-		fu_common_string_append_kv(str, idt + 1, _("Duration"), tmp);
+		fu_string_append(str, idt + 1, _("Duration"), tmp);
 	}
 	if (fwupd_release_get_update_message(rel) != NULL) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: helpful messages for the update */
-					   _("Update Message"),
-					   fwupd_release_get_update_message(rel));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: helpful messages for the update */
+				 _("Update Message"),
+				 fwupd_release_get_update_message(rel));
+	}
+	if (fwupd_release_get_update_image(rel) != NULL) {
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: helpful image for the update */
+				 _("Update Image"),
+				 fwupd_release_get_update_image(rel));
 	}
 
 	/* TRANSLATORS: release attributes */
@@ -1866,7 +1988,7 @@ fu_util_release_to_string(FwupdRelease *rel, guint idt)
 		if (tmp2 == NULL)
 			continue;
 		bullet = g_strdup_printf("• %s", tmp2);
-		fu_common_string_append_kv(str, idt + 1, title, bullet);
+		fu_string_append(str, idt + 1, title, bullet);
 		title = "";
 	}
 
@@ -1877,29 +1999,27 @@ fu_util_release_to_string(FwupdRelease *rel, guint idt)
 		if (desc == NULL)
 			desc = g_strdup(fwupd_release_get_description(rel));
 		/* TRANSLATORS: multiline description of device */
-		fu_common_string_append_kv(str, idt + 1, _("Description"), desc);
+		fu_string_append(str, idt + 1, _("Description"), desc);
 	}
 	for (guint i = 0; i < issues->len; i++) {
 		const gchar *issue = g_ptr_array_index(issues, i);
 		if (i == 0) {
-			fu_common_string_append_kv(
-			    str,
-			    idt + 1,
-			    /* TRANSLATORS: issue fixed with the release, e.g. CVE */
-			    ngettext("Issue", "Issues", issues->len),
-			    issue);
+			fu_string_append(str,
+					 idt + 1,
+					 /* TRANSLATORS: issue fixed with the release, e.g. CVE */
+					 ngettext("Issue", "Issues", issues->len),
+					 issue);
 		} else {
-			fu_common_string_append_kv(str, idt + 1, "", issue);
+			fu_string_append(str, idt + 1, "", issue);
 		}
 	}
 	if (tags->len > 0) {
-		g_autofree gchar *tag_strs = fu_common_strjoin_array(", ", tags);
-		fu_common_string_append_kv(
-		    str,
-		    idt + 1,
-		    /* TRANSLATORS: release tag set for release, e.g. lenovo-2021q3 */
-		    ngettext("Tag", "Tags", tags->len),
-		    tag_strs);
+		g_autofree gchar *tag_strs = fu_strjoin(", ", tags);
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: release tag set for release, e.g. lenovo-2021q3 */
+				 ngettext("Tag", "Tags", tags->len),
+				 tag_strs);
 	}
 
 	return g_string_free(str, FALSE);
@@ -1916,32 +2036,32 @@ fu_util_remote_to_string(FwupdRemote *remote, guint idt)
 
 	g_return_val_if_fail(FWUPD_IS_REMOTE(remote), NULL);
 
-	fu_common_string_append_kv(str, idt, fwupd_remote_get_title(remote), NULL);
+	fu_string_append(str, idt, fwupd_remote_get_title(remote), NULL);
 
 	/* TRANSLATORS: remote identifier, e.g. lvfs-testing */
-	fu_common_string_append_kv(str, idt + 1, _("Remote ID"), fwupd_remote_get_id(remote));
+	fu_string_append(str, idt + 1, _("Remote ID"), fwupd_remote_get_id(remote));
 
 	/* TRANSLATORS: remote type, e.g. remote or local */
-	fu_common_string_append_kv(str, idt + 1, _("Type"), fwupd_remote_kind_to_string(kind));
+	fu_string_append(str, idt + 1, _("Type"), fwupd_remote_kind_to_string(kind));
 
 	if (keyring_kind != FWUPD_KEYRING_KIND_UNKNOWN) {
-		fu_common_string_append_kv(str,
-					   idt + 1,
-					   /* TRANSLATORS: keyring type, e.g. GPG or PKCS7 */
-					   _("Keyring"),
-					   fwupd_keyring_kind_to_string(keyring_kind));
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: keyring type, e.g. GPG or PKCS7 */
+				 _("Keyring"),
+				 fwupd_keyring_kind_to_string(keyring_kind));
 	}
 
-	fu_common_string_append_kv(str,
-				   idt + 1,
-				   /* TRANSLATORS: if the remote is enabled */
-				   _("Enabled"),
-				   fwupd_remote_get_enabled(remote) ? "true" : "false");
+	fu_string_append(str,
+			 idt + 1,
+			 /* TRANSLATORS: if the remote is enabled */
+			 _("Enabled"),
+			 fwupd_remote_get_enabled(remote) ? "true" : "false");
 
 	tmp = fwupd_remote_get_checksum(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: remote checksum */
-		fu_common_string_append_kv(str, idt + 1, _("Checksum"), tmp);
+		fu_string_append(str, idt + 1, _("Checksum"), tmp);
 	}
 
 	/* optional parameters */
@@ -1968,66 +2088,65 @@ fu_util_remote_to_string(FwupdRemote *remote, guint idt)
 		}
 		age_str = g_strdup_printf("%.2f%s", age, unit);
 		/* TRANSLATORS: the age of the metadata */
-		fu_common_string_append_kv(str, idt + 1, _("Age"), age_str);
+		fu_string_append(str, idt + 1, _("Age"), age_str);
 	}
 	priority = fwupd_remote_get_priority(remote);
 	if (priority != 0) {
 		g_autofree gchar *priority_str = NULL;
 		priority_str = g_strdup_printf("%i", priority);
 		/* TRANSLATORS: the numeric priority */
-		fu_common_string_append_kv(str, idt + 1, _("Priority"), priority_str);
+		fu_string_append(str, idt + 1, _("Priority"), priority_str);
 	}
 	tmp = fwupd_remote_get_username(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: remote filename base */
-		fu_common_string_append_kv(str, idt + 1, _("Username"), tmp);
+		fu_string_append(str, idt + 1, _("Username"), tmp);
 	}
 	tmp = fwupd_remote_get_password(remote);
 	if (tmp != NULL) {
-		g_autofree gchar *hidden = g_strnfill(fu_common_strwidth(tmp), '*');
+		g_autofree gchar *hidden = g_strnfill(fu_strwidth(tmp), '*');
 		/* TRANSLATORS: remote filename base */
-		fu_common_string_append_kv(str, idt + 1, _("Password"), hidden);
+		fu_string_append(str, idt + 1, _("Password"), hidden);
 	}
 	tmp = fwupd_remote_get_filename_cache(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: filename of the local file */
-		fu_common_string_append_kv(str, idt + 1, _("Filename"), tmp);
+		fu_string_append(str, idt + 1, _("Filename"), tmp);
 	}
 	tmp = fwupd_remote_get_filename_cache_sig(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: filename of the local file */
-		fu_common_string_append_kv(str, idt + 1, _("Filename Signature"), tmp);
+		fu_string_append(str, idt + 1, _("Filename Signature"), tmp);
 	}
 	tmp = fwupd_remote_get_filename_source(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: full path of the remote.conf file */
-		fu_common_string_append_kv(str, idt + 1, _("Filename Source"), tmp);
+		fu_string_append(str, idt + 1, _("Filename Source"), tmp);
 	}
 	tmp = fwupd_remote_get_metadata_uri(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: remote URI */
-		fu_common_string_append_kv(str, idt + 1, _("Metadata URI"), tmp);
+		fu_string_append(str, idt + 1, _("Metadata URI"), tmp);
 	}
 	tmp = fwupd_remote_get_metadata_uri_sig(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: remote URI */
-		fu_common_string_append_kv(str, idt + 1, _("Metadata Signature"), tmp);
+		fu_string_append(str, idt + 1, _("Metadata Signature"), tmp);
 	}
 	tmp = fwupd_remote_get_firmware_base_uri(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: remote URI */
-		fu_common_string_append_kv(str, idt + 1, _("Firmware Base URI"), tmp);
+		fu_string_append(str, idt + 1, _("Firmware Base URI"), tmp);
 	}
 	tmp = fwupd_remote_get_report_uri(remote);
 	if (tmp != NULL) {
 		/* TRANSLATORS: URI to send success/failure reports */
-		fu_common_string_append_kv(str, idt + 1, _("Report URI"), tmp);
-		fu_common_string_append_kv(
-		    str,
-		    idt + 1,
-		    /* TRANSLATORS: Boolean value to automatically send reports */
-		    _("Automatic Reporting"),
-		    fwupd_remote_get_automatic_reports(remote) ? "true" : "false");
+		fu_string_append(str, idt + 1, _("Report URI"), tmp);
+		fu_string_append(str,
+				 idt + 1,
+				 /* TRANSLATORS: Boolean value to automatically send reports */
+				 _("Automatic Reporting"),
+				 fwupd_remote_get_automatic_reports(remote) ? "true" : "false");
 	}
 
 	return g_string_free(str, FALSE);
@@ -2056,20 +2175,20 @@ fu_security_attr_append_str(FwupdSecurityAttr *attr,
 		g_string_append(str, "✘ ");
 	}
 	g_string_append_printf(str, "%s:", name);
-	for (guint i = fu_common_strwidth(name); i < 30; i++)
+	for (guint i = fu_strwidth(name); i < 30; i++)
 		g_string_append(str, " ");
 	if (fwupd_security_attr_has_flag(attr, FWUPD_SECURITY_ATTR_FLAG_OBSOLETED)) {
-		g_string_append_printf(str,
-				       "\033[37m\033[1m%s\033[0m",
-				       fu_security_attr_get_result(attr));
+		g_autofree gchar *fmt = fu_util_term_format(fu_security_attr_get_result(attr),
+							    FU_UTIL_TERM_COLOR_YELLOW);
+		g_string_append(str, fmt);
 	} else if (fwupd_security_attr_has_flag(attr, FWUPD_SECURITY_ATTR_FLAG_SUCCESS)) {
-		g_string_append_printf(str,
-				       "\033[32m\033[1m%s\033[0m",
-				       fu_security_attr_get_result(attr));
+		g_autofree gchar *fmt = fu_util_term_format(fu_security_attr_get_result(attr),
+							    FU_UTIL_TERM_COLOR_GREEN);
+		g_string_append(str, fmt);
 	} else {
-		g_string_append_printf(str,
-				       "\033[31m\033[1m%s\033[0m",
-				       fu_security_attr_get_result(attr));
+		g_autofree gchar *fmt =
+		    fu_util_term_format(fu_security_attr_get_result(attr), FU_UTIL_TERM_COLOR_RED);
+		g_string_append(str, fmt);
 	}
 	if ((flags & FU_SECURITY_ATTR_TO_STRING_FLAG_SHOW_URLS) > 0 &&
 	    fwupd_security_attr_get_url(attr) != NULL) {
@@ -2137,12 +2256,12 @@ fu_util_security_event_to_string(FwupdSecurityAttr *attr)
 		      /* TRANSLATORS: HSI event title */
 		      _("Kernel lockdown enabled")},
 		     /* ------------------------------------------*/
-		     {FWUPD_SECURITY_ATTR_ID_ACPI_DMAR,
+		     {FWUPD_SECURITY_ATTR_ID_PREBOOT_DMA_PROTECTION,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
 		      _("Pre-boot DMA protection is disabled")},
-		     {FWUPD_SECURITY_ATTR_ID_ACPI_DMAR,
+		     {FWUPD_SECURITY_ATTR_ID_PREBOOT_DMA_PROTECTION,
 		      FWUPD_SECURITY_ATTR_RESULT_NOT_ENABLED,
 		      FWUPD_SECURITY_ATTR_RESULT_ENABLED,
 		      /* TRANSLATORS: HSI event title */
@@ -2258,6 +2377,12 @@ fu_util_security_events_to_string(GPtrArray *events, FuSecurityAttrToStringFlags
 		g_autofree gchar *check = NULL;
 		g_autofree gchar *eventstr = NULL;
 
+		/* skip events that have either been added or removed with no prior value */
+		if (fwupd_security_attr_get_result(attr) == FWUPD_SECURITY_ATTR_RESULT_UNKNOWN ||
+		    fwupd_security_attr_get_result_fallback(attr) ==
+			FWUPD_SECURITY_ATTR_RESULT_UNKNOWN)
+			continue;
+
 		date = g_date_time_new_from_unix_utc((gint64)fwupd_security_attr_get_created(attr));
 		dtstr = g_date_time_format(date, "%F %T");
 		eventstr = fu_util_security_event_to_string(attr);
@@ -2387,7 +2512,7 @@ fu_util_security_attrs_to_string(GPtrArray *attrs, FuSecurityAttrToStringFlags s
 		    "\n%s\n » %s\n",
 		    /* TRANSLATORS: this is instructions on how to improve the HSI security level */
 		    _("This system has a low HSI security level."),
-		    "https://github.com/fwupd/fwupd/wiki/Low-host-security-level");
+		    "https://fwupd.github.io/hsi.html#low-security-level");
 	}
 	if (runtime_help) {
 		g_string_append_printf(
@@ -2395,7 +2520,7 @@ fu_util_security_attrs_to_string(GPtrArray *attrs, FuSecurityAttrToStringFlags s
 		    "\n%s\n » %s\n",
 		    /* TRANSLATORS: this is instructions on how to improve the HSI suffix */
 		    _("This system has HSI runtime issues."),
-		    "https://github.com/fwupd/fwupd/wiki/Host-security-ID-runtime-issues");
+		    "https://fwupd.github.io/hsi.html#hsi-runtime-suffix");
 	}
 
 	if (pcr0_help) {
@@ -2404,7 +2529,7 @@ fu_util_security_attrs_to_string(GPtrArray *attrs, FuSecurityAttrToStringFlags s
 		    "\n%s\n » %s\n",
 		    /* TRANSLATORS: this is more background on a security measurement problem */
 		    _("The TPM PCR0 differs from reconstruction."),
-		    "https://github.com/fwupd/fwupd/wiki/TPM-PCR0-differs-from-reconstruction");
+		    "https://fwupd.github.io/hsi.html#pcr0-tpm-event-log-reconstruction");
 	}
 
 	return g_string_free(str, FALSE);
